type AbstractEventListener<T, O, R> = (pParameter: T, pEventOwner: O) => R;
type EventListener<T, O> = AbstractEventListener<T, O, void>;
type AsyncEventListener<T, O> = AbstractEventListener<T, O, Promise<void>>;
declare abstract class AbstractListenableEvent<T, O, R> {
    get hasListeners(): boolean;
    constructor(pOwner: O);
    addListener(pListener: AbstractEventListener<T, O, R>): void;
    removeListener(pListener: AbstractEventListener<T, O, R>): void;
    abstract trigger(pParameter?: T): R;
    protected mOwner: O;
    protected mListeners: Array<AbstractEventListener<T, O, R>>;
    protected mLockQueue: Array<{
        remove: boolean;
        listener: AbstractEventListener<T, O, R>;
    }> | null;
    protected mListenersLocked: boolean;
    protected addToLockQueue(pRemove: boolean, pListener: AbstractEventListener<T, O, R>): void;
    protected processLockQueue(): void;
}
/**
* Synchronous listenable event.
*/
declare class ListenableEvent<T, O> extends AbstractListenableEvent<T, O, void> {
    trigger(pParameter: T): void;
}
/**
* Asynchronous listenable event.
*/
declare class AsyncListenableEvent<T, O> extends AbstractListenableEvent<T, O, Promise<void>> {
    constructor(pOwner: O);
    trigger(pParameter: T): Promise<void>;
    private mTriggerLock;
}

declare abstract class CustomError extends Error {
    constructor(pMessage?: string);
    get name(): string;
    set name(pName: string);
    private mCustomName;
}

declare const ERR_FAILED = "failed";
declare const ERR_INVALID_STATE = "invalid state";
declare const ERR_INVALID_ARGUMENT = "invalid argument";
declare const ERR_NOT_IMPLEMENTED = "not implemented";
declare const ERR_NOT_AVAILABLE = "not available";
declare function newError(pCategory: string, pMessage?: string): Error;
declare function rejectError<T = unknown>(pCategory: string, pMessage?: string): Promise<T>;

type index_d$f_CustomError = CustomError;
declare const index_d$f_CustomError: typeof CustomError;
declare const index_d$f_ERR_FAILED: typeof ERR_FAILED;
declare const index_d$f_ERR_INVALID_ARGUMENT: typeof ERR_INVALID_ARGUMENT;
declare const index_d$f_ERR_INVALID_STATE: typeof ERR_INVALID_STATE;
declare const index_d$f_ERR_NOT_AVAILABLE: typeof ERR_NOT_AVAILABLE;
declare const index_d$f_ERR_NOT_IMPLEMENTED: typeof ERR_NOT_IMPLEMENTED;
declare const index_d$f_newError: typeof newError;
declare const index_d$f_rejectError: typeof rejectError;
declare namespace index_d$f {
  export { index_d$f_CustomError as CustomError, index_d$f_ERR_FAILED as ERR_FAILED, index_d$f_ERR_INVALID_ARGUMENT as ERR_INVALID_ARGUMENT, index_d$f_ERR_INVALID_STATE as ERR_INVALID_STATE, index_d$f_ERR_NOT_AVAILABLE as ERR_NOT_AVAILABLE, index_d$f_ERR_NOT_IMPLEMENTED as ERR_NOT_IMPLEMENTED, index_d$f_newError as newError, index_d$f_rejectError as rejectError };
}

interface Indexable<T = any> {
    [key: string]: T;
}

/**
 * Returns true if the given object is an object.
 */
declare function isObject(pObj: unknown): pObj is object;
/**
 * Returns true if the given object is plain object.
 */
declare function isPlainObject(pObj: unknown): pObj is object;
/**
 * Returns true if the object is null or does not contain own properties.
 */
declare function isNullOrEmpty$1(pObject: object | null | undefined): pObject is null | undefined;
/**
 * Creates a key/value map for the properties of the given object.
 */
declare function toMap<T>(pObject: object): Map<string, T>;
/**
 * Creates a plain object using the map entries as propeties.
 */
declare function fromMap<T>(pMap: Map<string, T>): Indexable<T>;
/**
 * Checks if two objects are shallow equal.
 */
declare function shallowEqual(pObjectA: object | null | undefined, pObjectB: object | null | undefined): boolean;

interface Serializable<T> {
    serialize(): T | null;
    deserialize(pData?: T | null): boolean;
}

type index_d$e_Indexable<T = any> = Indexable<T>;
type index_d$e_Serializable<T> = Serializable<T>;
declare const index_d$e_fromMap: typeof fromMap;
declare const index_d$e_isObject: typeof isObject;
declare const index_d$e_isPlainObject: typeof isPlainObject;
declare const index_d$e_shallowEqual: typeof shallowEqual;
declare const index_d$e_toMap: typeof toMap;
declare namespace index_d$e {
  export { type index_d$e_Indexable as Indexable, type index_d$e_Serializable as Serializable, index_d$e_fromMap as fromMap, isNullOrEmpty$1 as isNullOrEmpty, index_d$e_isObject as isObject, index_d$e_isPlainObject as isPlainObject, index_d$e_shallowEqual as shallowEqual, index_d$e_toMap as toMap };
}

type AjaxMethod = "GET" | "POST" | "PUT" | "DELETE" | "PATCH" | "HEAD";
type AjaxDataType = "post" | "queryString" | "json" | "text" | "arraybuffer" | "blob" | "document" | "formdata" | "xml";
interface AjaxOptions {
    /**
     * Defines the type of the request data.
     * Available types: `post`, `queryString`, `json`, `text`, `arraybuffer`, `blob`, `document`, `xml` or `formdata` (default: post)
     */
    dataType?: AjaxDataType;
    /**
     * The response type.
     * Available types: `auto`, `json`, `xml`, `text`, `arraybuffer`, `blob` or `document` (default: `auto`)
     * Note: use `xml` to parse the response always as xml using the DOMParser. If `document` is used the response will be parsed
     * as xml or as html by the browser depending on the content-type of the response.
     */
    responseType?: XMLHttpRequestResponseType | "xml" | "auto";
    /** browser caching (default: true) */
    cache?: boolean;
    /** the user to access to the URL, if needed */
    user?: string;
    /** the password to access to the URL, if needed */
    password?: string;
    /** object containing headers to be sent */
    headers?: {
        [key: string]: string;
    };
    /** sends credentials with the XHR request (default: false) */
    withCredentials?: boolean;
    /** the timeout for the request in ms (default: 30000) */
    timeout?: number;
    /** defines how many retry attempts will be performed in case of connection errors (default: 3) */
    retryAttempts?: number;
    /** if true the global `ajaxErrorHandler` will not be triggered in case of an error (default: false) */
    ignoreGlobalErrorHandler?: boolean;
}
/**
 * Will be thrown if the ajax request was aborted.
 */
declare class AjaxAbortedError extends CustomError {
    constructor(pUrl: string);
}
/**
 * Will be thrown for ajax request timeouts.
 */
declare class AjaxTimeoutError extends CustomError {
    constructor(pUrl: string);
}
/**
 * Will be thrown for ajax connection errors.
 */
declare class AjaxConnectionError extends CustomError {
    constructor(pUrl: string);
}
interface AjaxPromise<T> extends Promise<T> {
    /**
     * Aborts the currently running ajax request.
     * In this case the ajax promise will be rejected with `AjaxAbortedError`.
     */
    abort(): void;
}
interface AjaxRequestInfo {
    url: string;
    method: AjaxMethod;
    data?: unknown;
    options?: AjaxOptions;
}
interface AjaxErrorInfo {
    status: number;
    textStatus: string;
    errorThrown: Error | string;
    responseError: Error;
    requestInfo: AjaxRequestInfo;
    /** Shows how many retries were already performed. 0 for the first error. */
    retryCount: number;
    /** If called the ajax call will be executed again. */
    retry(): void;
    /** If retry was not called reject has to be called to reject the underlying promise. */
    reject(pCustomError?: Error): void;
}
type AjaxCustomErrorCallback = (pError: Error | string, pXhr: XMLHttpRequest, pResponse: unknown) => string | Error | null;
type AjaxBeforeCallback = (pXhr: XMLHttpRequest) => void;
/**
 * Wrapper function for XMLHttpRequests with optional custom error handling.
 * pErrorMessageCallback can be used to return a custom error message.
 */
declare function ajax<T = unknown>(pMethod: AjaxMethod, pUrl: string, pData?: unknown, pOptions?: AjaxOptions, pCustomErrorCallback?: AjaxCustomErrorCallback, pBeforeCallback?: AjaxBeforeCallback): AjaxPromise<T>;
/**
 * This function performs an HEAD request to fetch the content-type of the given url.
 */
declare function fetchContentType(pUrl: string): Promise<string | null>;

/**
 * Executes pTask sequentially for all elements of pArray.
 * If pTask returns false, the execution is aborted.
 * Returns false if execution was aborted.
 */
declare function forEach<T>(pArray: Array<T>, pReverseOrder: boolean, pTask: (pIndex: number, pElement: T) => Promise<boolean>): Promise<boolean>;
/**
 * Executes pTask parallel for all elements of pArray.
 * Order of execution is random.
 * Execution is aborted in case of error.
 * The maximum number of concurrent tasks can be defined with the `pMaxConcurrentTasks` parameter.
 * If it is 0 or undefined, the maximum number of concurrent tasks will be unlimited (default: undefined).
 */
declare function forEachParallel<T, PT>(pArray: Array<T>, pTask: (pIndex: number, pElement: T) => Promise<PT>, pMaxConcurrentTasks?: number): Promise<PT[]>;
/** Returns a promise which resolves after the given timeout. Note: uses `setTimeout` internally. */
declare function delay(pTimeout?: number): Promise<void>;
/** Returns a promise which resolves with the delay time after `requestAnimationFrame`. */
declare function delayForAnimation(): Promise<number>;

/**
 * A task which will be executed after a given delay.
 */
declare class DelayedTask<T = void> {
    constructor(pTask: () => Promise<T>);
    /**
     * Starts the execution of the task. The task will be executed only once if consecutive
     * calls are made during the delay.
     * @param pDelay Delay in milliseconds before the task gets executed.
     * @param pRestartTimer If true and the delay timer is currently running, the timer will be
     * restartet with the new delay. If false the currently running timer will
     * stay active and the new delay is ignored. (default: false)
     */
    run(pDelay: number, pRestartTimer?: boolean): Promise<T>;
    private mTask;
    private mTimer;
    private mPromise;
    private mPromiseResolve;
    private mPromiseReject;
    private onTimeout;
}

interface LockContext {
    unlock(pAsync?: boolean): void;
}
/** Can be use to synchronize an asynchronous operation to prevent parallel execution. */
declare class Lock {
    get isLocked(): boolean;
    constructor(pMaxConcurrentTasks?: number);
    acquireLock(): Promise<LockContext>;
    waitWhileLocked(): Promise<void>;
    private mMaxConcurrentTasks;
    private mCurrentRunningTasks;
    private mPromiseQueue;
    private mLockContext;
    private mWaitPromise;
    private mWaitPromiseResolve;
    private onUnlock;
    private resolveNext;
    private resolveWaitPromise;
}

/**
 * The TaskQueue is a FIFO queue for asynchronous tasks. The tasks are sequentially processed
 * in the order they were added.
 */
declare class TaskQueue {
    get hasPendingTasks(): boolean;
    constructor(pLock?: Lock);
    addTask<T>(pTask: () => Promise<T>): Promise<T>;
    private mLock;
}

/**
 * Wrapper class for window.setTimeout().
 */
declare class Timer {
    /** true if timer was started */
    get isRunning(): boolean;
    constructor(pHandler: () => void);
    /**
     * Starts the timer. The handler will be executed only once if consecutive calls are
     * made before the timeout.
     * @param pTimeout Timeout in milliseconds for the timer.
     * @param pRestart If true and the timer is currently running, the timer will be restartet
     * with the new timeout. If false the currently running timer will
     * stay active and the new timeout is ignored. (default: false)
     */
    start(pTimeout: number, pRestart?: boolean): void;
    /** stops the timmer if it is currently running */
    stop(): void;
    private mTimer;
    private mHandler;
    private onTimeout;
}

type index_d$d_AjaxAbortedError = AjaxAbortedError;
declare const index_d$d_AjaxAbortedError: typeof AjaxAbortedError;
type index_d$d_AjaxBeforeCallback = AjaxBeforeCallback;
type index_d$d_AjaxConnectionError = AjaxConnectionError;
declare const index_d$d_AjaxConnectionError: typeof AjaxConnectionError;
type index_d$d_AjaxCustomErrorCallback = AjaxCustomErrorCallback;
type index_d$d_AjaxDataType = AjaxDataType;
type index_d$d_AjaxErrorInfo = AjaxErrorInfo;
type index_d$d_AjaxMethod = AjaxMethod;
type index_d$d_AjaxOptions = AjaxOptions;
type index_d$d_AjaxPromise<T> = AjaxPromise<T>;
type index_d$d_AjaxRequestInfo = AjaxRequestInfo;
type index_d$d_AjaxTimeoutError = AjaxTimeoutError;
declare const index_d$d_AjaxTimeoutError: typeof AjaxTimeoutError;
type index_d$d_DelayedTask<T = void> = DelayedTask<T>;
declare const index_d$d_DelayedTask: typeof DelayedTask;
type index_d$d_Lock = Lock;
declare const index_d$d_Lock: typeof Lock;
type index_d$d_LockContext = LockContext;
type index_d$d_TaskQueue = TaskQueue;
declare const index_d$d_TaskQueue: typeof TaskQueue;
type index_d$d_Timer = Timer;
declare const index_d$d_Timer: typeof Timer;
declare const index_d$d_ajax: typeof ajax;
declare const index_d$d_delay: typeof delay;
declare const index_d$d_delayForAnimation: typeof delayForAnimation;
declare const index_d$d_fetchContentType: typeof fetchContentType;
declare const index_d$d_forEach: typeof forEach;
declare const index_d$d_forEachParallel: typeof forEachParallel;
declare namespace index_d$d {
  export { index_d$d_AjaxAbortedError as AjaxAbortedError, type index_d$d_AjaxBeforeCallback as AjaxBeforeCallback, index_d$d_AjaxConnectionError as AjaxConnectionError, type index_d$d_AjaxCustomErrorCallback as AjaxCustomErrorCallback, type index_d$d_AjaxDataType as AjaxDataType, type index_d$d_AjaxErrorInfo as AjaxErrorInfo, type index_d$d_AjaxMethod as AjaxMethod, type index_d$d_AjaxOptions as AjaxOptions, type index_d$d_AjaxPromise as AjaxPromise, type index_d$d_AjaxRequestInfo as AjaxRequestInfo, index_d$d_AjaxTimeoutError as AjaxTimeoutError, index_d$d_DelayedTask as DelayedTask, index_d$d_Lock as Lock, type index_d$d_LockContext as LockContext, index_d$d_TaskQueue as TaskQueue, index_d$d_Timer as Timer, index_d$d_ajax as ajax, index_d$d_delay as delay, index_d$d_delayForAnimation as delayForAnimation, index_d$d_fetchContentType as fetchContentType, index_d$d_forEach as forEach, index_d$d_forEachParallel as forEachParallel };
}

declare class SoapError extends CustomError {
    get detail(): SoapErrorDetail | undefined;
    get methodName(): string | undefined;
    constructor(pMessage?: string, pDetail?: SoapErrorDetail, pMethodName?: string);
    private mDetail;
    private mMethodName;
}
interface SoapErrorDetail {
}
type RequestOptionsCallback = (pSoapMethod: string) => AjaxOptions | undefined;
declare abstract class SoapService {
    get url(): string;
    get namespaceUrl(): string;
    get sessionId(): string;
    /** custom timeout for soap requests */
    requestTimeout?: number;
    /**
     * Can be used to define custom request options for different soap methods.
     */
    onGetRequestOptions?: RequestOptionsCallback | undefined;
    constructor(pUrl: string, pNamespaceUrl: string, pSessionId: string);
    static SoapDataToArray(pSoapData: any, pItemCallback?: (pSoapItem: any) => any): Array<any> | undefined;
    static SoapDataToArrayNU(pSoapData: any, pItemCallback?: (pSoapItem: any) => any): Array<any>;
    static SoapDataToBool(this: void, pSoapData: any): boolean | undefined;
    static SoapDataToFloat(this: void, pSoapData: any): number | undefined;
    static SoapDataToDecimal(this: void, pSoapData: any): number | undefined;
    static SoapDataToInt(this: void, pSoapData: any): number | undefined;
    static GetSoapDataNodeValue(pSoapData: any): string | undefined;
    static SerializeDataToXml(pData: string | object, pAddTypeNSCallback: () => void): string | null;
    static DeserializeXmlToObject(pXml: string | null): Indexable | null;
    static LogSoapErrors: boolean;
    protected mUrl: string;
    protected mNamespaceUrl: string;
    protected mSessionId: string;
    /**
     * @param pOptions Deprecated - should no longer be used, use `SoapService.onGetRequestOptions` instead
     */
    protected soapAjax(pMethod: string, pData: any, pOptions?: AjaxOptions): Promise<any>;
    protected getErrorDetail(pSoapData: any): SoapErrorDetail | undefined;
    private static readonly NODE_TEXT_KEY;
    private static ObjectToXml;
    private static PropertyToXml;
    private static XmlToJson;
    private getBodyFromSoapResponse;
    private getErrorBodyFromXhr;
}
declare abstract class SoapRequestData {
    constructor();
    /**
     * Helper property to force correct type in TypeScript.
     * If you get a TypeScript error like `Property _ensureTypeSafety is missing` you are perhaps
     * using a plain JavaScript object as a parameter for a SOAP function call.
     * Please use the correct class instance instead.
     */
    protected _ensureTypeSafety: string;
}
/**
 * Soap attribute decorator
 * Decorated properties will be used as soap attributes instead of elements.
 */
declare function soapAttribute(): PropertyDecorator;
/**
 * Soap node text decorator
 * The decorated property will be used as the element text. All other
 * properties (except attributes) will be ignored in this case.
 */
declare function soapNodeText(): PropertyDecorator;
declare abstract class BaseEaiwsService extends SoapService {
    constructor(pOwner: EaiwsSession, pUrl: string, pNamespaceUrl: string, pSessionId: string);
    protected mOwner: EaiwsSession;
}

type AttachmentMode = "None" | "Item" | "Composite" | "TryComposite";
type ArticleDescriptionMode = "Short" | "Long" | "Both";
type Axis = "X" | "Y" | "Z";
type BasketItemAttrId = "Undefined" | "UserDefined" | "Manufacturer" | "Series" | "ArticleNumber" | "Description" | "Quantity" | "SinglePurchasePrice" | "TotalPurchasePrice" | "SingleSalesPrice" | "TotalSalesPrice" | "SingleNetPrice" | "TotalNetPrice" | "SingleGrossPrice" | "TotalGrossPrice" | "Position" | "CatalogImage" | "GeneratedImage" | "ArticleImage";
type BasketItemType = "Undefined" | "Folder" | "Article" | "Aggregate" | "PartialPlanning" | "UserArticle" | "SetArticle" | "OCDArticle" | "Text";
type CalculationRule = "Invalid" | "Percent" | "FixedAmount" | "Quantity" | "GrossWeight" | "NetWeight" | "Volume" | "Rounding";
type CollatorDecomposition = "None" | "Canonical" | "Full";
type CollatorStrength = "Primary" | "Secondary" | "Tertiary" | "Identical";
type ColumnType = "Undefined" | "Builtin" | "Text" | "Number" | "Boolean" | "Image" | "EClass";
type ConditionClass = "Price" | "PriceModifier" | "Tax";
type ConditionEditMode = "Never" | "IfCondRecFound" | "IfCondRecNotFound" | "ManualWithDefault" | "Manual";
type ConditionSign = "NoRestriction" | "Negative" | "Positive";
type CSValueKind = "Other" | "ItemQuantity" | "SalesUnitSize" | "SalesUnitGrossWeight" | "SalesUnitNetWeight" | "SalesUnitVolume" | "InactiveItemFlag" | "SetArticleIdentifier" | "CondRecordAmount" | "Incoming" | "Reference" | "Outgoing" | "CondBase" | "ScaleBase" | "CondAmount" | "DefaultQtyRel" | "QuantityRelation" | "CondBaseQtyRelRatio" | "CondValue" | "SubtotalValue" | "SetArticleQty" | "GroupCondBase" | "AltGroupCondBase" | "GroupScaleBase" | "GroupAmount" | "CondBaseRatio" | "GroupValue" | "GroupValueResidue" | "AggrIncoming" | "AggrReference" | "AggrOutgoing" | "AggrCondBase" | "AggrCondValue" | "AggrSubtotalValue" | "AggrSetArticleQtys";
type CSErrorCode = "InconsistentItemState" | "UnknownItemDataAccessError" | "UndefinedValue" | "InvalidValue" | "InfiniteValue" | "NullValue" | "PercentageExpected" | "MonetaryValueExpected" | "MonetaryBaseExpected" | "QuantityBaseExpected" | "UnknownValue" | "UnknownCurrency" | "CurrencyConversionFailed" | "CurrencyMismatch" | "ConformabilityError" | "DivisionByZero" | "Overflow" | "InvalidOperation" | "NoPreviousLine" | "ReferencedLineNotFound" | "NoInversePriceCalculation" | "UndefinedInverseGroupConditionCalculation";
type CSOperationKind = "Add" | "Subtract" | "Multiply" | "Divide" | "Remainder" | "CurrencyConversion" | "UnitConversion";
type DescrType = "Default" | "Short" | "Long" | "Features" | "Extra" | "PreferUserDescr";
type Dimension = "X" | "Y" | "Z" | "PX" | "PY" | "PZ" | "NX" | "NY" | "NZ";
type GetItemPropertiesTextMode = "Legacy" | "Simple" | "Multi" | "Mixed";
type HalfWayRoundingMode = "Even" | "Up";
type InactiveFlag = "NoData" | "SubsequentPrice";
type LineInsertMode = "Always" | "Manual" | "Auto";
type LineType = "Condition" | "Subtotal" | "Text" | "CalculationBreak";
type MergeMode = "None" | "Articles" | "Composites" | "CompositesStrict" | "SubArticles" | "Compact" | "ArticlesCompact";
type MoveItemsDirection = "Up" | "Down" | "Indent" | "Unindent";
type MoveItemsResult = "Done" | "NothingToDo" | "NoConsecutiveItemSequence" | "NoPredecessor" | "NoSuccessor" | "HasSuccessor" | "NoGrandparent" | "CannotChangePlanningItemIndentation" | "NewParentHasInappropriateType";
type OAPActionState = "Disabled" | "Enabled" | "Success" | "Failure" | "NotResponsible";
type OAPArticleSpecMode = "Self" | "Explicit";
type OAPClientCapability = "MultiActionChoice" | "PlanningMode";
type OAPMediaSource = "PIM" | "YouTube";
type OAPMethodCallType = "Instance" | "Class";
type OAPObjectCategory = "Self" | "ParentArticle" | "TopArticle" | "SubArticles" | "SubArticlesDeep" | "SubArticle" | "Article" | "Attached" | "AttachedRecursive" | "AttachedArea" | "AttachedAreaRecursive" | "AttachedArticle" | "MethodCall";
type OAPPropChangeType = "Value" | "Visibility" | "Editability";
type OAPSymbolSize = "Small" | "Medium" | "Large";
type OAPSymbolType = "Add" | "Delete" | "Edit" | "Flip" | "RotatePY" | "RotateNY" | "RotateNY90" | "RotatePY90" | "Material" | "ChangeDimHorizontal" | "ChangeDim2Left" | "ChangeDim2Right" | "ChangeDimVertical" | "ChangeDimDown" | "ChangeDimUp" | "PosHorizontal" | "Pos2Left" | "Pos2Right" | "PosVertical" | "PosDown" | "PosUp" | "OnOff" | "StartDimChange" | "Video" | "Attention" | "Electrification" | "Lighting" | "PropChange" | "PropEdit" | "CreateChild" | "CreateChildren" | "CreateSibling" | "CreateSiblings" | "DeleteObj" | "Transform" | "Translate" | "Rotate" | "RotatePX" | "RotateNX" | "RotateX180" | "RotateY180" | "RotatePZ" | "RotateNZ" | "RotateZ180" | "Logics" | "CheckRules" | "Info" | "Other" | "MovePlane" | "MoveAxis" | "MoveDir";
type OAPTileSize = "Small" | "Medium" | "Large";
type OAPViewType = "List" | "Tile";
type OFMLUpdateState = "Unknown" | "UpToDate" | "Updatable" | "Migratable" | "Invalid" | "NoCatalog" | "MultipleCatalogs";
type PlanningDirection = "Right_Front" | "Right_Back" | "Left_Front" | "Left_Back" | "Front_Right" | "Front_Left" | "Back_Right" | "Back_Left";
type PrintControl = "Never" | "PositionAlways" | "PositionNonZero" | "PositionChanged" | "PositionChangedNonZero" | "HeaderAlways" | "HeaderNonZero" | "HeaderChanged" | "HeaderChangedNonZero";
type PropertyType = "Character" | "Numeric" | "Length";
type RelocateItemsResult = "Done" | "NothingToDo" | "CannotReparentPlanningItem" | "NewParentHasInappropriateType" | "IllegalStructuralChange";
type RoundingRule = "NoRounding" | "RoundToNearest" | "RoundUp" | "RoundDown";
type SetArticleMode = "Expand" | "Collapse" | "Dynamic";
type SetLanguagesMode = "Default" | "CurrentProject" | "AllProjects";
type SpatialPlanningDirection = "Horizontal" | "Vertical";
type TMColumnId = "Undefined" | "Identifier" | "Name" | "Language" | "Text" | "Visible";
type TMTextType = "Undefined" | "Short" | "Long" | "Features" | "Extra";
type ViewDisplayMode = "Undefined" | "Sorted" | "Planning";
type IsoDateString$2 = string;
declare class AddStateCode extends SoapRequestData {
    value: string;
    domain: string;
    constructor();
    static FromSoapArray(pSoapArray: any): Array<AddStateCode> | undefined;
    static FromSoapNU(this: void, pSoapData: any): AddStateCode;
}
declare class ArticleClassification extends SoapRequestData {
    description?: Array<DisplayText$1>;
    system: string;
    qualifier?: string;
    classId: string;
    constructor();
    static FromSoapArray(pSoapArray: any): Array<ArticleClassification> | undefined;
    static FromSoapNU(this: void, pSoapData: any): ArticleClassification;
}
declare class ArticleDescription extends SoapRequestData {
    shortText?: Array<DisplayText$1>;
    longText?: Array<DisplayText$1>;
    featureText?: Array<DisplayText$1>;
    static FromSoap(pSoapData: any): ArticleDescription | undefined;
}
declare class ArticleProperties extends SoapRequestData {
    catalogId?: string;
    manufacturerId?: string;
    manufacturerName?: string;
    seriesId?: string;
    seriesName?: string;
    manufacturer?: string;
    program?: string;
    distributionRegion?: string;
    baseArticleNumber?: string;
    finalArticleNumber?: string;
    variantCode?: string;
    ofmlVariantCode?: string;
    useFinalArticleNumber?: boolean;
    shortText?: string;
    longText?: string;
    featureText?: string;
    descriptionMode?: ArticleDescriptionMode;
    productDescription?: ArticleDescription;
    userDescription?: ArticleDescription;
    currency?: string;
    purchaseCurrency?: string;
    salesCurrency?: string;
    purchasePrice?: number;
    salesPrice?: number;
    priceDateSupported?: boolean;
    priceDateEditable?: boolean;
    priceDate?: IsoDateString$2;
    quantity?: number;
    alternativePosition?: boolean;
    excludedCalculations?: Array<string>;
    inactivePositionState?: Array<InactivePositionState>;
    inconsistencyFlag?: boolean;
    inconsistencyReason?: Array<string>;
    priceInfo?: PriceInfo;
    packagingInfo?: PackagingInfo;
    pseudoArticle?: boolean;
    nonOfferArticle?: boolean;
    nonOrderArticle?: boolean;
    articleClassifications?: Array<ArticleClassification>;
    ofmlUpdateState?: OFMLUpdateState;
    geometryId?: string;
    subArticles?: Array<ArticleProperties>;
    addStateCodes?: Array<AddStateCode>;
    static FromSoapArray(pSoapArray: any): Array<ArticleProperties> | undefined;
    static FromSoap(pSoapData: any): ArticleProperties | undefined;
    static FromSoapNU(this: void, pSoapData: any): ArticleProperties;
}
declare class BasketColumn extends SoapRequestData {
    name?: string;
    title?: string;
    defaultValue?: string;
    id: string;
    type?: ColumnType;
    itemAttrId?: BasketItemAttrId;
    removable?: boolean;
    editable?: boolean;
    defaultColumn?: string;
    minWidth?: number;
    weight?: number;
    readOnly?: boolean;
    constructor();
    static FromSoapArrayNU(pSoapArray: any): Array<BasketColumn>;
    static FromSoap(pSoapData: any): BasketColumn | undefined;
    static FromSoapNU(this: void, pSoapData: any): BasketColumn;
}
declare class BasketConfig extends SoapRequestData {
    viewIds?: Array<string>;
    columnIds?: Array<string>;
    obkVersionInfo?: OBKVersionInfo;
    defaultView?: string;
    columnsEditable?: boolean;
    currency?: string;
    currencyEditable?: boolean;
    defaultPriceDate?: IsoDateString$2;
    static FromSoap(pSoapData: any): BasketConfig | undefined;
}
declare class BasketViewConfig extends SoapRequestData {
    name?: string;
    visibleColumns?: Array<string>;
    columnWidths?: Array<ColumnWidth>;
    sortConfig?: BasketViewSortConfig;
    articleDescrMode?: Array<DescrType>;
    viewId: string;
    removable?: boolean;
    editable?: boolean;
    displayMode?: ViewDisplayMode;
    expandGroups?: boolean;
    expandPlanningFolders?: boolean;
    expandBasketFolders?: boolean;
    expandPartialPlannings?: boolean;
    expandAggregates?: boolean;
    textItemsVisible?: boolean;
    nonOfferArticlesVisible?: boolean;
    nonOrderArticlesVisible?: boolean;
    mergeMode?: MergeMode;
    autoColumnWidth?: boolean;
    hiddenDiscounts?: boolean;
    setArticleMode?: SetArticleMode;
    constructor();
    static FromSoapArrayNU(pSoapArray: any): Array<BasketViewConfig>;
    static FromSoap(pSoapData: any): BasketViewConfig | undefined;
    static FromSoapNU(this: void, pSoapData: any): BasketViewConfig;
}
declare class BasketViewSortConfig extends SoapRequestData {
    groups?: Array<SortGroup>;
    collatorStrength?: CollatorStrength;
    collatorDecomposition?: CollatorDecomposition;
    static FromSoap(pSoapData: any): BasketViewSortConfig | undefined;
}
declare class ColumnSortOrder extends SoapRequestData {
    columnId: string;
    ascending?: boolean;
    undefinedFirst?: boolean;
    constructor();
    static FromSoapArray(pSoapArray: any): Array<ColumnSortOrder> | undefined;
    static FromSoapNU(this: void, pSoapData: any): ColumnSortOrder;
}
declare class ColumnWidth extends SoapRequestData {
    columnId: string;
    width: number;
    constructor();
    static FromSoapArray(pSoapArray: any): Array<ColumnWidth> | undefined;
    static FromSoapNU(this: void, pSoapData: any): ColumnWidth;
}
declare class ComposableGeometryProperties extends SoapRequestData {
    enabled?: boolean;
    position?: Vector3;
    rotation?: Rotation;
    scale?: Vector3;
    geometry?: string;
    itemId?: string;
    static FromSoapArray(pSoapArray: any): Array<ComposableGeometryProperties> | undefined;
    static FromSoap(pSoapData: any): ComposableGeometryProperties | undefined;
    static FromSoapNU(this: void, pSoapData: any): ComposableGeometryProperties;
}
declare class CopyOptions extends SoapRequestData {
    encoding?: string;
    suffix?: string;
    overwrite?: boolean;
    cut?: boolean;
    omitPriceData?: boolean;
}
declare class DisplayText$1 extends SoapRequestData {
    value: string;
    lang?: string;
    constructor();
    static FromSoapArray(pSoapArray: any): Array<DisplayText$1> | undefined;
    static FromSoapNU(this: void, pSoapData: any): DisplayText$1;
}
declare class ExchangeRate extends SoapRequestData {
    currency: string;
    rate?: number;
    constructor();
    static FromSoapArrayNU(pSoapArray: any): Array<ExchangeRate>;
    static FromSoapNU(this: void, pSoapData: any): ExchangeRate;
}
declare class FolderProperties extends SoapRequestData {
    name?: string;
    displayName?: Array<DisplayText$1>;
    longDisplayText?: Array<DisplayText$1>;
    showSubTotal?: boolean;
    static FromSoap(pSoapData: any): FolderProperties | undefined;
}
declare class GetArticleDataOptions extends SoapRequestData {
    noProperties?: boolean;
    fetchCatalogImage?: boolean;
    fetchCatalogIcon?: boolean;
    viewId?: string;
    separateCurrencies?: boolean;
    highResPropValueIcons?: boolean;
    fetchPropValueImages?: boolean;
}
declare class GetArticleFeaturesOptions extends SoapRequestData {
    description?: boolean;
    noInternal?: boolean;
}
declare class GetChoiceListOptions extends SoapRequestData {
    convertSurcharge?: boolean;
    formatSurcharge?: boolean;
    discardSurcharge?: boolean;
    highResPropValueIcons?: boolean;
    fetchPropValueImages?: boolean;
}
declare class InactivePositionState extends SoapRequestData {
    ppName: string;
    optional?: boolean;
    constructor();
    static FromSoapArray(pSoapArray: any): Array<InactivePositionState> | undefined;
    static FromSoapNU(this: void, pSoapData: any): InactivePositionState;
}
declare class InsertArticleOptions extends SoapRequestData {
    noComplexType?: boolean;
    attachmentMode?: AttachmentMode;
    planarPlanningDirection?: PlanningDirection;
    spatialPlanningDirection?: SpatialPlanningDirection;
    strictVarCode?: boolean;
    migrate?: boolean;
    attachPoint?: string;
}
declare class InsertInfo extends SoapRequestData {
    articlePackageId?: string;
    baseArticleNumber: string;
    catalogId?: string;
    catalogPackageId?: string;
    manufacturerId?: string;
    ofmlVariantCode?: string;
    seriesId?: string;
    variantCode?: string;
    constructor();
}
declare class ItemProperties extends SoapRequestData {
    itemId?: string;
    itemType?: BasketItemType;
    visible?: boolean;
    expanded?: boolean;
    label?: string;
    setArticleId?: string;
    tmRows?: Array<TMRow>;
    tmDescription?: string;
    composableGeometry?: ComposableGeometryProperties;
    composableGeometries?: Array<ComposableGeometryProperties>;
    folder?: FolderProperties;
    article?: ArticleProperties;
    setArticle?: SetArticleProperties;
    textItem?: TextItemProperties;
    positionNumber?: string;
    static FromSoapArrayNU(pSoapArray: any): Array<ItemProperties>;
    static FromSoapNU(this: void, pSoapData: any): ItemProperties;
}
declare class ItemSelectionOptions extends SoapRequestData {
    wholeComposite?: boolean;
    subItems?: boolean;
    parentItems?: boolean;
    viewId?: string;
}
declare class DeleteItemsOptions extends ItemSelectionOptions {
    subArticles?: boolean;
}
declare class GetAllItemsOptions extends ItemSelectionOptions {
    setArticleIds?: boolean;
    geometryIds?: boolean;
    positionNumbers?: boolean;
    basketItems?: boolean;
}
declare class GetImagesOptions extends ItemSelectionOptions {
    useCache?: boolean;
    generate?: boolean;
    itemIds?: boolean;
    attributes?: boolean;
}
declare class GetItemFieldsOptions extends ItemSelectionOptions {
    useDefault?: boolean;
    expandVariables?: boolean;
    resolveURI?: boolean;
    useImageCache?: boolean;
    generateImages?: boolean;
}
declare class GetItemPropertiesOptions extends ItemSelectionOptions {
    tmDescrMode?: Array<DescrType>;
    extraPriceInfoSelectors?: Array<string>;
    priceInfo?: boolean;
    pricingProcedureName?: string;
    positionNumbers?: boolean;
    addStateCodes?: boolean;
    textMode?: GetItemPropertiesTextMode;
    preferUserDescriptions?: boolean;
    separateCurrencies?: boolean;
    inactivePositionState?: boolean;
    articleClassifications?: boolean;
    includeCalculationErrorsInInconsistencies?: boolean;
}
declare class GetManufacturerInfoOptions extends ItemSelectionOptions {
    allData?: boolean;
    allLanguages?: boolean;
    manufacturerName?: boolean;
    seriesInfo?: boolean;
    seriesName?: boolean;
    manufacturerConfig?: boolean;
    distributorName?: boolean;
    copyright?: boolean;
    address?: boolean;
    externalCatalog?: boolean;
}
declare class CondGroupSelectionOptions extends ItemSelectionOptions {
    excludeInactiveItems?: boolean;
    includeInactiveItems?: boolean;
}
declare class GetPriceCalculationSheetOptions extends CondGroupSelectionOptions {
    sumUpComposite?: boolean;
    itemCondAmountPerUnit?: boolean;
    headerCondAmountPerUnit?: boolean;
}
declare class ItemField extends SoapRequestData {
    data: string;
    itemId: string;
    columnId: string;
    constructor();
    static FromSoapArrayNU(pSoapArray: any): Array<ItemField>;
    static FromSoapNU(this: void, pSoapData: any): ItemField;
}
declare class UpdateBasketArticlesOptions extends ItemSelectionOptions {
    update?: boolean;
    migrate?: boolean;
    recalculate?: boolean;
    priceDate?: IsoDateString$2;
}
declare class OAPActionContext extends SoapRequestData {
    self: string;
    interactor?: string;
    dpr?: number;
    constructor();
}
declare class OBKVersionInfo extends SoapRequestData {
    vendorKey: string;
    appKey: string;
    appVersion: string;
    bskXmlVersion: string;
    bskVersion?: string;
    constructor();
    static FromSoap(pSoapData: any): OBKVersionInfo | undefined;
}
declare class OperationMode extends SoapRequestData {
    subPositions?: boolean;
    mainArticles?: boolean;
    breakUpSetArticles?: boolean;
    migrate?: boolean;
}
declare class PackagingInfo extends SoapRequestData {
    width?: Quantity;
    height?: Quantity;
    depth?: Quantity;
    volume?: Quantity;
    tareWeight?: Quantity;
    netWeight?: Quantity;
    itemsPerPackUnit?: number;
    packUnitsPerArticle?: number;
    static FromSoap(pSoapData: any): PackagingInfo | undefined;
}
declare class RelocateItemsOptions extends SoapRequestData {
    doNotModify?: boolean;
    flat?: boolean;
}
declare class PasteOptions extends SoapRequestData {
    reuseItemIds?: boolean;
    returnOriginalItemIds?: boolean;
    ignoreComposableGeometries?: boolean;
}
declare class PasteContainerOptions extends PasteOptions {
    setArticleIds?: boolean;
    geometryIds?: boolean;
}
declare class Rotation extends SoapRequestData {
    axis: Vector3;
    angle: number;
    constructor();
    static FromSoap(pSoapData: any): Rotation | undefined;
}
declare class SetArticleProperties extends SoapRequestData {
    partIds?: Array<string>;
    allPartIds?: Array<string>;
    collapsed?: boolean;
    static FromSoap(pSoapData: any): SetArticleProperties | undefined;
}
declare class SetPropertyValueOptions extends SoapRequestData {
    computeVisibilityChangeFlags?: boolean;
    computeValueChangeFlags?: boolean;
    computeChoiceListChangeFlags?: boolean;
}
declare class SortGroup extends SoapRequestData {
    selector?: Array<SortGroupSelector>;
    sortOrder?: Array<ColumnSortOrder>;
    position: number;
    constructor();
    static FromSoapArray(pSoapArray: any): Array<SortGroup> | undefined;
    static FromSoapNU(this: void, pSoapData: any): SortGroup;
}
declare class SortGroupSelector extends SoapRequestData {
    itemType?: BasketItemType;
    itemId?: string;
    static FromSoapArray(pSoapArray: any): Array<SortGroupSelector> | undefined;
    static FromSoapNU(this: void, pSoapData: any): SortGroupSelector;
}
declare class TextItemProperties extends SoapRequestData {
    text?: string;
    displayText?: Array<DisplayText$1>;
    longDisplayText?: Array<DisplayText$1>;
    static FromSoap(pSoapData: any): TextItemProperties | undefined;
}
declare class Vector3 extends SoapRequestData {
    x: number;
    y: number;
    z: number;
    constructor();
    static FromSoap(pSoapData: any): Vector3 | undefined;
    static FromSoapNU(this: void, pSoapData: any): Vector3;
}
declare class Value extends SoapRequestData {
    value?: number;
    static FromSoap(pSoapData: any): Value | undefined;
}
declare class Money extends Value {
    currency: string;
    constructor();
    static FromSoap(pSoapData: any): Money | undefined;
}
declare class Percentage extends Value {
}
declare class Quantity extends Value {
    unit: string;
    constructor();
    static FromSoap(pSoapData: any): Quantity | undefined;
}
declare class ArticleData {
    baseArticleNumber: string;
    catalogIcon?: string;
    catalogImage?: string;
    currency?: string;
    descriptionMode: ArticleDescriptionMode;
    featureText: string;
    longText: string;
    manufacturerId: string;
    pdPurchasePrice?: number;
    pdPurchasePriceComponents?: Array<PriceComponent>;
    pdSalesPrice?: number;
    pdSalesPriceComponents?: Array<PriceComponent>;
    properties?: Array<Property>;
    propertyClasses?: Array<PropertyClass>;
    seriesId: string;
    shortText: string;
    variantCode: string;
    purchaseCurrency?: string;
    salesCurrency?: string;
    priceDateSupported: boolean;
    priceDateEditable: boolean;
    priceDate?: IsoDateString$2;
    getProperty(pPropClass: string, pPropName: string): Property | null;
    getPropertyValue(pPropClass: string, pPropName: string): PropertyValue | null;
    static FromSoapNU(this: void, pSoapData: any): ArticleData;
}
declare class ArticleFeature {
    displayName?: string;
    displayValue?: string;
    symbolicName?: string;
    symbolicValue?: string;
    visible: boolean;
    static FromSoapArrayNU(pSoapArray: any): Array<ArticleFeature>;
    static FromSoapNU(this: void, pSoapData: any): ArticleFeature;
}
declare class BasketItem {
    itemId: string;
    itemType: BasketItemType;
    label: string;
    mainArticleId?: string;
    subArticleIds?: Array<string>;
    subItemIds?: Array<string>;
    setArticlePartIds?: Array<string>;
    basketItemIds?: Array<string>;
    basketItems?: Array<BasketItem>;
    setArticleId?: string;
    geometryId?: string;
    positionNumber?: string;
    /**
     * Returns this.mainArticleId if it is a valid id or this.itemId otherwise.
     * Returns undefined if this.mainArticleId is undefined.
     */
    getMainArticleId(): string | undefined;
    static FromSoapArray(pSoapArray: any): Array<BasketItem> | undefined;
    static FromSoapArrayNU(pSoapArray: any): Array<BasketItem>;
    static FromSoapNU(this: void, pSoapData: any): BasketItem;
}
declare class BasketServiceFault implements SoapErrorDetail {
    message?: string;
    partCompositionFailures?: Array<PartCompositionFailure>;
    static FromSoap(pSoapData: any): BasketServiceFault | undefined;
}
declare class CalculationLine {
    inactive?: Array<InactiveFlag>;
    description: string;
    amount?: Value;
    qtyRelation?: Quantity;
    value?: Money;
    level: number;
    groupError?: CSValidationError;
    error?: CSValidationError;
    counter: number;
    conditionType?: string;
    conditionRemovable: boolean;
    amountEditable: boolean;
    amountEdited?: boolean;
    qtyRelationEditable: boolean;
    valueEditable: boolean;
    static FromSoapArrayNU(pSoapArray: any): Array<CalculationLine>;
    static FromSoapNU(this: void, pSoapData: any): CalculationLine;
}
declare class CalculationSheet {
    quantity?: Quantity;
    netValue?: Money;
    tax?: Money;
    lines: Array<CalculationLine>;
    addableConditions: Array<string>;
    currency: string;
    static FromSoapNU(this: void, pSoapData: any): CalculationSheet;
}
declare class ChoiceList {
    propClass: string;
    propName: string;
    values?: Array<PropertyValue>;
    static FromSoapArrayNU(pSoapArray: any): Array<ChoiceList>;
    static FromSoapNU(this: void, pSoapData: any): ChoiceList;
}
declare class ConditionType {
    description: string;
    accessMethod?: string;
    amountEditable: boolean;
    calculationRule: CalculationRule;
    calculationRuleEditable: boolean;
    conditionClass: ConditionClass;
    conditionDeletable: boolean;
    conditionSign: ConditionSign;
    deferredCurrencyConversionEnabled: boolean;
    editMode: ConditionEditMode;
    groupCondition: boolean;
    headerCondition: boolean;
    name: string;
    quantityRelationEditable: boolean;
    roundingRule: RoundingRule;
    valueEditable: boolean;
    static FromSoapArrayNU(pSoapArray: any): Array<ConditionType>;
    static FromSoapNU(this: void, pSoapData: any): ConditionType;
}
declare class CSValidationError {
    message: string;
    resultKind: CSValueKind;
    errorCode: CSErrorCode;
    static FromSoap(pSoapData: any): CSValidationError | undefined;
    static FromSoapNU(this: void, pSoapData: any): OAPAction;
}
declare class CSArithmeticOperationError extends CSValidationError {
    operationKind: CSOperationKind;
}
declare class CSConformabilityError extends CSValidationError {
    operationKind: CSOperationKind;
    unit1: string;
    unit2: string;
}
declare class CSCurrencyError extends CSValidationError {
    operationKind: CSOperationKind;
    currency1: string;
    currency2: string;
}
declare class CSInvalidValueError extends CSValidationError {
    parameterKind: CSValueKind;
}
declare class CSItemDataAccessError extends CSValidationError {
}
declare class CSLineNotFoundError extends CSValidationError {
}
declare class CSUndefinedOperationError extends CSValidationError {
    calculationRule: CalculationRule;
}
declare class ImageInfo {
    tag: string;
    url: string;
    attributes?: Array<string>;
    itemId?: string;
    static FromSoapArrayNU(pSoapArray: any): Array<ImageInfo>;
    static FromSoapNU(this: void, pSoapData: any): ImageInfo;
}
declare class Interval {
    maxValue: number;
    minValue: number;
    static FromSoapArray(pSoapArray: any): Array<Interval> | undefined;
    static FromSoapNU(this: void, pSoapData: any): Interval;
}
declare class ItemCalculationSheet {
    id: string;
    sheet: CalculationSheet;
    static FromSoapArrayNU(pSoapArray: any): Array<ItemCalculationSheet>;
    static FromSoapNU(this: void, pSoapData: any): ItemCalculationSheet;
}
declare class ManufacturerInfo {
    manufacturerId: string;
    concernId?: string;
    supplierId?: string;
    priceProfileRegionId?: string;
    manufacturerName?: Array<DisplayText$1>;
    seriesInfos?: Array<SeriesInfo>;
    distributorName?: Array<DisplayText$1>;
    copyright?: Array<DisplayText$1>;
    addressName?: Array<DisplayText$1>;
    addressStreet?: Array<DisplayText$1>;
    addressCity?: Array<DisplayText$1>;
    addressState?: Array<DisplayText$1>;
    addressPOBox?: Array<DisplayText$1>;
    addressZIP?: Array<DisplayText$1>;
    addressCountry?: Array<DisplayText$1>;
    addressEMail?: Array<DisplayText$1>;
    addressPhone?: Array<DisplayText$1>;
    addressFAX?: Array<DisplayText$1>;
    addressWWW?: Array<DisplayText$1>;
    externalCatalogURL?: string;
    externalCatalogName?: Array<DisplayText$1>;
    static FromSoapArrayNU(pSoapArray: any): Array<ManufacturerInfo>;
    static FromSoapNU(this: void, pSoapData: any): ManufacturerInfo;
}
declare class MergeResult {
    addedItems?: Array<string>;
    removedItems?: Array<string>;
    movedItems?: Array<string>;
    updatedItems?: Array<string>;
    static FromSoapNU(this: void, pSoapData: any): MergeResult;
}
declare class OAPAction {
    objects?: Array<OAPObjectDefinition>;
    id: string;
    static FromSoap(pSoapData: any): OAPAction | undefined;
    static FromSoapNU(this: void, pSoapData: any): OAPAction;
}
declare class OAPActionChoiceAction extends OAPAction {
    title?: string;
    actions: Array<OAPActionListItem>;
    viewType: OAPViewType;
    tileSize?: OAPTileSize;
}
declare class OAPCreateObjectAction extends OAPAction {
    parent?: OAPObjectDefinition;
    ofmlVariantCode?: string;
    initialPlacement: OAPPlacement;
    articleSpecMode: OAPArticleSpecMode;
    packageId?: string;
    baseArticleNumber?: string;
}
declare class OAPDeleteObjectAction extends OAPAction {
}
declare class OAPDimChangeAction extends OAPAction {
    dimChanges?: Array<OAPDimChange>;
}
declare class OAPDimChange2Action extends OAPAction {
    dimChanges?: Array<OAPDimChange>;
}
declare class OAPMethodCallAction extends OAPAction {
    type: OAPMethodCallType;
    context: string;
    method: string;
    arguments: string;
}
declare class OAPMessageAction extends OAPAction {
    text: string;
}
declare class OAPPropChangeAction extends OAPAction {
    type: OAPPropChangeType;
    property: string;
    value: string;
}
declare class OAPPropEditAction extends OAPAction {
    title: string;
    properties?: Array<string>;
    propertyClasses?: Array<string>;
    visibleOnly: boolean;
    editableOnly: boolean;
}
declare class OAPPropEdit2Action extends OAPAction {
    title: string;
    properties?: Array<OAPPropEditProp>;
    propertyClasses?: Array<OAPPropEditClass>;
}
declare class OAPSelectObjectAction extends OAPAction {
}
declare class OAPShowMediaAction extends OAPAction {
    mediaSource: OAPMediaSource;
    mediaId: string;
}
declare class OAPActionResult {
    actionData?: OAPAction;
    objects?: Array<string>;
    referenceObject?: string;
    newObjectPosition?: Vector3;
    newObjectRotation?: Rotation;
    addedItems?: Array<string>;
    removedItems?: Array<string>;
    movedItems?: Array<string>;
    updatedItems?: Array<string>;
    id: string;
    state: OAPActionState;
    static FromSoapArray(pSoapArray: any): Array<OAPActionResult> | undefined;
    static FromSoapArrayNU(pSoapArray: any): Array<OAPActionResult>;
    static FromSoapNU(this: void, pSoapData: any): OAPActionResult;
}
declare class OAPActionListItem {
    /**
     * Only available if OAP client capability `MultiActionChoice` is not set.
     * see `BasketService.oapSetClientCapabilities()`
     */
    action?: OAPAction;
    /**
     * Only available if OAP client capability `MultiActionChoice` is set.
     * see `BasketService.oapSetClientCapabilities()`
     */
    actionIds?: Array<string>;
    text?: string;
    imageFile?: string;
    static FromSoapArrayNU(pSoapArray: any): Array<OAPActionListItem>;
    static FromSoapNU(this: void, pSoapData: any): OAPActionListItem;
}
declare class OAPDimChange {
    propChoiceList?: Array<number>;
    symbolicPropValues?: Array<string>;
    axis?: Axis;
    dimension: Dimension;
    propClass?: string;
    propName: string;
    propValue: number;
    minPropValue: number;
    maxPropValue: number;
    fixedValue: boolean;
    propDecDigits: number;
    multiplier: number;
    precision: number;
    changeSeparately: boolean;
    thirdDimension: boolean;
    static FromSoapArray(pSoapArray: any): Array<OAPDimChange> | undefined;
    static FromSoapNU(this: void, pSoapData: any): OAPDimChange;
}
declare class OAPInteractor {
    symbolOffset?: Vector3;
    actionIds?: Array<string>;
    symbols?: Array<OAPSymbolDisplay>;
    directActionIds?: Array<string>;
    directActions?: Array<OAPActionResult>;
    id: string;
    symbolType: OAPSymbolType;
    symbolSize: OAPSymbolSize;
    static FromSoapArrayNU(pSoapArray: any): Array<OAPInteractor>;
    static FromSoapNU(this: void, pSoapData: any): OAPInteractor;
}
declare class OAPObjectDefinition {
    arguments?: Array<string>;
    category: OAPObjectCategory;
    static FromSoapArray(pSoapArray: any): Array<OAPObjectDefinition> | undefined;
    static FromSoap(pSoapData: any): OAPObjectDefinition | undefined;
    static FromSoapNU(this: void, pSoapData: any): OAPObjectDefinition;
}
declare class OAPPropEditClass {
    propClass: string;
    visibleOnly: boolean;
    editableOnly: boolean;
    static FromSoapArray(pSoapArray: any): Array<OAPPropEditClass> | undefined;
    static FromSoapNU(this: void, pSoapData: any): OAPPropEditClass;
}
declare class OAPPropEditProp {
    propClass?: string;
    propName: string;
    visibleOnly: boolean;
    editableOnly: boolean;
    static FromSoapArray(pSoapArray: any): Array<OAPPropEditProp> | undefined;
    static FromSoapNU(this: void, pSoapData: any): OAPPropEditProp;
}
declare class OAPSymbolDisplay {
    symbolOffset: Vector3;
    direction?: Vector3;
    orientationX?: Vector3;
    viewAngle?: number;
    hiddenMode?: boolean;
    static FromSoapArray(pSoapArray: any): Array<OAPSymbolDisplay>;
    static FromSoapNU(this: void, pSoapData: any): OAPSymbolDisplay;
}
declare class OAPPlacement {
    static FromSoap(pSoapData: any): OAPPlacement | undefined;
}
declare class OAPDataDefinedPlacement extends OAPPlacement {
    referenceObject?: OAPObjectDefinition;
    attachPoint?: string;
}
declare class OAPAttachAreasPlacement extends OAPPlacement {
    referenceObject: OAPObjectDefinition;
    refObjectAttachAreaIds: Array<string>;
    newObjectAttachAreaId: string;
}
declare class OrderedTax {
    order: number;
    typeId: string;
    static FromSoapArray(pSoapArray: any): Array<OrderedTax> | undefined;
    static FromSoapNU(this: void, pSoapData: any): OrderedTax;
}
declare class PartCompositionFailure {
    itemId: string;
    cause?: Array<string>;
    static FromSoapArray(pSoapArray: any): Array<PartCompositionFailure> | undefined;
    static FromSoapNU(this: void, pSoapData: any): PartCompositionFailure;
}
declare class PasteContainerResult {
    items: Array<BasketItem>;
    itemGeometries: Array<string>;
    originalItemIds?: Array<string>;
    sceneGeometry: string;
    static FromSoap(pSoapData: any): PasteContainerResult | undefined;
}
declare class PriceInfo {
    unitSize: Quantity;
    netPrice?: Money;
    netValue?: Money;
    tax?: Money;
    extraPriceInfos?: Array<PriceInfoElement>;
    inactive: boolean;
    quantity: number;
    static FromSoap(pSoapData: any): PriceInfo | undefined;
}
declare class PriceInfoElement {
    value?: Value;
    selector: string;
    static FromSoapArray(pSoapArray: any): Array<PriceInfoElement> | undefined;
    static FromSoapNU(this: void, pSoapData: any): PriceInfoElement;
}
declare class PriceComponent {
    name: string;
    value: number;
    static FromSoapArray(pSoapArray: any): Array<PriceComponent> | undefined;
    static FromSoapNU(this: void, pSoapData: any): PriceComponent;
}
declare class PricingProcedure {
    displayName: string;
    lines: Array<PricingProcedureLine>;
    halfWayRoundingMode: HalfWayRoundingMode;
    name: string;
    static FromSoapNU(this: void, pSoapData: any): PricingProcedure;
}
declare class PricingProcedureDescription {
    displayName: string;
    name: string;
    static FromSoapArrayNU(pSoapArray: any): Array<PricingProcedureDescription>;
    static FromSoapNU(this: void, pSoapData: any): PricingProcedureDescription;
}
declare class PricingProcedureLine {
    description: string;
    tags?: Array<string>;
    conditionType: string;
    counter: number;
    from?: number;
    insertMode: LineInsertMode;
    level: number;
    lineType: LineType;
    maxOccurs: number;
    printControl: PrintControl;
    to?: number;
    static FromSoapArrayNU(pSoapArray: any): Array<PricingProcedureLine>;
    static FromSoapNU(this: void, pSoapData: any): PricingProcedureLine;
}
declare class Property {
    addValues: boolean;
    choiceList: boolean;
    decDigits: number;
    digits: number;
    editable: boolean;
    intervals?: Array<Interval>;
    propClass: string;
    propName: string;
    propText: string;
    type: PropertyType;
    value: PropertyValue;
    visible: boolean;
    width: number;
    multiLine?: boolean;
    static FromSoapArray(pSoapArray: any): Array<Property> | undefined;
    static FromSoapNU(this: void, pSoapData: any): Property;
}
declare class PropertyClass {
    description: string;
    name: string;
    static FromSoapArray(pSoapArray: any): Array<PropertyClass> | undefined;
    static FromSoapNU(this: void, pSoapData: any): PropertyClass;
}
declare class PropertyValue {
    largeIcon: string;
    smallIcon: string;
    surcharge?: Money;
    text: string;
    value: string;
    image?: string;
    selectable?: boolean;
    static FromSoapArray(pSoapArray: any): Array<PropertyValue> | undefined;
    static FromSoapArrayNU(pSoapArray: any): Array<PropertyValue>;
    static FromSoapNU(this: void, pSoapData: any): PropertyValue;
}
declare class SeriesInfo {
    seriesId: string;
    seriesName?: Array<DisplayText$1>;
    static FromSoapArray(pSoapArray: any): Array<SeriesInfo> | undefined;
    static FromSoapNU(this: void, pSoapData: any): SeriesInfo;
}
declare class TaxCategory {
    name: string;
    identifier: string;
    rate?: number;
    rateReadOnly: boolean;
    static FromSoapArray(pSoapArray: any): Array<TaxCategory> | undefined;
    static FromSoapNU(this: void, pSoapData: any): TaxCategory;
}
declare class TaxInfo {
    taxCategory: string;
    taxType: string;
    static FromSoapArrayNU(pSoapArray: any): Array<TaxInfo>;
    static FromSoapNU(this: void, pSoapData: any): TaxInfo;
}
declare class TaxScheme {
    variantName: string;
    taxTypes?: Array<TaxType>;
    orderedTaxes?: Array<OrderedTax>;
    country: string;
    currency: string;
    identifier: string;
    region: string;
    static FromSoapNU(this: void, pSoapData: any): TaxScheme;
}
declare class TaxType {
    abbreviation: string;
    name: string;
    taxCategories?: Array<TaxCategory>;
    identifier: string;
    rateUnit: string;
    static FromSoapArray(pSoapArray: any): Array<TaxType> | undefined;
    static FromSoapNU(this: void, pSoapData: any): TaxType;
}
declare class TaxSchemeDescription {
    variantName: string;
    country: string;
    identifier: string;
    region: string;
    static FromSoapArrayNU(pSoapArray: any): Array<TaxSchemeDescription>;
    static FromSoapNU(this: void, pSoapData: any): TaxSchemeDescription;
}
declare class TMColumnDef {
    displayName: string;
    columnId: TMColumnId;
    static FromSoapArrayNU(pSoapArray: any): Array<TMColumnDef>;
    static FromSoapNU(this: void, pSoapData: any): TMColumnDef;
}
declare class TMRow {
    texts: Array<TMText>;
    textId: string;
    readOnly: boolean;
    visible: boolean;
    static FromSoapArrayNU(pSoapArray: any): Array<TMRow>;
    static FromSoapArray(pSoapArray: any): Array<TMRow> | undefined;
    static FromSoapNU(this: void, pSoapData: any): TMRow;
}
declare class TMRowDef {
    displayName: string;
    type: TMTextType;
    textId: string;
    readOnly: boolean;
    defaultVisible: boolean;
    static FromSoapArrayNU(pSoapArray: any): Array<TMRowDef>;
    static FromSoapNU(this: void, pSoapData: any): TMRowDef;
}
declare class TMTable {
    columns: Array<TMColumnDef>;
    rows: Array<TMRowDef>;
    static FromSoap(pSoapData: any): TMTable | undefined;
}
declare class TMText {
    text: string;
    language?: string;
    static FromSoapArrayNU(pSoapArray: any): Array<TMText>;
    static FromSoapNU(this: void, pSoapData: any): TMText;
}
declare class UpdateBasketArticleResult {
    itemId: string;
    updateState: OFMLUpdateState;
    static FromSoapArrayNU(pSoapArray: any): Array<UpdateBasketArticleResult>;
    static FromSoapNU(this: void, pSoapData: any): UpdateBasketArticleResult;
}

declare class BasketService extends BaseEaiwsService {
    constructor(pOwner: EaiwsSession, pBaseUrl: string, pSessionId: string);
    addBasketColumns(pColumns?: ReadonlyArray<BasketColumn>): Promise<Array<BasketColumn>>;
    addBasketView(pTemplate: BasketViewConfig): Promise<BasketViewConfig | undefined>;
    addManualCondition(pItemIds: ReadonlyArray<string>, pPpName: string, pCondType: string, pOptions?: ItemSelectionOptions): Promise<number>;
    addPriceCalculation(pPpName: string): Promise<void>;
    addToSetArticle(pItemIds: ReadonlyArray<string>, pOpMode?: OperationMode): Promise<void>;
    adjustCalculationLineAmount(pItemIds: ReadonlyArray<string>, pPpName: string, pLevel: number, pCounter: number, pAmount: number, pCurrency: string, pOptions?: CondGroupSelectionOptions): Promise<void>;
    adjustCalculationLineValue(pItemIds: ReadonlyArray<string>, pPpName: string, pLevel: number, pCounter: number, pValue: number, pCurrency: string, pOptions?: CondGroupSelectionOptions): Promise<void>;
    adjustConditionValue(pItemIds: ReadonlyArray<string>, pPpName: string, pCondType: string, pCounter: number, pValue: number, pCurrency: string, pOptions?: CondGroupSelectionOptions): Promise<void>;
    breakUpSetArticle(pSetArtId: string): Promise<string>;
    changeAlternativePositionState(pItemIds: ReadonlyArray<string>, pPpName: string, pAltPos: boolean, pOptions?: ItemSelectionOptions, pOptional?: boolean): Promise<boolean>;
    changeBasketConfig(pBasketConfig: BasketConfig): Promise<void>;
    changeBasketViewConfig(pViewConfig: BasketViewConfig): Promise<void>;
    collapseSetArticles(pItemIds?: ReadonlyArray<string>): Promise<void>;
    convertToSetArticle(pFolderId: string, pOpMode?: OperationMode): Promise<string>;
    convertToUserArticles(pItemIds: ReadonlyArray<string>, pOptions?: ItemSelectionOptions): Promise<Array<string>>;
    copy(pItemIds: ReadonlyArray<string>, pOpMode?: OperationMode | null, pUri?: string | null, pOptions?: CopyOptions): Promise<string>;
    deleteItems(pItemIds: ReadonlyArray<string>, pOptions?: DeleteItemsOptions): Promise<void>;
    expandSetArticles(pItemIds?: ReadonlyArray<string>): Promise<void>;
    getAllChoiceLists(pItemId: string, pOptions?: GetChoiceListOptions): Promise<Array<ChoiceList>>;
    getAllItems(pItemIds?: ReadonlyArray<string>, pOptions?: GetAllItemsOptions): Promise<Array<BasketItem>>;
    getArticleData(pItemId: string, pOptions?: GetArticleDataOptions): Promise<ArticleData>;
    getArticleFeatures(pItemId: string, pOptions?: GetArticleFeaturesOptions): Promise<Array<ArticleFeature>>;
    getBasketAppData(pAppKey: string, pPaths: ReadonlyArray<string>): Promise<Array<string>>;
    getBasketColumns(pColumnIds?: ReadonlyArray<string>): Promise<Array<BasketColumn>>;
    getBasketConfig(): Promise<BasketConfig | undefined>;
    getBasketViewConfigs(pViewIds?: ReadonlyArray<string>): Promise<Array<BasketViewConfig>>;
    getChoiceList(pItemId: string, pPropClass: string, pPropName: string, pOptions?: GetChoiceListOptions): Promise<Array<PropertyValue>>;
    getConditionTypes(pActive: boolean, pPpName: string, pNames?: ReadonlyArray<string>): Promise<Array<ConditionType>>;
    getCurrency(): Promise<string>;
    getCurrentTaxScheme(): Promise<string>;
    getExchangeRates(pCurrencies?: ReadonlyArray<string>): Promise<Array<ExchangeRate>>;
    /**
     * @param pTimeout Deprecated - should no longer be used, use `SoapService.onGetRequestOptions` instead
     */
    getExportedGeometry(pItemId: string, pOptions: ReadonlyArray<string>, pTimeout?: number): Promise<string>;
    getGeneratedImage(pItemId: string, pOptions: ReadonlyArray<string>): Promise<string>;
    getImages(pItemId: string, pOptions?: GetImagesOptions): Promise<Array<ImageInfo>>;
    getItemAppData(pItemId: string, pAppKey: string, pPaths: ReadonlyArray<string>): Promise<Array<string | null>>;
    getItemFields(pItemIds?: ReadonlyArray<string>, pColumnIds?: ReadonlyArray<string>, pOptions?: GetItemFieldsOptions): Promise<Array<ItemField>>;
    getItemProperties(pItemIds?: ReadonlyArray<string>, pOptions?: GetItemPropertiesOptions): Promise<Array<ItemProperties>>;
    /**
     * Note: The server response will be cached to speed up further calls.
     */
    getLanguages(): Promise<Array<string>>;
    getManufacturerInfo(pItemIds?: ReadonlyArray<string> | null, pManuIds?: ReadonlyArray<string> | null, pSeriesIds?: ReadonlyArray<string> | null, pOptions?: GetManufacturerInfoOptions): Promise<Array<ManufacturerInfo>>;
    getPriceCalculationSheet(pItemIds: ReadonlyArray<string>, pPpName: string, pOptions?: GetPriceCalculationSheetOptions): Promise<CalculationSheet>;
    getPriceCalculationSheets(pItemIds: ReadonlyArray<string> | null | undefined, pPpName: string, pOptions?: GetPriceCalculationSheetOptions): Promise<Array<ItemCalculationSheet>>;
    getPricingProcedure(pActive: boolean, pName: string): Promise<PricingProcedure>;
    getReferenceCurrency(): Promise<string>;
    getTaxInformation(pItemId: string): Promise<Array<TaxInfo>>;
    getTaxScheme(pActive: boolean, pSchemeId: string): Promise<TaxScheme>;
    getTopFolderId(pViewId?: string): Promise<string>;
    insertFolder(pFatherId: string | null, pBeforeId: string | null, pName: string): Promise<string>;
    insertTextItem(pFatherId: string | null, pBeforeId: string | null, pText: string): Promise<string>;
    insertUserArticle(pFatherId: string | null, pBeforeId: string | null, pShortText: string): Promise<string>;
    insertOFMLArticle(pFatherId: string | null, pBeforeId: string | null, pInsertInfo: InsertInfo, pOptions?: InsertArticleOptions): Promise<string>;
    listPricingProcedures(pActive: boolean): Promise<Array<PricingProcedureDescription>>;
    listTaxSchemes(pActive: boolean, pCountry: string): Promise<Array<TaxSchemeDescription>>;
    mergeBasketArticles(pItemIds: ReadonlyArray<string>, pOptions?: ItemSelectionOptions): Promise<MergeResult>;
    moveItems(pItemIds: ReadonlyArray<string>, pDirection: MoveItemsDirection): Promise<MoveItemsResult>;
    oapGetActionData(pItemId: string, pActionId: string, pDpr?: number, pInteractor?: string): Promise<OAPAction | undefined>;
    oapGetInteractors(pItemId: string, pInteractorIds?: ReadonlyArray<string>, pDpr?: number): Promise<Array<OAPInteractor>>;
    oapProcessActions(pActionIds: ReadonlyArray<string>, pExec: boolean, pContext: OAPActionContext): Promise<Array<OAPActionResult>>;
    oapSetClientCapabilities(pCapabilities?: ReadonlyArray<OAPClientCapability>): Promise<void>;
    paste(pFatherId: string | null, pBeforeId: string | null, pUri: string, pOptions?: PasteOptions): Promise<Array<string>>;
    pasteContainer(pFatherId: string | null, pBeforeId: string | null, pUri: string, pOptions?: PasteContainerOptions): Promise<PasteContainerResult | undefined>;
    relocateItems(pFatherId: string | null, pBeforeId: string | null, pItemIds: ReadonlyArray<string>, pOptions?: RelocateItemsOptions): Promise<RelocateItemsResult>;
    removeBasketColumns(pColumnIds: ReadonlyArray<string>): Promise<void>;
    removeBasketViews(pViewIds: ReadonlyArray<string>): Promise<void>;
    removeCondition(pItemIds: ReadonlyArray<string>, pPpName: string, pCondType: string, pCounter: number, pOptions?: ItemSelectionOptions): Promise<boolean>;
    removeFromSetArticle(pItemIds: ReadonlyArray<string>, pOpMode?: OperationMode): Promise<void>;
    resetConditionAmount(pItemIds: ReadonlyArray<string>, pPpName: string, pCondType: string, pCounter: number, pOptions?: CondGroupSelectionOptions): Promise<void>;
    resetItemFields(pItemIds: ReadonlyArray<string>, pColumnId: string, pData?: string, pOptions?: ItemSelectionOptions): Promise<void>;
    resetQuantityRelation(pItemIds: ReadonlyArray<string>, pPpName: string, pCondType: string, pCounter: number, pOptions?: ItemSelectionOptions): Promise<void>;
    resetTaxConfiguration(): Promise<void>;
    resetTaxScheme(pSchemeId: string): Promise<void>;
    resetTaxRate(pSchemeId: string, pTypeId: string, pCategoryId: string): Promise<void>;
    selectCurrentTaxScheme(pSchemeId: string): Promise<void>;
    setBasketAppData(pAppKey: string, pData: ReadonlyArray<string>): Promise<void>;
    setBasketColumnProperties(pColumns?: ReadonlyArray<BasketColumn>): Promise<void>;
    setConditionAmount(pItemIds: ReadonlyArray<string>, pPpName: string, pCondType: string, pCounter: number, pAmount: number, pCurrency: string, pOptions?: CondGroupSelectionOptions): Promise<void>;
    setConditionDescription(pPpName: string, pCondType: string, pLang: string | null, pDescription: string): Promise<void>;
    setCurrency(pCurrency: string): Promise<void>;
    setExchangeRates(pExchangeRates: ReadonlyArray<ExchangeRate>, pReferenceCurrency?: string): Promise<void>;
    setItemAppData(pItemId: string, pAppKey: string, pData: ReadonlyArray<string>): Promise<void>;
    setItemConditionDescription(pItemIds: ReadonlyArray<string>, pPpName: string, pCondType: string, pCounter: number, pLang: string | null, pDescription: string, pOptions?: ItemSelectionOptions): Promise<void>;
    setItemFields(pFields: ReadonlyArray<ItemField>): Promise<void>;
    setItemProperties(pItemId: string, pProperties: ItemProperties): Promise<void>;
    setLanguages(pLanguages: ReadonlyArray<string>, pMode?: SetLanguagesMode): Promise<void>;
    setPropertyValue(pItemId: string, pPropClass: string, pPropName: string, pValue: string | null, pOptions?: SetPropertyValueOptions): Promise<string>;
    setQuantityRelation(pItemIds: ReadonlyArray<string>, pPpName: string, pCondType: string, pCounter: number, pQuantity: number, pUnit: string, pOptions?: ItemSelectionOptions): Promise<void>;
    setTaxInformation(pItemId: string, pTaxType: string, pTaxCategory: string): Promise<void>;
    setTaxRate(pSchemeId: string, pTypeId: string, pCategoryId: string, pRate: number): Promise<void>;
    splitUpCompositeArticles(pItemIds: ReadonlyArray<string>, pOptions?: ItemSelectionOptions): Promise<Array<string>>;
    startOFMLDebugging(pDebugModes: Array<string>, pTraceLevel: number, pDetailLevel: string, pOutputDevice?: string, pDebugClasses?: Array<string>): Promise<void>;
    stopOFMLDebugging(): Promise<void>;
    tmGetTable(pViewId: string | null, pItemId: string | null): Promise<TMTable | undefined>;
    tmGetText(pViewId: string | null, pItemId: string | null, pAllLanguages: boolean, pEnableLangTags?: boolean): Promise<Array<TMRow>>;
    tmSetText(pViewId: string | null, pItemId: string | null, pTextId: string, pLang: string, pText: string): Promise<void>;
    tmSetTextVisibility(pViewId: string | null, pItemId: string | null, pTextId: string, pVisible: boolean): Promise<void>;
    updateBasketArticles(pItemIds: ReadonlyArray<string>, pCatalogIds?: ReadonlyArray<string> | null, pOptions?: UpdateBasketArticlesOptions): Promise<Array<UpdateBasketArticleResult>>;
    protected getErrorDetail(pSoapData: any): SoapErrorDetail | undefined;
    private mLanguages;
}

type PricingProcedureLineTag = Uppercase<string> | "PURCHASE_CALC" | "PD_PURCHASE_PRICE" | "GROSS_PURCHASE_PRICE" | "PURCHASE_VALUE" | "PD_SALES_PRICE" | "GROSS_SALES_PRICE" | "ITEM_NET_VALUE" | "NET_VALUE" | "NET_VALUE_ECO" | "FINAL_VALUE" | "FINAL_VALUE_NO_DISCOUNTS" | "PURCHASE_DISCOUNT" | "PURCHASE_EXTRA_CHARGE" | "DISCOUNT" | "EXTRA_CHARGE" | "HEADER_DISCOUNT" | "HEADER_EXTRA_CHARGE" | "VAT" | "TAX" | "MARGIN_QTY" | "MARGIN_REL" | "INVISIBLE";
/**
 * Helper class for PricingProcedure handling.
 */
declare class PricingProcedureInfo {
    get name(): string;
    get procedure(): PricingProcedure;
    getConditionType(pConditionName: string): ConditionType | undefined;
    /**
     * Returns the PricingProcedureLine for the given line level and counter. If the line
     * doesn't exist and pFallbackToDefaultCounter is true, the default counter (0) will be used
     * as a fallback.
     */
    getProcedureLine(pLevel: number, pCounter: number, pFallbackToDefaultCounter?: boolean): PricingProcedureLine | undefined;
    /**
     * Returns the tags of a PricingProcedureLine as Set which is cached internally.
     */
    getLineTags(pLine: PricingProcedureLine): Set<PricingProcedureLineTag>;
    static CreateInfo(pSession: EaiwsSession, pPricingProcedureName: string, pUseActiveProcedure?: boolean): Promise<PricingProcedureInfo>;
    private mProcedure;
    private mTypes;
    private mLines;
    private mLineTags;
    private constructor();
}

/**
 * Helper class for CalculationSheet handling.
 */
declare class CalculationSheetInfo {
    get procedure(): PricingProcedureInfo;
    get sheet(): CalculationSheet;
    get purchasePrice(): Money | undefined;
    get unitPurchasePrice(): Money | undefined;
    get salesPrice(): Money | undefined;
    get unitSalesPrice(): Money | undefined;
    get itemNetPrice(): Money | undefined;
    get unitItemNetPrice(): Money | undefined;
    get netPrice(): Money | undefined;
    get unitNetPrice(): Money | undefined;
    get grossPrice(): Money | undefined;
    get unitGrossPrice(): Money | undefined;
    constructor(pProc: PricingProcedureInfo, pSheet: CalculationSheet);
    /**
     * Returns the tags of a CalculationLine as Set which is cached internally.
     */
    getLineTags(pLine: CalculationLine): Set<PricingProcedureLineTag>;
    private mProcedure;
    private mSheet;
    private mPurchasePrice;
    private mUnitPurchasePrice;
    private mSalesPrice;
    private mUnitSalesPrice;
    private mItemNetPrice;
    private mUnitItemNetPrice;
    private mNetPrice;
    private mUnitNetPrice;
    private mGrossPrice;
    private mUnitGrossPrice;
    private prepareInfo;
    private getUnitPrice;
}

type index_d$c_AddStateCode = AddStateCode;
declare const index_d$c_AddStateCode: typeof AddStateCode;
type index_d$c_ArticleClassification = ArticleClassification;
declare const index_d$c_ArticleClassification: typeof ArticleClassification;
type index_d$c_ArticleData = ArticleData;
declare const index_d$c_ArticleData: typeof ArticleData;
type index_d$c_ArticleDescription = ArticleDescription;
declare const index_d$c_ArticleDescription: typeof ArticleDescription;
type index_d$c_ArticleDescriptionMode = ArticleDescriptionMode;
type index_d$c_ArticleFeature = ArticleFeature;
declare const index_d$c_ArticleFeature: typeof ArticleFeature;
type index_d$c_ArticleProperties = ArticleProperties;
declare const index_d$c_ArticleProperties: typeof ArticleProperties;
type index_d$c_AttachmentMode = AttachmentMode;
type index_d$c_Axis = Axis;
type index_d$c_BasketColumn = BasketColumn;
declare const index_d$c_BasketColumn: typeof BasketColumn;
type index_d$c_BasketConfig = BasketConfig;
declare const index_d$c_BasketConfig: typeof BasketConfig;
type index_d$c_BasketItem = BasketItem;
declare const index_d$c_BasketItem: typeof BasketItem;
type index_d$c_BasketItemAttrId = BasketItemAttrId;
type index_d$c_BasketItemType = BasketItemType;
type index_d$c_BasketService = BasketService;
declare const index_d$c_BasketService: typeof BasketService;
type index_d$c_BasketServiceFault = BasketServiceFault;
declare const index_d$c_BasketServiceFault: typeof BasketServiceFault;
type index_d$c_BasketViewConfig = BasketViewConfig;
declare const index_d$c_BasketViewConfig: typeof BasketViewConfig;
type index_d$c_BasketViewSortConfig = BasketViewSortConfig;
declare const index_d$c_BasketViewSortConfig: typeof BasketViewSortConfig;
type index_d$c_CSArithmeticOperationError = CSArithmeticOperationError;
declare const index_d$c_CSArithmeticOperationError: typeof CSArithmeticOperationError;
type index_d$c_CSConformabilityError = CSConformabilityError;
declare const index_d$c_CSConformabilityError: typeof CSConformabilityError;
type index_d$c_CSCurrencyError = CSCurrencyError;
declare const index_d$c_CSCurrencyError: typeof CSCurrencyError;
type index_d$c_CSErrorCode = CSErrorCode;
type index_d$c_CSInvalidValueError = CSInvalidValueError;
declare const index_d$c_CSInvalidValueError: typeof CSInvalidValueError;
type index_d$c_CSItemDataAccessError = CSItemDataAccessError;
declare const index_d$c_CSItemDataAccessError: typeof CSItemDataAccessError;
type index_d$c_CSLineNotFoundError = CSLineNotFoundError;
declare const index_d$c_CSLineNotFoundError: typeof CSLineNotFoundError;
type index_d$c_CSOperationKind = CSOperationKind;
type index_d$c_CSUndefinedOperationError = CSUndefinedOperationError;
declare const index_d$c_CSUndefinedOperationError: typeof CSUndefinedOperationError;
type index_d$c_CSValidationError = CSValidationError;
declare const index_d$c_CSValidationError: typeof CSValidationError;
type index_d$c_CSValueKind = CSValueKind;
type index_d$c_CalculationLine = CalculationLine;
declare const index_d$c_CalculationLine: typeof CalculationLine;
type index_d$c_CalculationRule = CalculationRule;
type index_d$c_CalculationSheet = CalculationSheet;
declare const index_d$c_CalculationSheet: typeof CalculationSheet;
type index_d$c_CalculationSheetInfo = CalculationSheetInfo;
declare const index_d$c_CalculationSheetInfo: typeof CalculationSheetInfo;
type index_d$c_ChoiceList = ChoiceList;
declare const index_d$c_ChoiceList: typeof ChoiceList;
type index_d$c_CollatorDecomposition = CollatorDecomposition;
type index_d$c_CollatorStrength = CollatorStrength;
type index_d$c_ColumnSortOrder = ColumnSortOrder;
declare const index_d$c_ColumnSortOrder: typeof ColumnSortOrder;
type index_d$c_ColumnType = ColumnType;
type index_d$c_ColumnWidth = ColumnWidth;
declare const index_d$c_ColumnWidth: typeof ColumnWidth;
type index_d$c_ComposableGeometryProperties = ComposableGeometryProperties;
declare const index_d$c_ComposableGeometryProperties: typeof ComposableGeometryProperties;
type index_d$c_CondGroupSelectionOptions = CondGroupSelectionOptions;
declare const index_d$c_CondGroupSelectionOptions: typeof CondGroupSelectionOptions;
type index_d$c_ConditionClass = ConditionClass;
type index_d$c_ConditionEditMode = ConditionEditMode;
type index_d$c_ConditionSign = ConditionSign;
type index_d$c_ConditionType = ConditionType;
declare const index_d$c_ConditionType: typeof ConditionType;
type index_d$c_CopyOptions = CopyOptions;
declare const index_d$c_CopyOptions: typeof CopyOptions;
type index_d$c_DeleteItemsOptions = DeleteItemsOptions;
declare const index_d$c_DeleteItemsOptions: typeof DeleteItemsOptions;
type index_d$c_DescrType = DescrType;
type index_d$c_Dimension = Dimension;
type index_d$c_ExchangeRate = ExchangeRate;
declare const index_d$c_ExchangeRate: typeof ExchangeRate;
type index_d$c_FolderProperties = FolderProperties;
declare const index_d$c_FolderProperties: typeof FolderProperties;
type index_d$c_GetAllItemsOptions = GetAllItemsOptions;
declare const index_d$c_GetAllItemsOptions: typeof GetAllItemsOptions;
type index_d$c_GetArticleDataOptions = GetArticleDataOptions;
declare const index_d$c_GetArticleDataOptions: typeof GetArticleDataOptions;
type index_d$c_GetArticleFeaturesOptions = GetArticleFeaturesOptions;
declare const index_d$c_GetArticleFeaturesOptions: typeof GetArticleFeaturesOptions;
type index_d$c_GetChoiceListOptions = GetChoiceListOptions;
declare const index_d$c_GetChoiceListOptions: typeof GetChoiceListOptions;
type index_d$c_GetImagesOptions = GetImagesOptions;
declare const index_d$c_GetImagesOptions: typeof GetImagesOptions;
type index_d$c_GetItemFieldsOptions = GetItemFieldsOptions;
declare const index_d$c_GetItemFieldsOptions: typeof GetItemFieldsOptions;
type index_d$c_GetItemPropertiesOptions = GetItemPropertiesOptions;
declare const index_d$c_GetItemPropertiesOptions: typeof GetItemPropertiesOptions;
type index_d$c_GetItemPropertiesTextMode = GetItemPropertiesTextMode;
type index_d$c_GetManufacturerInfoOptions = GetManufacturerInfoOptions;
declare const index_d$c_GetManufacturerInfoOptions: typeof GetManufacturerInfoOptions;
type index_d$c_GetPriceCalculationSheetOptions = GetPriceCalculationSheetOptions;
declare const index_d$c_GetPriceCalculationSheetOptions: typeof GetPriceCalculationSheetOptions;
type index_d$c_HalfWayRoundingMode = HalfWayRoundingMode;
type index_d$c_ImageInfo = ImageInfo;
declare const index_d$c_ImageInfo: typeof ImageInfo;
type index_d$c_InactiveFlag = InactiveFlag;
type index_d$c_InactivePositionState = InactivePositionState;
declare const index_d$c_InactivePositionState: typeof InactivePositionState;
type index_d$c_InsertArticleOptions = InsertArticleOptions;
declare const index_d$c_InsertArticleOptions: typeof InsertArticleOptions;
type index_d$c_InsertInfo = InsertInfo;
declare const index_d$c_InsertInfo: typeof InsertInfo;
type index_d$c_Interval = Interval;
declare const index_d$c_Interval: typeof Interval;
type index_d$c_ItemCalculationSheet = ItemCalculationSheet;
declare const index_d$c_ItemCalculationSheet: typeof ItemCalculationSheet;
type index_d$c_ItemField = ItemField;
declare const index_d$c_ItemField: typeof ItemField;
type index_d$c_ItemProperties = ItemProperties;
declare const index_d$c_ItemProperties: typeof ItemProperties;
type index_d$c_ItemSelectionOptions = ItemSelectionOptions;
declare const index_d$c_ItemSelectionOptions: typeof ItemSelectionOptions;
type index_d$c_LineInsertMode = LineInsertMode;
type index_d$c_LineType = LineType;
type index_d$c_ManufacturerInfo = ManufacturerInfo;
declare const index_d$c_ManufacturerInfo: typeof ManufacturerInfo;
type index_d$c_MergeMode = MergeMode;
type index_d$c_MergeResult = MergeResult;
declare const index_d$c_MergeResult: typeof MergeResult;
type index_d$c_Money = Money;
declare const index_d$c_Money: typeof Money;
type index_d$c_MoveItemsDirection = MoveItemsDirection;
type index_d$c_MoveItemsResult = MoveItemsResult;
type index_d$c_OAPAction = OAPAction;
declare const index_d$c_OAPAction: typeof OAPAction;
type index_d$c_OAPActionChoiceAction = OAPActionChoiceAction;
declare const index_d$c_OAPActionChoiceAction: typeof OAPActionChoiceAction;
type index_d$c_OAPActionContext = OAPActionContext;
declare const index_d$c_OAPActionContext: typeof OAPActionContext;
type index_d$c_OAPActionListItem = OAPActionListItem;
declare const index_d$c_OAPActionListItem: typeof OAPActionListItem;
type index_d$c_OAPActionResult = OAPActionResult;
declare const index_d$c_OAPActionResult: typeof OAPActionResult;
type index_d$c_OAPActionState = OAPActionState;
type index_d$c_OAPArticleSpecMode = OAPArticleSpecMode;
type index_d$c_OAPAttachAreasPlacement = OAPAttachAreasPlacement;
declare const index_d$c_OAPAttachAreasPlacement: typeof OAPAttachAreasPlacement;
type index_d$c_OAPClientCapability = OAPClientCapability;
type index_d$c_OAPCreateObjectAction = OAPCreateObjectAction;
declare const index_d$c_OAPCreateObjectAction: typeof OAPCreateObjectAction;
type index_d$c_OAPDataDefinedPlacement = OAPDataDefinedPlacement;
declare const index_d$c_OAPDataDefinedPlacement: typeof OAPDataDefinedPlacement;
type index_d$c_OAPDeleteObjectAction = OAPDeleteObjectAction;
declare const index_d$c_OAPDeleteObjectAction: typeof OAPDeleteObjectAction;
type index_d$c_OAPDimChange = OAPDimChange;
declare const index_d$c_OAPDimChange: typeof OAPDimChange;
type index_d$c_OAPDimChange2Action = OAPDimChange2Action;
declare const index_d$c_OAPDimChange2Action: typeof OAPDimChange2Action;
type index_d$c_OAPDimChangeAction = OAPDimChangeAction;
declare const index_d$c_OAPDimChangeAction: typeof OAPDimChangeAction;
type index_d$c_OAPInteractor = OAPInteractor;
declare const index_d$c_OAPInteractor: typeof OAPInteractor;
type index_d$c_OAPMediaSource = OAPMediaSource;
type index_d$c_OAPMessageAction = OAPMessageAction;
declare const index_d$c_OAPMessageAction: typeof OAPMessageAction;
type index_d$c_OAPMethodCallAction = OAPMethodCallAction;
declare const index_d$c_OAPMethodCallAction: typeof OAPMethodCallAction;
type index_d$c_OAPMethodCallType = OAPMethodCallType;
type index_d$c_OAPObjectCategory = OAPObjectCategory;
type index_d$c_OAPObjectDefinition = OAPObjectDefinition;
declare const index_d$c_OAPObjectDefinition: typeof OAPObjectDefinition;
type index_d$c_OAPPlacement = OAPPlacement;
declare const index_d$c_OAPPlacement: typeof OAPPlacement;
type index_d$c_OAPPropChangeAction = OAPPropChangeAction;
declare const index_d$c_OAPPropChangeAction: typeof OAPPropChangeAction;
type index_d$c_OAPPropChangeType = OAPPropChangeType;
type index_d$c_OAPPropEdit2Action = OAPPropEdit2Action;
declare const index_d$c_OAPPropEdit2Action: typeof OAPPropEdit2Action;
type index_d$c_OAPPropEditAction = OAPPropEditAction;
declare const index_d$c_OAPPropEditAction: typeof OAPPropEditAction;
type index_d$c_OAPPropEditClass = OAPPropEditClass;
declare const index_d$c_OAPPropEditClass: typeof OAPPropEditClass;
type index_d$c_OAPPropEditProp = OAPPropEditProp;
declare const index_d$c_OAPPropEditProp: typeof OAPPropEditProp;
type index_d$c_OAPSelectObjectAction = OAPSelectObjectAction;
declare const index_d$c_OAPSelectObjectAction: typeof OAPSelectObjectAction;
type index_d$c_OAPShowMediaAction = OAPShowMediaAction;
declare const index_d$c_OAPShowMediaAction: typeof OAPShowMediaAction;
type index_d$c_OAPSymbolDisplay = OAPSymbolDisplay;
declare const index_d$c_OAPSymbolDisplay: typeof OAPSymbolDisplay;
type index_d$c_OAPSymbolSize = OAPSymbolSize;
type index_d$c_OAPSymbolType = OAPSymbolType;
type index_d$c_OAPTileSize = OAPTileSize;
type index_d$c_OAPViewType = OAPViewType;
type index_d$c_OBKVersionInfo = OBKVersionInfo;
declare const index_d$c_OBKVersionInfo: typeof OBKVersionInfo;
type index_d$c_OFMLUpdateState = OFMLUpdateState;
type index_d$c_OperationMode = OperationMode;
declare const index_d$c_OperationMode: typeof OperationMode;
type index_d$c_OrderedTax = OrderedTax;
declare const index_d$c_OrderedTax: typeof OrderedTax;
type index_d$c_PackagingInfo = PackagingInfo;
declare const index_d$c_PackagingInfo: typeof PackagingInfo;
type index_d$c_PartCompositionFailure = PartCompositionFailure;
declare const index_d$c_PartCompositionFailure: typeof PartCompositionFailure;
type index_d$c_PasteContainerOptions = PasteContainerOptions;
declare const index_d$c_PasteContainerOptions: typeof PasteContainerOptions;
type index_d$c_PasteContainerResult = PasteContainerResult;
declare const index_d$c_PasteContainerResult: typeof PasteContainerResult;
type index_d$c_PasteOptions = PasteOptions;
declare const index_d$c_PasteOptions: typeof PasteOptions;
type index_d$c_Percentage = Percentage;
declare const index_d$c_Percentage: typeof Percentage;
type index_d$c_PlanningDirection = PlanningDirection;
type index_d$c_PriceComponent = PriceComponent;
declare const index_d$c_PriceComponent: typeof PriceComponent;
type index_d$c_PriceInfo = PriceInfo;
declare const index_d$c_PriceInfo: typeof PriceInfo;
type index_d$c_PriceInfoElement = PriceInfoElement;
declare const index_d$c_PriceInfoElement: typeof PriceInfoElement;
type index_d$c_PricingProcedure = PricingProcedure;
declare const index_d$c_PricingProcedure: typeof PricingProcedure;
type index_d$c_PricingProcedureDescription = PricingProcedureDescription;
declare const index_d$c_PricingProcedureDescription: typeof PricingProcedureDescription;
type index_d$c_PricingProcedureInfo = PricingProcedureInfo;
declare const index_d$c_PricingProcedureInfo: typeof PricingProcedureInfo;
type index_d$c_PricingProcedureLine = PricingProcedureLine;
declare const index_d$c_PricingProcedureLine: typeof PricingProcedureLine;
type index_d$c_PricingProcedureLineTag = PricingProcedureLineTag;
type index_d$c_PrintControl = PrintControl;
type index_d$c_Property = Property;
declare const index_d$c_Property: typeof Property;
type index_d$c_PropertyClass = PropertyClass;
declare const index_d$c_PropertyClass: typeof PropertyClass;
type index_d$c_PropertyType = PropertyType;
type index_d$c_PropertyValue = PropertyValue;
declare const index_d$c_PropertyValue: typeof PropertyValue;
type index_d$c_Quantity = Quantity;
declare const index_d$c_Quantity: typeof Quantity;
type index_d$c_RelocateItemsOptions = RelocateItemsOptions;
declare const index_d$c_RelocateItemsOptions: typeof RelocateItemsOptions;
type index_d$c_RelocateItemsResult = RelocateItemsResult;
type index_d$c_Rotation = Rotation;
declare const index_d$c_Rotation: typeof Rotation;
type index_d$c_RoundingRule = RoundingRule;
type index_d$c_SeriesInfo = SeriesInfo;
declare const index_d$c_SeriesInfo: typeof SeriesInfo;
type index_d$c_SetArticleMode = SetArticleMode;
type index_d$c_SetArticleProperties = SetArticleProperties;
declare const index_d$c_SetArticleProperties: typeof SetArticleProperties;
type index_d$c_SetLanguagesMode = SetLanguagesMode;
type index_d$c_SetPropertyValueOptions = SetPropertyValueOptions;
declare const index_d$c_SetPropertyValueOptions: typeof SetPropertyValueOptions;
type index_d$c_SortGroup = SortGroup;
declare const index_d$c_SortGroup: typeof SortGroup;
type index_d$c_SortGroupSelector = SortGroupSelector;
declare const index_d$c_SortGroupSelector: typeof SortGroupSelector;
type index_d$c_SpatialPlanningDirection = SpatialPlanningDirection;
type index_d$c_TMColumnDef = TMColumnDef;
declare const index_d$c_TMColumnDef: typeof TMColumnDef;
type index_d$c_TMColumnId = TMColumnId;
type index_d$c_TMRow = TMRow;
declare const index_d$c_TMRow: typeof TMRow;
type index_d$c_TMRowDef = TMRowDef;
declare const index_d$c_TMRowDef: typeof TMRowDef;
type index_d$c_TMTable = TMTable;
declare const index_d$c_TMTable: typeof TMTable;
type index_d$c_TMText = TMText;
declare const index_d$c_TMText: typeof TMText;
type index_d$c_TMTextType = TMTextType;
type index_d$c_TaxCategory = TaxCategory;
declare const index_d$c_TaxCategory: typeof TaxCategory;
type index_d$c_TaxInfo = TaxInfo;
declare const index_d$c_TaxInfo: typeof TaxInfo;
type index_d$c_TaxScheme = TaxScheme;
declare const index_d$c_TaxScheme: typeof TaxScheme;
type index_d$c_TaxSchemeDescription = TaxSchemeDescription;
declare const index_d$c_TaxSchemeDescription: typeof TaxSchemeDescription;
type index_d$c_TaxType = TaxType;
declare const index_d$c_TaxType: typeof TaxType;
type index_d$c_TextItemProperties = TextItemProperties;
declare const index_d$c_TextItemProperties: typeof TextItemProperties;
type index_d$c_UpdateBasketArticleResult = UpdateBasketArticleResult;
declare const index_d$c_UpdateBasketArticleResult: typeof UpdateBasketArticleResult;
type index_d$c_UpdateBasketArticlesOptions = UpdateBasketArticlesOptions;
declare const index_d$c_UpdateBasketArticlesOptions: typeof UpdateBasketArticlesOptions;
type index_d$c_Value = Value;
declare const index_d$c_Value: typeof Value;
type index_d$c_Vector3 = Vector3;
declare const index_d$c_Vector3: typeof Vector3;
type index_d$c_ViewDisplayMode = ViewDisplayMode;
declare namespace index_d$c {
  export { index_d$c_AddStateCode as AddStateCode, index_d$c_ArticleClassification as ArticleClassification, index_d$c_ArticleData as ArticleData, index_d$c_ArticleDescription as ArticleDescription, type index_d$c_ArticleDescriptionMode as ArticleDescriptionMode, index_d$c_ArticleFeature as ArticleFeature, index_d$c_ArticleProperties as ArticleProperties, type index_d$c_AttachmentMode as AttachmentMode, type index_d$c_Axis as Axis, index_d$c_BasketColumn as BasketColumn, index_d$c_BasketConfig as BasketConfig, index_d$c_BasketItem as BasketItem, type index_d$c_BasketItemAttrId as BasketItemAttrId, type index_d$c_BasketItemType as BasketItemType, index_d$c_BasketService as BasketService, index_d$c_BasketServiceFault as BasketServiceFault, index_d$c_BasketViewConfig as BasketViewConfig, index_d$c_BasketViewSortConfig as BasketViewSortConfig, index_d$c_CSArithmeticOperationError as CSArithmeticOperationError, index_d$c_CSConformabilityError as CSConformabilityError, index_d$c_CSCurrencyError as CSCurrencyError, type index_d$c_CSErrorCode as CSErrorCode, index_d$c_CSInvalidValueError as CSInvalidValueError, index_d$c_CSItemDataAccessError as CSItemDataAccessError, index_d$c_CSLineNotFoundError as CSLineNotFoundError, type index_d$c_CSOperationKind as CSOperationKind, index_d$c_CSUndefinedOperationError as CSUndefinedOperationError, index_d$c_CSValidationError as CSValidationError, type index_d$c_CSValueKind as CSValueKind, index_d$c_CalculationLine as CalculationLine, type index_d$c_CalculationRule as CalculationRule, index_d$c_CalculationSheet as CalculationSheet, index_d$c_CalculationSheetInfo as CalculationSheetInfo, index_d$c_ChoiceList as ChoiceList, type index_d$c_CollatorDecomposition as CollatorDecomposition, type index_d$c_CollatorStrength as CollatorStrength, index_d$c_ColumnSortOrder as ColumnSortOrder, type index_d$c_ColumnType as ColumnType, index_d$c_ColumnWidth as ColumnWidth, index_d$c_ComposableGeometryProperties as ComposableGeometryProperties, index_d$c_CondGroupSelectionOptions as CondGroupSelectionOptions, type index_d$c_ConditionClass as ConditionClass, type index_d$c_ConditionEditMode as ConditionEditMode, type index_d$c_ConditionSign as ConditionSign, index_d$c_ConditionType as ConditionType, index_d$c_CopyOptions as CopyOptions, index_d$c_DeleteItemsOptions as DeleteItemsOptions, type index_d$c_DescrType as DescrType, type index_d$c_Dimension as Dimension, DisplayText$1 as DisplayText, index_d$c_ExchangeRate as ExchangeRate, index_d$c_FolderProperties as FolderProperties, index_d$c_GetAllItemsOptions as GetAllItemsOptions, index_d$c_GetArticleDataOptions as GetArticleDataOptions, index_d$c_GetArticleFeaturesOptions as GetArticleFeaturesOptions, index_d$c_GetChoiceListOptions as GetChoiceListOptions, index_d$c_GetImagesOptions as GetImagesOptions, index_d$c_GetItemFieldsOptions as GetItemFieldsOptions, index_d$c_GetItemPropertiesOptions as GetItemPropertiesOptions, type index_d$c_GetItemPropertiesTextMode as GetItemPropertiesTextMode, index_d$c_GetManufacturerInfoOptions as GetManufacturerInfoOptions, index_d$c_GetPriceCalculationSheetOptions as GetPriceCalculationSheetOptions, type index_d$c_HalfWayRoundingMode as HalfWayRoundingMode, index_d$c_ImageInfo as ImageInfo, type index_d$c_InactiveFlag as InactiveFlag, index_d$c_InactivePositionState as InactivePositionState, index_d$c_InsertArticleOptions as InsertArticleOptions, index_d$c_InsertInfo as InsertInfo, index_d$c_Interval as Interval, type IsoDateString$2 as IsoDateString, index_d$c_ItemCalculationSheet as ItemCalculationSheet, index_d$c_ItemField as ItemField, index_d$c_ItemProperties as ItemProperties, index_d$c_ItemSelectionOptions as ItemSelectionOptions, type index_d$c_LineInsertMode as LineInsertMode, type index_d$c_LineType as LineType, index_d$c_ManufacturerInfo as ManufacturerInfo, type index_d$c_MergeMode as MergeMode, index_d$c_MergeResult as MergeResult, index_d$c_Money as Money, type index_d$c_MoveItemsDirection as MoveItemsDirection, type index_d$c_MoveItemsResult as MoveItemsResult, index_d$c_OAPAction as OAPAction, index_d$c_OAPActionChoiceAction as OAPActionChoiceAction, index_d$c_OAPActionContext as OAPActionContext, index_d$c_OAPActionListItem as OAPActionListItem, index_d$c_OAPActionResult as OAPActionResult, type index_d$c_OAPActionState as OAPActionState, type index_d$c_OAPArticleSpecMode as OAPArticleSpecMode, index_d$c_OAPAttachAreasPlacement as OAPAttachAreasPlacement, type index_d$c_OAPClientCapability as OAPClientCapability, index_d$c_OAPCreateObjectAction as OAPCreateObjectAction, index_d$c_OAPDataDefinedPlacement as OAPDataDefinedPlacement, index_d$c_OAPDeleteObjectAction as OAPDeleteObjectAction, index_d$c_OAPDimChange as OAPDimChange, index_d$c_OAPDimChange2Action as OAPDimChange2Action, index_d$c_OAPDimChangeAction as OAPDimChangeAction, index_d$c_OAPInteractor as OAPInteractor, type index_d$c_OAPMediaSource as OAPMediaSource, index_d$c_OAPMessageAction as OAPMessageAction, index_d$c_OAPMethodCallAction as OAPMethodCallAction, type index_d$c_OAPMethodCallType as OAPMethodCallType, type index_d$c_OAPObjectCategory as OAPObjectCategory, index_d$c_OAPObjectDefinition as OAPObjectDefinition, index_d$c_OAPPlacement as OAPPlacement, index_d$c_OAPPropChangeAction as OAPPropChangeAction, type index_d$c_OAPPropChangeType as OAPPropChangeType, index_d$c_OAPPropEdit2Action as OAPPropEdit2Action, index_d$c_OAPPropEditAction as OAPPropEditAction, index_d$c_OAPPropEditClass as OAPPropEditClass, index_d$c_OAPPropEditProp as OAPPropEditProp, index_d$c_OAPSelectObjectAction as OAPSelectObjectAction, index_d$c_OAPShowMediaAction as OAPShowMediaAction, index_d$c_OAPSymbolDisplay as OAPSymbolDisplay, type index_d$c_OAPSymbolSize as OAPSymbolSize, type index_d$c_OAPSymbolType as OAPSymbolType, type index_d$c_OAPTileSize as OAPTileSize, type index_d$c_OAPViewType as OAPViewType, index_d$c_OBKVersionInfo as OBKVersionInfo, type index_d$c_OFMLUpdateState as OFMLUpdateState, index_d$c_OperationMode as OperationMode, index_d$c_OrderedTax as OrderedTax, index_d$c_PackagingInfo as PackagingInfo, index_d$c_PartCompositionFailure as PartCompositionFailure, index_d$c_PasteContainerOptions as PasteContainerOptions, index_d$c_PasteContainerResult as PasteContainerResult, index_d$c_PasteOptions as PasteOptions, index_d$c_Percentage as Percentage, type index_d$c_PlanningDirection as PlanningDirection, index_d$c_PriceComponent as PriceComponent, index_d$c_PriceInfo as PriceInfo, index_d$c_PriceInfoElement as PriceInfoElement, index_d$c_PricingProcedure as PricingProcedure, index_d$c_PricingProcedureDescription as PricingProcedureDescription, index_d$c_PricingProcedureInfo as PricingProcedureInfo, index_d$c_PricingProcedureLine as PricingProcedureLine, type index_d$c_PricingProcedureLineTag as PricingProcedureLineTag, type index_d$c_PrintControl as PrintControl, index_d$c_Property as Property, index_d$c_PropertyClass as PropertyClass, type index_d$c_PropertyType as PropertyType, index_d$c_PropertyValue as PropertyValue, index_d$c_Quantity as Quantity, index_d$c_RelocateItemsOptions as RelocateItemsOptions, type index_d$c_RelocateItemsResult as RelocateItemsResult, index_d$c_Rotation as Rotation, type index_d$c_RoundingRule as RoundingRule, index_d$c_SeriesInfo as SeriesInfo, type index_d$c_SetArticleMode as SetArticleMode, index_d$c_SetArticleProperties as SetArticleProperties, type index_d$c_SetLanguagesMode as SetLanguagesMode, index_d$c_SetPropertyValueOptions as SetPropertyValueOptions, index_d$c_SortGroup as SortGroup, index_d$c_SortGroupSelector as SortGroupSelector, type index_d$c_SpatialPlanningDirection as SpatialPlanningDirection, index_d$c_TMColumnDef as TMColumnDef, type index_d$c_TMColumnId as TMColumnId, index_d$c_TMRow as TMRow, index_d$c_TMRowDef as TMRowDef, index_d$c_TMTable as TMTable, index_d$c_TMText as TMText, type index_d$c_TMTextType as TMTextType, index_d$c_TaxCategory as TaxCategory, index_d$c_TaxInfo as TaxInfo, index_d$c_TaxScheme as TaxScheme, index_d$c_TaxSchemeDescription as TaxSchemeDescription, index_d$c_TaxType as TaxType, index_d$c_TextItemProperties as TextItemProperties, index_d$c_UpdateBasketArticleResult as UpdateBasketArticleResult, index_d$c_UpdateBasketArticlesOptions as UpdateBasketArticlesOptions, index_d$c_Value as Value, index_d$c_Vector3 as Vector3, type index_d$c_ViewDisplayMode as ViewDisplayMode };
}

type CatalogItemType = "Undefined" | "CatalogView" | "Folder" | "Article" | "Information" | "Graphics" | "MethodCall" | "MetaPlanning" | "Container";
type DisplayMode = "Undefined" | "All" | "Planning2D" | "Planning3D" | "Configuration" | "CAD" | "AllVisible" | "AllVisibleBasket";
type PackageType = "Unknown" | "Foundation" | "ProductWithCatalog" | "ProductWithoutCatalog" | "CatalogOnly" | "Extension" | "ACMaterial" | "User" | "AttributeSelection";
type PackageCategory = "Unknown" | "Furniture" | "Building";
type SearchFlag = "ViewItems" | "CatalogItems" | "WildcardsInFilter" | "FolderText";
type SeriesType = "Undefined" | "GOMeta";
type VarCodeType = "None" | "Manufacturer" | "OFML";
type IsoDateString$1 = string;
declare abstract class BasicSearchParameterSet extends SoapRequestData {
    catalogIds?: Array<string>;
    flags?: Array<SearchFlag>;
    views?: Array<string>;
    firstHitPosition?: number;
    numberOfHits?: number;
}
declare class DisplayText extends SoapRequestData {
    value: string;
    lang?: string;
    constructor();
    static FromSoapArray(pSoapArray: any): Array<DisplayText> | undefined;
    static FromSoapNU(this: void, pSoapData: any): DisplayText;
}
declare class GetPackageInfoOptions extends SoapRequestData {
    allData?: boolean;
    allLanguages?: boolean;
    useManufacturerConfig?: boolean;
    manufacturerId?: boolean;
    supplierId?: boolean;
    seriesIds?: boolean;
    releaseVersion?: boolean;
    releaseDate?: boolean;
    releaseState?: boolean;
    languages?: boolean;
    type?: boolean;
    category?: boolean;
    dependencies?: boolean;
    catalogs?: boolean;
    features?: boolean;
    seriesType?: boolean;
    priceProfileRegionId?: boolean;
    specialArticleScheme?: boolean;
    globalTradeItemNumber?: boolean;
    maskedCatalogs?: boolean;
    releaseText?: boolean;
    manufacturerName?: boolean;
    programName?: boolean;
    distributorName?: boolean;
    copyright?: boolean;
    description?: boolean;
}
declare class LookupOptions extends SoapRequestData {
    itemTypes?: Array<CatalogItemType>;
    languages?: Array<string>;
    textPurposes?: Array<string>;
    imagePurposes?: Array<string>;
    resourceTypes?: Array<string>;
    displayMode?: DisplayMode;
    descriptors?: boolean;
    subCategories?: boolean;
    synonyms?: boolean;
    resourceValues?: boolean;
    resourceURLs?: boolean;
}
declare class SearchArticleParameterSet extends BasicSearchParameterSet {
    brandId?: string;
    manufacturerId?: string;
    seriesId?: string;
    baseArticleNumber?: string;
    varCodeType?: VarCodeType;
    variantCode?: string;
}
declare class SearchParameterSet extends BasicSearchParameterSet {
    query: string;
    filter?: string;
    constructor();
}
declare class SearchResourceParameterSet extends BasicSearchParameterSet {
    value: string;
    catalogPackageId?: string;
    language?: string;
    resourceType?: string;
    constructor();
}
declare class CatalogItem {
    catalogId: string;
    catalogNodeKey: string;
    catalogPackageId: string;
    label: string;
    icon: string;
    name: string;
    type: CatalogItemType;
    resources?: Array<CatalogResource>;
    manufacturerIds?: Array<string>;
    images?: Array<CatalogImage>;
    static FromSoapArrayNU(pSoapArray: any): Array<CatalogItem>;
    static FromSoapNU(this: void, pSoapData: any): CatalogItem;
}
declare class ArticleCatalogItem extends CatalogItem {
    articlePackageId: string;
    baseArticleNumber: string;
    varCodeType: VarCodeType;
    variantCode: string;
}
declare class CatalogImage {
    purpose: string;
    language: string;
    highRes: boolean;
    width: number;
    height: number;
    name: string;
    url: string;
    static FromSoapArray(pSoapArray: any): Array<CatalogImage> | undefined;
    static FromSoapNU(this: void, pSoapData: any): CatalogImage;
}
declare class CatalogResource {
    language: string;
    type: string;
    value?: string;
    url?: string;
    static FromSoapArray(pSoapArray: any): Array<CatalogResource> | undefined;
    static FromSoapNU(this: void, pSoapData: any): CatalogResource;
}
declare class MaskedCatalog {
    moduleKey: string;
    version?: string;
    static FromSoapArray(pSoapArray: any): Array<MaskedCatalog> | undefined;
    static FromSoapNU(this: void, pSoapData: any): MaskedCatalog;
}
declare class PackageInfo {
    manufacturerId?: string;
    supplierId?: string;
    seriesIds?: Array<string>;
    releaseVersion?: string;
    releaseDate?: IsoDateString$1;
    releaseState?: string;
    languages?: Array<string>;
    type?: PackageType;
    category?: PackageCategory;
    dependencies?: Array<PackageDependency>;
    catalogs?: Array<string>;
    features?: Array<string>;
    seriesType?: SeriesType;
    priceProfileRegionId?: string;
    specialArticleScheme?: string;
    globalTradeItemNumber?: string;
    maskedCatalogs?: Array<MaskedCatalog>;
    releaseText?: Array<DisplayText>;
    manufacturerName?: Array<DisplayText>;
    programName?: Array<DisplayText>;
    distributorName?: Array<DisplayText>;
    copyright?: Array<DisplayText>;
    description?: Array<DisplayText>;
    packageId: string;
    static FromSoapArrayNU(pSoapArray: any): Array<PackageInfo>;
    static FromSoapNU(this: void, pSoapData: any): PackageInfo;
}
declare class PackageDependency {
    packageId: string;
    version: string;
    static FromSoapArray(pSoapArray: any): Array<PackageDependency> | undefined;
    static FromSoapNU(this: void, pSoapData: any): PackageDependency;
}
declare class ScoredCatalogItem {
    item: CatalogItem;
    score: number;
    static FromSoapArrayNU(pSoapArray: any): Array<ScoredCatalogItem>;
    static FromSoapNU(this: void, pSoapData: any): ScoredCatalogItem;
}
declare class TopCatalogItems {
    scoredItems: Array<ScoredCatalogItem>;
    totalHits: number;
    static FromSoap(pSoapData: any): TopCatalogItems | undefined;
}

declare class CatalogService extends BaseEaiwsService {
    constructor(pOwner: EaiwsSession, pBaseUrl: string, pSessionId: string);
    getCatalogItem(pPath: ReadonlyArray<string>, pOptions?: LookupOptions): Promise<CatalogItem>;
    getCatalogPath(pCatalogId: string, pCatNodeKey: string): Promise<Array<string>>;
    /**
     * Note: The server response will be cached to speed up further calls.
     */
    getLanguages(): Promise<Array<string>>;
    getPackageInfo(pManuIds?: Array<string> | null, pPackageIds?: Array<string> | null, pOptions?: GetPackageInfoOptions): Promise<Array<PackageInfo>>;
    listCatalogItems(pPath: ReadonlyArray<string>, pOptions?: LookupOptions): Promise<Array<CatalogItem>>;
    searchArticle(pSearch: SearchArticleParameterSet, pOptions?: LookupOptions): Promise<TopCatalogItems | undefined>;
    searchCatalogItems(pSearch: SearchParameterSet, pOptions?: LookupOptions): Promise<TopCatalogItems | undefined>;
    searchResource(pSearch: SearchResourceParameterSet, pOptions?: LookupOptions): Promise<TopCatalogItems | undefined>;
    setLanguages(pLanguages: ReadonlyArray<string>): Promise<void>;
    private mLanguages;
}

type index_d$b_ArticleCatalogItem = ArticleCatalogItem;
declare const index_d$b_ArticleCatalogItem: typeof ArticleCatalogItem;
type index_d$b_BasicSearchParameterSet = BasicSearchParameterSet;
declare const index_d$b_BasicSearchParameterSet: typeof BasicSearchParameterSet;
type index_d$b_CatalogImage = CatalogImage;
declare const index_d$b_CatalogImage: typeof CatalogImage;
type index_d$b_CatalogItem = CatalogItem;
declare const index_d$b_CatalogItem: typeof CatalogItem;
type index_d$b_CatalogItemType = CatalogItemType;
type index_d$b_CatalogResource = CatalogResource;
declare const index_d$b_CatalogResource: typeof CatalogResource;
type index_d$b_CatalogService = CatalogService;
declare const index_d$b_CatalogService: typeof CatalogService;
type index_d$b_DisplayMode = DisplayMode;
type index_d$b_DisplayText = DisplayText;
declare const index_d$b_DisplayText: typeof DisplayText;
type index_d$b_GetPackageInfoOptions = GetPackageInfoOptions;
declare const index_d$b_GetPackageInfoOptions: typeof GetPackageInfoOptions;
type index_d$b_LookupOptions = LookupOptions;
declare const index_d$b_LookupOptions: typeof LookupOptions;
type index_d$b_MaskedCatalog = MaskedCatalog;
declare const index_d$b_MaskedCatalog: typeof MaskedCatalog;
type index_d$b_PackageCategory = PackageCategory;
type index_d$b_PackageDependency = PackageDependency;
declare const index_d$b_PackageDependency: typeof PackageDependency;
type index_d$b_PackageInfo = PackageInfo;
declare const index_d$b_PackageInfo: typeof PackageInfo;
type index_d$b_PackageType = PackageType;
type index_d$b_ScoredCatalogItem = ScoredCatalogItem;
declare const index_d$b_ScoredCatalogItem: typeof ScoredCatalogItem;
type index_d$b_SearchArticleParameterSet = SearchArticleParameterSet;
declare const index_d$b_SearchArticleParameterSet: typeof SearchArticleParameterSet;
type index_d$b_SearchFlag = SearchFlag;
type index_d$b_SearchParameterSet = SearchParameterSet;
declare const index_d$b_SearchParameterSet: typeof SearchParameterSet;
type index_d$b_SearchResourceParameterSet = SearchResourceParameterSet;
declare const index_d$b_SearchResourceParameterSet: typeof SearchResourceParameterSet;
type index_d$b_SeriesType = SeriesType;
type index_d$b_TopCatalogItems = TopCatalogItems;
declare const index_d$b_TopCatalogItems: typeof TopCatalogItems;
type index_d$b_VarCodeType = VarCodeType;
declare namespace index_d$b {
  export { index_d$b_ArticleCatalogItem as ArticleCatalogItem, index_d$b_BasicSearchParameterSet as BasicSearchParameterSet, index_d$b_CatalogImage as CatalogImage, index_d$b_CatalogItem as CatalogItem, type index_d$b_CatalogItemType as CatalogItemType, index_d$b_CatalogResource as CatalogResource, index_d$b_CatalogService as CatalogService, type index_d$b_DisplayMode as DisplayMode, index_d$b_DisplayText as DisplayText, index_d$b_GetPackageInfoOptions as GetPackageInfoOptions, type IsoDateString$1 as IsoDateString, index_d$b_LookupOptions as LookupOptions, index_d$b_MaskedCatalog as MaskedCatalog, type index_d$b_PackageCategory as PackageCategory, index_d$b_PackageDependency as PackageDependency, index_d$b_PackageInfo as PackageInfo, type index_d$b_PackageType as PackageType, index_d$b_ScoredCatalogItem as ScoredCatalogItem, index_d$b_SearchArticleParameterSet as SearchArticleParameterSet, type index_d$b_SearchFlag as SearchFlag, index_d$b_SearchParameterSet as SearchParameterSet, index_d$b_SearchResourceParameterSet as SearchResourceParameterSet, type index_d$b_SeriesType as SeriesType, index_d$b_TopCatalogItems as TopCatalogItems, type index_d$b_VarCodeType as VarCodeType };
}

type AddressType = "SoldTo" | "ShipTo" | "BillTo" | "Payer" | "Carrier" | "Supplier" | "EndUser" | "InstallationCompany" | "InstallationLocation" | "Branch" | "InCharge";
type AuthMessageType = "SCRAM_SHA_256_first" | "SCRAM_SHA_256_final";
type CommAddrType = "Phone" | "Fax" | "Mobile" | "WWW" | "EMail";
type ContactType = "Sale" | "Warehouse" | "Installer" | "Support" | "Employee" | "Client";
type LockingMode = "Default" | "NoLock" | "TryLock" | "Lock" | "ForceLock";
type ScopeInfo = "Business" | "Private";
type ProjectAttribute = "CreateTime" | "LastModifiedTime" | "ProjectState" | "ProjectName" | "ProjectNumber" | "Description" | "ExternalReferenceNumber" | "ExternalReferenceText" | "CustomerNumber" | "ExternalCustomerId" | "CustomerRelatedRemarks" | "Company" | "GeneralAgreementNumber" | "Keywords" | "ProjectDate" | "ValidToDate" | "CreatedBy" | "LastModifiedBy" | "AddressNumber" | "AddressId" | "Title" | "Name1" | "Name2" | "Name3" | "Name4" | "Street" | "Street2" | "CountryCode" | "PostalCode" | "Location" | "District" | "RegionCode" | "PoBox" | "TaxCode" | "TaxCodeEU" | "TaxCodeUSA" | "ContactNumber" | "ContactTitle" | "ContactFirstName" | "ContactLastName";
type ProjectFilterOperator = "IsDefined" | "IsUndefined" | "And" | "Or" | "Not" | "Equal" | "NotEqual" | "Distinct" | "NotDistinct" | "Less" | "LessEqual" | "Greater" | "GreaterEqual" | "Between" | "NotBetween" | "Like" | "NotLike";
type ProjectState = "Undefined" | "InProgress" | "Offered" | "Ordered" | "NotCommissioned" | "ApprovalRequired" | "WaitingForApproval" | "ApprovalDenied" | "Approved";
type ProjectTextType = "HeaderText" | "FooterText";
type TextFormat = "None" | "IML" | "XML" | "JSON" | "HTML";
type IsoDateString = string;
type IsoDateTimeString = string;
type IsoDurationString = string;
declare class AddressData extends SoapRequestData {
    addressNumber?: string;
    addressId?: string;
    title?: string;
    name1?: string;
    name2?: string;
    name3?: string;
    name4?: string;
    street?: string;
    street2?: string;
    countryCode?: string;
    postalCode?: string;
    location?: string;
    district?: string;
    regionCode?: string;
    poBox?: string;
    taxCode?: string;
    taxCodeEU?: string;
    taxCodeUSA?: string;
    commAddresses?: Array<CommAddress>;
    contacts?: Array<ContactData>;
    addressType: AddressType;
    constructor();
    /** Serialize to xml string. */
    static Serialize(pAddress: AddressData): string | null;
    /** Deserialize xml string. */
    static Deserialize(pData: string, pResetContactIds?: boolean): AddressData | null;
    static FromSoapArray(pSoapArray: any): Array<AddressData> | undefined;
    static FromSoapArrayNU(pSoapArray: any): Array<AddressData>;
    static FromSoapNU(this: void, pSoapData: any): AddressData;
    static FromSoap(pSoapData: any): AddressData | undefined;
}
declare class AutoSaveOptions extends SoapRequestData {
    onSessionClose?: boolean;
    onProjectClose?: boolean;
    periodical?: boolean;
    interval?: IsoDurationString;
    idleTime?: IsoDurationString;
    static FromSoap(pSoapData: any): AutoSaveOptions | undefined;
}
declare class CommAddress extends SoapRequestData {
    value: string;
    type: CommAddrType;
    scope: ScopeInfo;
    constructor();
    static FromSoapArrayNU(pSoapArray: any): Array<CommAddress>;
    static FromSoapNU(this: void, pSoapData: any): CommAddress;
}
declare class ContactData extends SoapRequestData {
    contactNumber?: string;
    title?: string;
    firstName?: string;
    lastName?: string;
    commAddresses?: Array<CommAddress>;
    id: number;
    contactType?: ContactType;
    constructor();
    static FromSoapArrayNU(pSoapArray: any): Array<ContactData>;
    static FromSoapNU(this: void, pSoapData: any): ContactData;
}
declare class DeleteProjectsOptions extends SoapRequestData {
    ignoreVersionNumbers?: boolean;
    failIfNonExistent?: boolean;
    failIfPermissionDenied?: boolean;
    failIfNotLockable?: boolean;
    ignoreLocks?: boolean;
}
declare class DisplayName extends SoapRequestData {
    value: string;
    language: string;
    constructor();
    static FromSoapArrayNU(pSoapArray: any): Array<DisplayName>;
    static FromSoapNU(this: void, pSoapData: any): DisplayName;
}
declare class FormattedText extends SoapRequestData {
    value: string;
    language: string;
    format: TextFormat;
    constructor();
    static FromSoapArray(pSoapArray: any): Array<FormattedText> | undefined;
    static FromSoapNU(this: void, pSoapData: any): FormattedText;
}
declare class ListCompletionsOptions extends SoapRequestData {
    prefix: string;
    projectGroupPattern?: string;
    addressType?: AddressType;
    contactType?: ContactType;
    limit?: number;
    filterAttribute?: ProjectAttribute;
    ignoreCase?: boolean;
    constructor();
}
declare class ListProjectsOptions extends SoapRequestData {
    projectURI?: string;
    searchExpression?: string;
    filter?: ProjectFilter;
    orderBy?: Array<ProjectSortSpec>;
    resultAddressTypes?: Array<AddressType>;
    projectGroupPattern?: string;
    addressType?: AddressType;
    contactType?: ContactType;
    offset?: number;
    limit?: number;
}
declare class Permission extends SoapRequestData {
    userRole?: string;
    create?: boolean;
    read?: boolean;
    write?: boolean;
    delete?: boolean;
    list?: boolean;
    static FromSoapArrayNU(pSoapArray: any): Array<Permission>;
    static FromSoapNU(this: void, pSoapData: any): Permission;
    static FromSoap(pSoapData: any): Permission | undefined;
}
declare class PriceList extends SoapRequestData {
    userRoles?: Array<string>;
    displayNames?: Array<DisplayName>;
    id: string;
    startup?: string;
    availableToCurrentUser?: boolean;
    constructor();
    static FromSoapArrayNU(pSoapArray: any): Array<PriceList>;
    static FromSoapNU(this: void, pSoapData: any): PriceList;
}
declare class ProjectData$1 extends SoapRequestData {
    uri?: string;
    projectName?: string;
    projectNumber?: string;
    description?: string;
    externalReferenceNumber?: string;
    externalReferenceText?: string;
    customerNumber?: string;
    externalCustomerId?: string;
    customerRelatedRemarks?: string;
    company?: string;
    generalAgreementNumber?: string;
    keywords?: Array<string>;
    addresses?: Array<AddressData>;
    languages?: Array<string>;
    projectTexts?: Array<ProjectText>;
    projectGroup?: string;
    projectId?: string;
    projectVersion?: number;
    priceList?: string;
    projectState?: ProjectState;
    created?: IsoDateTimeString;
    lastModified?: IsoDateTimeString;
    projectDate?: IsoDateString;
    validToDate?: IsoDateString;
    createdByUser?: string;
    modifiedByUser?: string;
    changed?: boolean;
    locked?: boolean;
    lockHolder?: string;
    lockTime?: IsoDateTimeString;
    projectNumberEditable?: boolean;
    static FromSoapArrayNU(pSoapArray: any): Array<ProjectData$1>;
    static FromSoapNU(this: void, pSoapData: any): ProjectData$1;
    static FromSoap(pSoapData: any): ProjectData$1 | undefined;
}
declare abstract class ProjectFilterNode extends SoapRequestData {
}
declare class ProjectFilter extends ProjectFilterNode {
    arguments: Array<ProjectFilterNode>;
    operator: ProjectFilterOperator;
    ignoreCase?: boolean;
    constructor();
}
declare class ProjectFilterAttribute extends ProjectFilterNode {
    attribute: ProjectAttribute;
    constructor();
}
declare abstract class ProjectFilterValue extends ProjectFilterNode {
}
declare class ProjectFilterStringValue extends ProjectFilterValue {
    value: string;
    constructor();
}
declare class ProjectFilterDateTimeValue extends ProjectFilterValue {
    value: IsoDateTimeString;
    constructor();
}
declare class ProjectFilterDateValue extends ProjectFilterValue {
    date: IsoDateString;
    constructor();
}
declare class ProjectFilterStateValue extends ProjectFilterValue {
    value: ProjectState;
    constructor();
}
declare class ProjectGroup extends SoapRequestData {
    numberScheme?: ProjectNumberScheme;
    priceLists?: Array<PriceList>;
    permissions?: Array<Permission>;
    simpleNames?: Array<DisplayName>;
    fullNames?: Array<DisplayName>;
    subgroupTitles?: Array<DisplayName>;
    currentUserPermissions?: Permission;
    id: string;
    folder?: boolean;
    constructor();
    static FromSoapArrayNU(pSoapArray: any): Array<ProjectGroup>;
    static FromSoapNU(this: void, pSoapData: any): ProjectGroup;
}
declare class ProjectNumberScheme extends SoapRequestData {
    id: string;
    pattern?: string;
    minimumValue?: number;
    maximumValue?: number;
    nextValue?: number;
    currentYear?: number;
    zoneId?: string;
    constructor();
    static FromSoapArrayNU(pSoapArray: any): Array<ProjectNumberScheme>;
    static FromSoap(pSoapData: any): ProjectNumberScheme | undefined;
    static FromSoapNU(this: void, pSoapData: any): ProjectNumberScheme;
}
declare class ProjectSortSpec extends SoapRequestData {
    attribute: ProjectAttribute;
    ascending?: boolean;
    undefFirst?: boolean;
    ignoreCase?: boolean;
    constructor();
}
declare class ProjectText extends SoapRequestData {
    texts?: Array<FormattedText>;
    type: ProjectTextType;
    constructor();
    static FromSoapArrayNU(pSoapArray: any): Array<ProjectText>;
    static FromSoapNU(this: void, pSoapData: any): ProjectText;
}
declare class SaveProjectOptions extends SoapRequestData {
    projectGroup?: string;
    priceList?: string;
    noVersionCheck?: boolean;
    autoDelete?: boolean;
}
declare class CountryData {
    displayName: string;
    iso3166Code: string;
    static FromSoapArrayNU(pSoapArray: any): Array<CountryData>;
    static FromSoapNU(this: void, pSoapData: any): CountryData;
}
declare class SubdivisionData {
    iso3166names: Array<string>;
    localVariants?: Array<string>;
    languageCodes: Array<string>;
    displayName: string;
    category: string;
    iso3166Code: string;
    regionCode: string;
    parentSubdivision?: string;
    static FromSoapArrayNU(pSoapArray: any): Array<SubdivisionData>;
    static FromSoapNU(this: void, pSoapData: any): SubdivisionData;
}

declare class ProjectService extends BaseEaiwsService {
    constructor(pOwner: EaiwsSession, pBaseUrl: string, pSessionId: string);
    addPriceList(pId: string, pStartup: string, pDisplayName: string): Promise<void>;
    addProjectGroup(pId: string, pFolder: boolean, pSimpleName: string, pSubgroupTitle?: string): Promise<void>;
    addProjectNumberScheme(pId: string, pPattern: string, pMinValue?: number, pMaxValue?: number): Promise<void>;
    authenticateUser(pMessageType: AuthMessageType, pMessage?: string): Promise<string | undefined>;
    deleteProjects(pUris: Array<string>, pOptions?: DeleteProjectsOptions): Promise<Array<string>>;
    getAddressData(pAddressTypes?: Array<AddressType>): Promise<Array<AddressData>>;
    getContactData(): Promise<Array<ContactData>>;
    getCountries(): Promise<Array<CountryData>>;
    getCountrySubdivisions(pCountryCode: string): Promise<Array<SubdivisionData>>;
    getPriceLists(pIdPattern: string): Promise<Array<PriceList>>;
    getProjectData(pTextFormat?: TextFormat): Promise<ProjectData$1 | undefined>;
    getProjectGroups(pIdPattern: string): Promise<Array<ProjectGroup>>;
    getProjectNumberSchemes(pIdPattern: string): Promise<Array<ProjectNumberScheme>>;
    getProjectTexts(pTextFormat: TextFormat, pTextTypes?: Array<ProjectTextType>): Promise<Array<ProjectText>>;
    listCompletions(pOptions?: ListCompletionsOptions): Promise<Array<string>>;
    listProjects(pOptions?: ListProjectsOptions): Promise<Array<ProjectData$1>>;
    loadProject(pUri: string, pLockMode?: LockingMode): Promise<void>;
    newProject(pProjectGroup: string, pPriceList?: string): Promise<void>;
    removeAddressData(pAddressTypes: Array<AddressType>): Promise<Array<AddressType>>;
    removeContactData(pAddressType?: AddressType, pContactIds?: Array<number>): Promise<Array<number>>;
    removePriceList(pId: string): Promise<void>;
    removeProjectGroup(pId: string): Promise<void>;
    removeProjectNumberScheme(pId: string): Promise<void>;
    saveProject(pOptions?: SaveProjectOptions): Promise<string>;
    setAddressData(pAddress: AddressData): Promise<void>;
    setAutoSaveOptions(pOptions?: AutoSaveOptions): Promise<AutoSaveOptions | undefined>;
    setContactData(pContact: ContactData): Promise<void>;
    setProjectData(pData: ProjectData$1): Promise<void>;
    setProjectText(pText: ProjectText, pUpdate: boolean): Promise<void>;
    updatePriceList(pPriceList: PriceList): Promise<void>;
    updateProjectGroup(pProjectGroup: ProjectGroup): Promise<void>;
    updateProjectLock(pLockMode: LockingMode): Promise<boolean>;
    updateProjectNumberScheme(pNumberScheme: ProjectNumberScheme): Promise<void>;
}

type index_d$a_AddressData = AddressData;
declare const index_d$a_AddressData: typeof AddressData;
type index_d$a_AddressType = AddressType;
type index_d$a_AuthMessageType = AuthMessageType;
type index_d$a_AutoSaveOptions = AutoSaveOptions;
declare const index_d$a_AutoSaveOptions: typeof AutoSaveOptions;
type index_d$a_CommAddrType = CommAddrType;
type index_d$a_CommAddress = CommAddress;
declare const index_d$a_CommAddress: typeof CommAddress;
type index_d$a_ContactData = ContactData;
declare const index_d$a_ContactData: typeof ContactData;
type index_d$a_ContactType = ContactType;
type index_d$a_CountryData = CountryData;
declare const index_d$a_CountryData: typeof CountryData;
type index_d$a_DeleteProjectsOptions = DeleteProjectsOptions;
declare const index_d$a_DeleteProjectsOptions: typeof DeleteProjectsOptions;
type index_d$a_DisplayName = DisplayName;
declare const index_d$a_DisplayName: typeof DisplayName;
type index_d$a_FormattedText = FormattedText;
declare const index_d$a_FormattedText: typeof FormattedText;
type index_d$a_IsoDateString = IsoDateString;
type index_d$a_IsoDateTimeString = IsoDateTimeString;
type index_d$a_IsoDurationString = IsoDurationString;
type index_d$a_ListCompletionsOptions = ListCompletionsOptions;
declare const index_d$a_ListCompletionsOptions: typeof ListCompletionsOptions;
type index_d$a_ListProjectsOptions = ListProjectsOptions;
declare const index_d$a_ListProjectsOptions: typeof ListProjectsOptions;
type index_d$a_LockingMode = LockingMode;
type index_d$a_Permission = Permission;
declare const index_d$a_Permission: typeof Permission;
type index_d$a_PriceList = PriceList;
declare const index_d$a_PriceList: typeof PriceList;
type index_d$a_ProjectAttribute = ProjectAttribute;
type index_d$a_ProjectFilter = ProjectFilter;
declare const index_d$a_ProjectFilter: typeof ProjectFilter;
type index_d$a_ProjectFilterAttribute = ProjectFilterAttribute;
declare const index_d$a_ProjectFilterAttribute: typeof ProjectFilterAttribute;
type index_d$a_ProjectFilterDateTimeValue = ProjectFilterDateTimeValue;
declare const index_d$a_ProjectFilterDateTimeValue: typeof ProjectFilterDateTimeValue;
type index_d$a_ProjectFilterDateValue = ProjectFilterDateValue;
declare const index_d$a_ProjectFilterDateValue: typeof ProjectFilterDateValue;
type index_d$a_ProjectFilterNode = ProjectFilterNode;
declare const index_d$a_ProjectFilterNode: typeof ProjectFilterNode;
type index_d$a_ProjectFilterOperator = ProjectFilterOperator;
type index_d$a_ProjectFilterStateValue = ProjectFilterStateValue;
declare const index_d$a_ProjectFilterStateValue: typeof ProjectFilterStateValue;
type index_d$a_ProjectFilterStringValue = ProjectFilterStringValue;
declare const index_d$a_ProjectFilterStringValue: typeof ProjectFilterStringValue;
type index_d$a_ProjectFilterValue = ProjectFilterValue;
declare const index_d$a_ProjectFilterValue: typeof ProjectFilterValue;
type index_d$a_ProjectGroup = ProjectGroup;
declare const index_d$a_ProjectGroup: typeof ProjectGroup;
type index_d$a_ProjectNumberScheme = ProjectNumberScheme;
declare const index_d$a_ProjectNumberScheme: typeof ProjectNumberScheme;
type index_d$a_ProjectService = ProjectService;
declare const index_d$a_ProjectService: typeof ProjectService;
type index_d$a_ProjectSortSpec = ProjectSortSpec;
declare const index_d$a_ProjectSortSpec: typeof ProjectSortSpec;
type index_d$a_ProjectState = ProjectState;
type index_d$a_ProjectText = ProjectText;
declare const index_d$a_ProjectText: typeof ProjectText;
type index_d$a_ProjectTextType = ProjectTextType;
type index_d$a_SaveProjectOptions = SaveProjectOptions;
declare const index_d$a_SaveProjectOptions: typeof SaveProjectOptions;
type index_d$a_ScopeInfo = ScopeInfo;
type index_d$a_SubdivisionData = SubdivisionData;
declare const index_d$a_SubdivisionData: typeof SubdivisionData;
type index_d$a_TextFormat = TextFormat;
declare namespace index_d$a {
  export { index_d$a_AddressData as AddressData, type index_d$a_AddressType as AddressType, type index_d$a_AuthMessageType as AuthMessageType, index_d$a_AutoSaveOptions as AutoSaveOptions, type index_d$a_CommAddrType as CommAddrType, index_d$a_CommAddress as CommAddress, index_d$a_ContactData as ContactData, type index_d$a_ContactType as ContactType, index_d$a_CountryData as CountryData, index_d$a_DeleteProjectsOptions as DeleteProjectsOptions, index_d$a_DisplayName as DisplayName, index_d$a_FormattedText as FormattedText, type index_d$a_IsoDateString as IsoDateString, type index_d$a_IsoDateTimeString as IsoDateTimeString, type index_d$a_IsoDurationString as IsoDurationString, index_d$a_ListCompletionsOptions as ListCompletionsOptions, index_d$a_ListProjectsOptions as ListProjectsOptions, type index_d$a_LockingMode as LockingMode, index_d$a_Permission as Permission, index_d$a_PriceList as PriceList, type index_d$a_ProjectAttribute as ProjectAttribute, ProjectData$1 as ProjectData, index_d$a_ProjectFilter as ProjectFilter, index_d$a_ProjectFilterAttribute as ProjectFilterAttribute, index_d$a_ProjectFilterDateTimeValue as ProjectFilterDateTimeValue, index_d$a_ProjectFilterDateValue as ProjectFilterDateValue, index_d$a_ProjectFilterNode as ProjectFilterNode, type index_d$a_ProjectFilterOperator as ProjectFilterOperator, index_d$a_ProjectFilterStateValue as ProjectFilterStateValue, index_d$a_ProjectFilterStringValue as ProjectFilterStringValue, index_d$a_ProjectFilterValue as ProjectFilterValue, index_d$a_ProjectGroup as ProjectGroup, index_d$a_ProjectNumberScheme as ProjectNumberScheme, index_d$a_ProjectService as ProjectService, index_d$a_ProjectSortSpec as ProjectSortSpec, type index_d$a_ProjectState as ProjectState, index_d$a_ProjectText as ProjectText, type index_d$a_ProjectTextType as ProjectTextType, index_d$a_SaveProjectOptions as SaveProjectOptions, type index_d$a_ScopeInfo as ScopeInfo, index_d$a_SubdivisionData as SubdivisionData, type index_d$a_TextFormat as TextFormat };
}

type SessionCacheFileType = "Project" | "CutBuffer" | "Import";
type SendMessageStatus = "OK" | "UnexpectedError" | "UnknownTargetType" | "UnknownPlugin" | "NoPluginImplementation" | "NoMessageHandler" | "UnknownMessageId" | "InvalidMessageData" | "TargetError";
declare class ClientMessage extends SoapRequestData {
    data?: Array<StringPair>;
    target: string;
    messageId: string;
    constructor();
}
declare class CustomerData extends SoapRequestData {
    customerNumber?: string;
    salutation?: string;
    firstName?: string;
    lastName?: string;
    emailAddr?: string;
    company?: string;
    organization?: string;
    streetAddr?: string;
    city?: string;
    stateOrProvince?: string;
    cityCode?: string;
    poBox?: string;
    postalCode?: string;
    poBoxPostalCode?: string;
    country?: string;
    language?: string;
    phone?: string;
    fax?: string;
    static FromSoap(pSoapData: any): CustomerData | undefined;
}
declare class GetSystemInformationOptions extends SoapRequestData {
    operatingSystem?: boolean;
    runtime?: boolean;
    memory?: boolean;
    application?: boolean;
    server?: boolean;
}
declare class ImportFileOptions extends SoapRequestData {
    deleteAfterImport?: boolean;
}
declare class LoadSessionOptions extends SoapRequestData {
    suffix?: string;
    assignNewProjectId?: boolean;
}
declare class LogConfig extends SoapRequestData {
    maxRecordCount?: number;
    discardOldest?: boolean;
    storeStackTrace?: boolean;
    timeZoneId?: string;
    filter?: LogFilter;
}
declare class LogFilter extends SoapRequestData {
    include?: Array<LogFilterSpec>;
    exclude?: Array<LogFilterSpec>;
}
declare class LogFilterSpec extends SoapRequestData {
    level?: string;
    facility?: string;
    origin?: string;
}
declare class ProjectData extends SoapRequestData {
    number?: string;
    name?: string;
    description?: string;
    personInCharge?: string;
    extRefNr?: string;
    extRefText?: string;
    static FromSoap(pSoapData: any): ProjectData | undefined;
}
declare class ProjectSettings extends SoapRequestData {
    projectData?: ProjectData;
    customerData?: CustomerData;
    static FromSoap(pSoapData: any): ProjectSettings | undefined;
}
declare class ResolveURIsOptions extends SoapRequestData {
    serverBase?: string;
}
declare class SaveSessionOptions extends SoapRequestData {
    suffix?: string;
    overwrite?: boolean;
    generateImages?: boolean;
    omitPriceData?: boolean;
    saveCalculations?: boolean;
    saveLegacyCalculation?: boolean;
    legacyCalculationName?: string;
    export?: boolean;
}
declare class StringPair extends SoapRequestData {
    first: string;
    second: string;
    constructor(pFirst?: string, pSecond?: string);
    static FromSoapArray(pSoapArray: any): Array<StringPair> | undefined;
    static FromSoapNU(this: void, pSoapData: any): StringPair;
}
declare class ApplicationInformation {
    appName: string;
    appKey: string;
    appVersion: string;
    vendorKey: string;
    static FromSoap(pSoapData: any): ApplicationInformation | undefined;
}
declare class CallSite {
    className: string;
    methodName: string;
    fileName?: string;
    lineNumber?: number;
    static FromSoapArray(pSoapArray: any): Array<CallSite> | undefined;
    static FromSoapArrayNU(pSoapArray: any): Array<CallSite>;
    static FromSoap(pSoapData: any): CallSite | undefined;
    static FromSoapNU(this: void, pSoapData: any): CallSite;
}
declare class FaultInfo {
    message: string;
    stackTrace: Array<CallSite>;
    type: string;
    static FromSoapArray(pSoapArray: any): Array<FaultInfo> | undefined;
    static FromSoapNU(this: void, pSoapData: any): FaultInfo;
}
declare class LogData {
    data: Array<LogRecord>;
    discarded: number;
    suppressed: number;
    static FromSoap(pSoapData: any): LogData | undefined;
}
declare class LogRecord {
    cause?: Array<FaultInfo>;
    message: string;
    origin?: CallSite;
    facility: string;
    level: string;
    timeStamp: string;
    static FromSoapArrayNU(pSoapArray: any): Array<LogRecord>;
    static FromSoapNU(this: void, pSoapData: any): LogRecord;
}
declare class SendMessageResult {
    messages: Array<ServerResponse>;
    sessionAlive: boolean;
    static FromSoap(pSoapData: any): SendMessageResult | undefined;
}
declare class ServerInformation {
    maxConcurrentSessionCount: number;
    openSessionCount: number;
    activeSessionCount: number;
    sessionTimeout: number;
    sessionSuspendTimeout: number;
    static FromSoap(pSoapData: any): ServerInformation | undefined;
}
declare class ServerResponse {
    data?: Array<StringPair>;
    errorDetail?: Array<string>;
    origin: string;
    messageId: string;
    statusCode: SendMessageStatus;
    targetErrorCode?: string;
    static FromSoapArrayNU(pSoapArray: any): Array<ServerResponse>;
    static FromSoapNU(this: void, pSoapData: any): ServerResponse;
}
declare class SystemInformation {
    operatingSystem?: any;
    runtime?: any;
    memory?: any;
    application?: ApplicationInformation;
    server?: ServerInformation;
    static FromSoap(pSoapData: any): SystemInformation | undefined;
}

declare class SessionService extends BaseEaiwsService {
    constructor(pOwner: EaiwsSession, pBaseUrl: string, pSessionId: string);
    static GetSystemInformation(pBaseUrl: string, pOptions?: GetSystemInformationOptions): Promise<SystemInformation | undefined>;
    static OpenSession(pBaseUrl: string, pArgs: ReadonlyArray<StringPair>): Promise<string>;
    closeSession(): Promise<void>;
    configureSessionLog(pEnable: boolean, pConfig?: LogConfig): Promise<void>;
    /**
     * Note: The server response will be cached to speed up further calls.
     */
    getLocale(pWithTimeZone?: boolean): Promise<string>;
    getProjectAppData(pAppKey: string, pPaths: ReadonlyArray<string>): Promise<Array<string | null>>;
    getProjectSettings(): Promise<ProjectSettings | undefined>;
    getSessionLog(pReset: boolean): Promise<LogData | undefined>;
    getSessionProperty(pName: string): Promise<string | undefined>;
    getSystemInformation(pOptions?: GetSystemInformationOptions): Promise<SystemInformation | undefined>;
    getUploadURL(pFileType: SessionCacheFileType, pSuffix?: string): Promise<string>;
    importFile(pUrl: string, pAttributes?: ReadonlyArray<string> | null, pOptions?: ImportFileOptions): Promise<string>;
    keepAlive(): Promise<boolean>;
    loadEmptySession(): Promise<void>;
    loadSession(pUri: string, pOptions?: LoadSessionOptions): Promise<string>;
    resolveURIs(pUris: ReadonlyArray<string>, pOptions?: ResolveURIsOptions): Promise<Array<string>>;
    saveSession(pUri: string | null, pOptions?: SaveSessionOptions): Promise<string>;
    sendMessage(pMessages: ReadonlyArray<ClientMessage>): Promise<SendMessageResult>;
    setLocale(pLocale: string, pTimeZone?: string, pTzOffset?: number): Promise<void>;
    setProjectAppData(pAppKey: string, pData: ReadonlyArray<string>): Promise<void>;
    setProjectSettings(pSettings: ProjectSettings): Promise<void>;
    setSessionProperty(pName: string, pValue: string): Promise<void>;
    private mLocale;
}

type index_d$9_ApplicationInformation = ApplicationInformation;
declare const index_d$9_ApplicationInformation: typeof ApplicationInformation;
type index_d$9_CallSite = CallSite;
declare const index_d$9_CallSite: typeof CallSite;
type index_d$9_ClientMessage = ClientMessage;
declare const index_d$9_ClientMessage: typeof ClientMessage;
type index_d$9_CustomerData = CustomerData;
declare const index_d$9_CustomerData: typeof CustomerData;
type index_d$9_FaultInfo = FaultInfo;
declare const index_d$9_FaultInfo: typeof FaultInfo;
type index_d$9_GetSystemInformationOptions = GetSystemInformationOptions;
declare const index_d$9_GetSystemInformationOptions: typeof GetSystemInformationOptions;
type index_d$9_ImportFileOptions = ImportFileOptions;
declare const index_d$9_ImportFileOptions: typeof ImportFileOptions;
type index_d$9_LoadSessionOptions = LoadSessionOptions;
declare const index_d$9_LoadSessionOptions: typeof LoadSessionOptions;
type index_d$9_LogConfig = LogConfig;
declare const index_d$9_LogConfig: typeof LogConfig;
type index_d$9_LogData = LogData;
declare const index_d$9_LogData: typeof LogData;
type index_d$9_LogFilter = LogFilter;
declare const index_d$9_LogFilter: typeof LogFilter;
type index_d$9_LogFilterSpec = LogFilterSpec;
declare const index_d$9_LogFilterSpec: typeof LogFilterSpec;
type index_d$9_LogRecord = LogRecord;
declare const index_d$9_LogRecord: typeof LogRecord;
type index_d$9_ProjectData = ProjectData;
declare const index_d$9_ProjectData: typeof ProjectData;
type index_d$9_ProjectSettings = ProjectSettings;
declare const index_d$9_ProjectSettings: typeof ProjectSettings;
type index_d$9_ResolveURIsOptions = ResolveURIsOptions;
declare const index_d$9_ResolveURIsOptions: typeof ResolveURIsOptions;
type index_d$9_SaveSessionOptions = SaveSessionOptions;
declare const index_d$9_SaveSessionOptions: typeof SaveSessionOptions;
type index_d$9_SendMessageResult = SendMessageResult;
declare const index_d$9_SendMessageResult: typeof SendMessageResult;
type index_d$9_SendMessageStatus = SendMessageStatus;
type index_d$9_ServerInformation = ServerInformation;
declare const index_d$9_ServerInformation: typeof ServerInformation;
type index_d$9_ServerResponse = ServerResponse;
declare const index_d$9_ServerResponse: typeof ServerResponse;
type index_d$9_SessionCacheFileType = SessionCacheFileType;
type index_d$9_SessionService = SessionService;
declare const index_d$9_SessionService: typeof SessionService;
type index_d$9_StringPair = StringPair;
declare const index_d$9_StringPair: typeof StringPair;
type index_d$9_SystemInformation = SystemInformation;
declare const index_d$9_SystemInformation: typeof SystemInformation;
declare namespace index_d$9 {
  export { index_d$9_ApplicationInformation as ApplicationInformation, index_d$9_CallSite as CallSite, index_d$9_ClientMessage as ClientMessage, index_d$9_CustomerData as CustomerData, index_d$9_FaultInfo as FaultInfo, index_d$9_GetSystemInformationOptions as GetSystemInformationOptions, index_d$9_ImportFileOptions as ImportFileOptions, index_d$9_LoadSessionOptions as LoadSessionOptions, index_d$9_LogConfig as LogConfig, index_d$9_LogData as LogData, index_d$9_LogFilter as LogFilter, index_d$9_LogFilterSpec as LogFilterSpec, index_d$9_LogRecord as LogRecord, index_d$9_ProjectData as ProjectData, index_d$9_ProjectSettings as ProjectSettings, index_d$9_ResolveURIsOptions as ResolveURIsOptions, index_d$9_SaveSessionOptions as SaveSessionOptions, index_d$9_SendMessageResult as SendMessageResult, type index_d$9_SendMessageStatus as SendMessageStatus, index_d$9_ServerInformation as ServerInformation, index_d$9_ServerResponse as ServerResponse, type index_d$9_SessionCacheFileType as SessionCacheFileType, index_d$9_SessionService as SessionService, index_d$9_StringPair as StringPair, index_d$9_SystemInformation as SystemInformation };
}

/**
 * Options for `EaiwsSession.open()`
 */
interface OpenSessionOptions {
    /** name of the startup file for the session */
    startup?: string;
    /** list of package groups for the session */
    packageGroups?: string;
    /** user token which will be used to authorize the session */
    userToken?: string;
    /** optional locale which can be used to override the locale defined in the startup file */
    locale?: string;
    /** data domain for this session, used from project store */
    dataDomain?: string;
    /** Interval in milliseconds which is used to call `keepAlive()` at the session. A value of 0 or null will disabled the autmoatic keep alive handling. (default: 60000) */
    keepAliveInterval?: number | null;
}
declare class EaiwsSession {
    get baseUrl(): string;
    get sessionId(): string;
    get session(): SessionService;
    get catalog(): CatalogService;
    get basket(): BasketService;
    get project(): ProjectService;
    get isValid(): boolean;
    /**
     * Will be triggered if this instance was connected to an EAIWS session.
     */
    readonly eventConnected: ListenableEvent<void, EaiwsSession>;
    /**
     * Will be triggered if this instance was disconnected from an EAIWS session.
     */
    readonly eventDisconnected: ListenableEvent<void, EaiwsSession>;
    /**
     * Will be triggered from `session.setLocale()`.
     */
    readonly eventSessionLocaleChanged: ListenableEvent<void, EaiwsSession>;
    /**
     * Will be triggered from `catalog.setLanguages()`.
     */
    readonly eventCatalogLanguagesChanged: ListenableEvent<void, EaiwsSession>;
    /**
     * Will be triggered from `basket.setLanguages()`.
     */
    readonly eventBasketLanguagesChanged: ListenableEvent<void, EaiwsSession>;
    constructor();
    /**
     * Opens and connects a new EAIWS session.
     */
    open(pBaseUrl: string, pOptions: OpenSessionOptions): Promise<boolean>;
    /**
     * Closes the currently connected EAIWS session and disconnects.
     */
    close(): Promise<boolean>;
    /**
     * Connects to an already opened EAIWS session. If pKeepAliveInterval is null or 0 the keep
     * alive handling will be disabled (default: 60000).
     */
    connect(pBaseUrl: string, pSessionId: string, pKeepAliveInterval?: number | null): boolean;
    /**
     * Disconnects from the currently connected EAIWS session. The session will not be closed.
     */
    disconnect(): boolean;
    uploadFileToUrl(pTargetUrl: string, pFile: Blob, pOnProgress?: (pEvent: ProgressEvent, pXhr: XMLHttpRequest) => any): Promise<string>;
    uploadFile(pType: SessionCacheFileType, pFile: Blob, pOnProgress?: (pEvent: ProgressEvent, pXhr: XMLHttpRequest) => any, pUrlSuffix?: string): Promise<string | null>;
    deleteFile(pUrl: string): Promise<void>;
    private mBaseUrl;
    private mSessionId;
    private mKeepAliveInterval;
    private mSession;
    private mCatalog;
    private mBasket;
    private mProject;
    private keepAlive;
}

declare class ConditionRule extends SoapRequestData {
    manufacturer?: string;
    series?: string;
    baseArticleNumber?: string;
    finalArticleNumber?: string;
    itemId?: string;
    value: number;
    currency?: string;
    constructor();
    static FromSoapArrayNU(pSoapArray: any): Array<ConditionRule>;
    static FromSoapNU(this: void, pSoapData: any): ConditionRule;
}
declare const _ConditionRuleBase: typeof ConditionRule;
/**
 * @deprecated Use REST API of PriceProfile plugin instead.
 */
declare class PriceProfileService extends SoapService {
    constructor(pBaseUrl: string, pSessionId: string);
    addRules(pAccMeth: string, pRules: Array<ConditionRule>): Promise<void>;
    getRules(pAccMeth: string): Promise<Array<ConditionRule>>;
    loadCsv(pAccMeth: string, pCsvPath: string): Promise<void>;
    removeRules(pAccMeth?: string): Promise<void>;
}
declare namespace PriceProfileService {
    /**
    * @deprecated Use REST API of PriceProfile plugin instead.
    */
    class ConditionRule extends _ConditionRuleBase {
    }
}

type PriceProfileService_d_ConditionRule = ConditionRule;
declare const PriceProfileService_d_ConditionRule: typeof ConditionRule;
declare const PriceProfileService_d_PriceProfileService: typeof PriceProfileService;
declare namespace PriceProfileService_d {
  export { PriceProfileService_d_ConditionRule as ConditionRule, PriceProfileService_d_PriceProfileService as PriceProfileService };
}

type index_d$8_ConditionRule = ConditionRule;
declare const index_d$8_ConditionRule: typeof ConditionRule;
declare const index_d$8_PriceProfileService: typeof PriceProfileService;
declare namespace index_d$8 {
  export { index_d$8_ConditionRule as ConditionRule, index_d$8_PriceProfileService as PriceProfileService, PriceProfileService_d as priceProfile };
}

type eaiws_BaseEaiwsService = BaseEaiwsService;
declare const eaiws_BaseEaiwsService: typeof BaseEaiwsService;
type eaiws_EaiwsSession = EaiwsSession;
declare const eaiws_EaiwsSession: typeof EaiwsSession;
type eaiws_OpenSessionOptions = OpenSessionOptions;
type eaiws_RequestOptionsCallback = RequestOptionsCallback;
type eaiws_SoapError = SoapError;
declare const eaiws_SoapError: typeof SoapError;
type eaiws_SoapErrorDetail = SoapErrorDetail;
type eaiws_SoapRequestData = SoapRequestData;
declare const eaiws_SoapRequestData: typeof SoapRequestData;
type eaiws_SoapService = SoapService;
declare const eaiws_SoapService: typeof SoapService;
declare const eaiws_soapAttribute: typeof soapAttribute;
declare const eaiws_soapNodeText: typeof soapNodeText;
declare namespace eaiws {
  export { eaiws_BaseEaiwsService as BaseEaiwsService, eaiws_EaiwsSession as EaiwsSession, type eaiws_OpenSessionOptions as OpenSessionOptions, type eaiws_RequestOptionsCallback as RequestOptionsCallback, eaiws_SoapError as SoapError, type eaiws_SoapErrorDetail as SoapErrorDetail, eaiws_SoapRequestData as SoapRequestData, eaiws_SoapService as SoapService, index_d$c as basket, index_d$b as catalog, index_d$8 as plugins, index_d$a as project, index_d$9 as session, eaiws_soapAttribute as soapAttribute, eaiws_soapNodeText as soapNodeText };
}

interface GroupedMapData {
    [groupKey: string]: {
        [dataKey: string]: unknown;
    };
}
declare class GroupedMap implements Serializable<GroupedMapData> {
    constructor();
    clear(): void;
    /**
     * Adds or overrides an data entry.
     * Data used as custom data has to be serializable as a JSON string.
     * If pData is undefined an existing entry will be removed.
     * The group key should be a unique identifer (e.g. an appliaction id or a module id)
     */
    setData<T>(pGroupKey: string, pDataKey: string, pData: T | undefined): void;
    /**
     * Get the value for an data entry.
     */
    getData<T>(pGroupKey: string, pDataKey: string): T | undefined;
    serialize(): GroupedMapData | null;
    deserialize(pData?: GroupedMapData | null): boolean;
    private mData;
    private getGroup;
    private hasKeys;
}

declare abstract class Log {
    static onWarn: ((pMsg: string) => void) | undefined;
    static onError: ((pMsg: string, pError: unknown) => void) | undefined;
    static debug(pMsg: string): void;
    static info(pMsg: string): void;
    static warn(pMsg: string): void;
    static error(pMsg: string, pError?: unknown): void;
    private static FormatMsg;
}

type ProgressCallback = (pProgress: number) => void;
declare class Progress {
    get progress(): number;
    get sectionProgress(): number;
    constructor(pCallback?: ProgressCallback | null, pMultipleSections?: boolean);
    /**
     * Sets the current progress. If multiple sections are used the progress for the
     * current section will be set.
     * @param pProgress The new progress in percent. (range: [0, 100])
     */
    setProgress(pProgress: number): void;
    /**
     * Starts a new progress section and finishes previous one.
     * @param pSize Size of the section in percent.
     */
    startSection(pSize: number): void;
    private mSectionSize;
    private mSectionProgress;
    private mBaseProgress;
    private mProgress;
    private mCallback;
    private finishSection;
}

interface LoadContentErrorInfo {
    /** Url of the content which failed to load. */
    url: string;
    /** Shows how many retries were already performed. 0 for the first error. */
    retryCount: number;
    /** If called another attempt will be made to load the content. */
    retry(): void;
    /** If retry was not called reject has to be called to reject the underlying promise. */
    reject(): void;
}
/**
 * Loads the content of the given url and provides it via blob url.
 * If the content is no longer used `URL.revokeObjectURL()` has to be called to release resources.
 * Note: This function will trigger `async.ajaxErrorHandler` instead of `loadContentErrorHandler` because ajax is used internally.
 */
declare function loadContentAsBlobUrl(pUrl: string): Promise<string>;
/**
 * Loads and executes JavaScript.
 * pAsync can be set to false to ensure correct execution order of loaded script. (default: true)
 */
declare function loadScript(pUrl: string, pAsync?: boolean): Promise<void>;
/**
 * Loads a Cascading Style Sheet.
 */
declare function loadStyleSheet(pUrl: string): Promise<void>;
/**
 * Submits the given fields as a form to the given url. This will change the window location.
 */
declare function submitForm(pMethod: AjaxMethod, pUrl: string, pFields: Map<string, string>): void;

type index_d$7_LoadContentErrorInfo = LoadContentErrorInfo;
declare const index_d$7_loadContentAsBlobUrl: typeof loadContentAsBlobUrl;
declare const index_d$7_loadScript: typeof loadScript;
declare const index_d$7_loadStyleSheet: typeof loadStyleSheet;
declare const index_d$7_submitForm: typeof submitForm;
declare namespace index_d$7 {
  export { type index_d$7_LoadContentErrorInfo as LoadContentErrorInfo, index_d$7_loadContentAsBlobUrl as loadContentAsBlobUrl, index_d$7_loadScript as loadScript, index_d$7_loadStyleSheet as loadStyleSheet, index_d$7_submitForm as submitForm };
}

/** options for article configuration */
interface ArticleConfigurationOptions {
    /** enables high resolution property icons (default: false) */
    highResPropValueIcons: boolean;
    /** enables fetching of property images (default: false) */
    fetchPropValueImages: boolean;
    /** if true spaces and colons at the end of the property text/name will be removed (default: true) */
    trimPropText: boolean;
}

interface WcfConfig {
    /**
     * Path of the W-CF data folder. e.g. `/wcf/data/`
     */
    dataPath?: string;
    /**
     * Options for article configuration.
     */
    articleConfigurationOptions: ArticleConfigurationOptions;
    /**
     * Default options used for ajax requests.
     */
    ajaxDefaultOptions: Required<AjaxOptions>;
    /**
     * Global ajax error handler which can be used to capture and handle all ajax errors.
     */
    ajaxErrorHandler?: ((pError: AjaxErrorInfo) => void);
    /**
     * Global ajax event which will be triggered for every successful ajax request.
     */
    ajaxResolvedEvent?: ((pRequestInfo: AjaxRequestInfo, pXhr: XMLHttpRequest) => void);
    /**
     * Global ajax event which will be triggered for every failed ajax request.
     */
    ajaxRejectedEvent?: ((pRequestInfo: AjaxRequestInfo, pXhr: XMLHttpRequest, pError: Error) => void);
    /**
     * Function which returns a delay (in ms) for the next ajax retry attempt based on the retry counter.
     * Can be overridden for custom delays. (default: 200ms * pRetryCount)
     */
    ajaxGetRetryDelay: (pRetryCount: number) => number;
    /**
     * Global error handler which can be used to capture and handle all content loading errors (DomUtils).
     */
    loadContentErrorHandler?: ((pError: LoadContentErrorInfo) => void);
}
declare function getDataPath(): string;
/**
 * Global configuration for W-CF.
 */
declare const wcfConfig: WcfConfig;

/**
 * Returns true if the given object is an array. No type conversion will be performed.
 */
declare function isArray<T = unknown>(pObj: unknown): pObj is Array<T>;
/**
 * Removes the first element from pArray equal to pElement.
 * Returns true if element was removed.
 */
declare function removeElement<T>(pArray: Array<T>, pElement: T): boolean;
/**
 * Adds a list of elements to the given array.
 */
declare function addElements<T>(pArray: Array<T>, pElements: Array<T>): void;
/**
 * Inserts a list of elements into the given array.
 */
declare function insertElements<T>(pArray: Array<T>, pElements: Array<T>, pInsertIndex: number): void;
/**
 * Creates a clone of the given array.
 */
declare function clone<T>(pArray: Array<T> | ReadonlyArray<T>): Array<T>;
/**
 * Returns true if pArray contains pElement.
 */
declare function contains<T>(pArray: Array<T> | ReadonlyArray<T>, pElement: T): boolean;
/**
 * Clears the given array.
 * Note: Its usually faster to create a new empty array instead of clearing it.
 */
declare function clear<T>(pArray: Array<T>): void;
/**
 * Returns a new array which only contains the unique entries (no duplicates) of pArray.
 */
declare function unique<T>(pArray: Array<T> | ReadonlyArray<T>): Array<T>;
/**
 * Splits the given array into chunks.
 * Returns an array of arrays with the given chunk size.
 */
declare function chunk<T>(pArray: Array<T> | ReadonlyArray<T>, pChunkSize: number): Array<Array<T>>;

declare const index_d$6_addElements: typeof addElements;
declare const index_d$6_chunk: typeof chunk;
declare const index_d$6_clear: typeof clear;
declare const index_d$6_clone: typeof clone;
declare const index_d$6_contains: typeof contains;
declare const index_d$6_insertElements: typeof insertElements;
declare const index_d$6_isArray: typeof isArray;
declare const index_d$6_removeElement: typeof removeElement;
declare const index_d$6_unique: typeof unique;
declare namespace index_d$6 {
  export { index_d$6_addElements as addElements, index_d$6_chunk as chunk, index_d$6_clear as clear, index_d$6_clone as clone, index_d$6_contains as contains, index_d$6_insertElements as insertElements, index_d$6_isArray as isArray, index_d$6_removeElement as removeElement, index_d$6_unique as unique };
}

/**
 * Converts an ArrayBuffer into a Base64 encoded string.
 */
declare function toBase64(pBuffer: ArrayBuffer): string;
/**
 * Converts an ArrayBuffer into a hex (Base16) encoded string.
 */
declare function toHex(pBuffer: ArrayBuffer): string;
/**
 * Converts an ArrayBuffer into a data uri.
 */
declare function toDataUri(pBuffer: ArrayBuffer, pMimeType: string): string;
/**
 * Converts a Base64 encoded string into an ArrayBuffer.
 */
declare function fromBase64(pBase64Str: string): ArrayBuffer;
/**
 * Converts a data uri into an ArrayBuffer.
 */
declare function fromDataUri(pDataUri: string): ArrayBuffer;
/**
 * Converts a Blob into an ArrayBuffer.
 */
declare function fromBlob$1(pBlob: Blob): Promise<ArrayBuffer>;
/**
 * Computes the hash for the given buffer and returns it as hex string.
 * Note: This function requires a secure connection (HTTPS).
 */
declare function hash$1(pBuffer: ArrayBuffer | Uint8Array, pAlgorithm: "SHA-256" | "SHA-384" | "SHA-512"): Promise<string>;

declare const index_d$5_fromBase64: typeof fromBase64;
declare const index_d$5_fromDataUri: typeof fromDataUri;
declare const index_d$5_toBase64: typeof toBase64;
declare const index_d$5_toDataUri: typeof toDataUri;
declare const index_d$5_toHex: typeof toHex;
declare namespace index_d$5 {
  export { index_d$5_fromBase64 as fromBase64, fromBlob$1 as fromBlob, index_d$5_fromDataUri as fromDataUri, hash$1 as hash, index_d$5_toBase64 as toBase64, index_d$5_toDataUri as toDataUri, index_d$5_toHex as toHex };
}

/**
 * Returns true if the given object is a boolean. No type conversion will be performed.
 */
declare function isBoolean(pObj: unknown): pObj is boolean;

declare const index_d$4_isBoolean: typeof isBoolean;
declare namespace index_d$4 {
  export { index_d$4_isBoolean as isBoolean };
}

type ImageMimeType = "image/jpeg" | "image/png" | "image/svg+xml" | "image/gif";
interface ResizeOptions {
    /** new width of the image */
    width: number;
    /** new height of the image */
    height: number;
    /** if false the aspect ratio of the resulting image may change (default: true) */
    keepAspectRatio?: boolean;
    /** mime type of the resulting dataUri / blob (default: "image/png") */
    mimeType?: string;
}
/**
 * Loads the given image and returns it as an HTMLImageElement.
 */
declare function loadImage(pImageSrc: string | Blob | File): Promise<HTMLImageElement>;
/**
 * Returns the mime type of the given image source. Null will be returned if the mime type is
 * unknown or if its an unsupported type.
 */
declare function getImageMimeType(pImageSrc: string | Blob | File): Promise<ImageMimeType | null>;
/** Resizes the given image according to the resize options and returns it as a canvas. */
declare function resizeToCanvas(pImage: HTMLImageElement, pOptions: ResizeOptions): HTMLCanvasElement;
/** Resizes the given image according to the resize options and returns it as a dataUri. */
declare function resizeToDataUri(pImage: HTMLImageElement, pOptions: ResizeOptions): string;
/** Resizes the given image according to the resize options and returns it as a blob. */
declare function resizeToBlob(pImage: HTMLImageElement, pOptions: ResizeOptions): Promise<Blob>;
/**
 * Returns the image content of the given canvas as a blob.
 * If pMimeType is undefined it will be returned as a png file.
 */
declare function canvasToBlob(pCanvas: HTMLCanvasElement, pMimeType?: string): Promise<Blob>;

type index_d$3_ImageMimeType = ImageMimeType;
type index_d$3_ResizeOptions = ResizeOptions;
declare const index_d$3_canvasToBlob: typeof canvasToBlob;
declare const index_d$3_getImageMimeType: typeof getImageMimeType;
declare const index_d$3_loadImage: typeof loadImage;
declare const index_d$3_resizeToBlob: typeof resizeToBlob;
declare const index_d$3_resizeToCanvas: typeof resizeToCanvas;
declare const index_d$3_resizeToDataUri: typeof resizeToDataUri;
declare namespace index_d$3 {
  export { type index_d$3_ImageMimeType as ImageMimeType, type index_d$3_ResizeOptions as ResizeOptions, index_d$3_canvasToBlob as canvasToBlob, index_d$3_getImageMimeType as getImageMimeType, index_d$3_loadImage as loadImage, index_d$3_resizeToBlob as resizeToBlob, index_d$3_resizeToCanvas as resizeToCanvas, index_d$3_resizeToDataUri as resizeToDataUri };
}

declare const EPSILON: number;
declare const PI_MUL2: number;
declare const PI_DIV2: number;
declare const PI_DIV4: number;
declare const FACTOR_DEG_TO_RAD: number;
declare const FACTOR_RAD_TO_DEG: number;
/**
 * Epsilon equal test.
 */
declare function eq(pN1: number, pN2: number, pEpsilon?: number): boolean;
/**
 * Epsilon greater equal test.
 */
declare function geq(pN1: number, pN2: number, pEpsilon?: number): boolean;
/**
 * Epsilon lesser equal test.
 */
declare function leq(pN1: number, pN2: number, pEpsilon?: number): boolean;
declare function clamp(pValue: number, pMin: number, pMax: number): number;
declare function roundTo(pValue: number, pDecimals: number): number;
declare function radToDeg(pRad: number): number;
declare function degToRad(pDeg: number): number;

declare const index_d$2_EPSILON: typeof EPSILON;
declare const index_d$2_FACTOR_DEG_TO_RAD: typeof FACTOR_DEG_TO_RAD;
declare const index_d$2_FACTOR_RAD_TO_DEG: typeof FACTOR_RAD_TO_DEG;
declare const index_d$2_PI_DIV2: typeof PI_DIV2;
declare const index_d$2_PI_DIV4: typeof PI_DIV4;
declare const index_d$2_PI_MUL2: typeof PI_MUL2;
declare const index_d$2_clamp: typeof clamp;
declare const index_d$2_degToRad: typeof degToRad;
declare const index_d$2_eq: typeof eq;
declare const index_d$2_geq: typeof geq;
declare const index_d$2_leq: typeof leq;
declare const index_d$2_radToDeg: typeof radToDeg;
declare const index_d$2_roundTo: typeof roundTo;
declare namespace index_d$2 {
  export { index_d$2_EPSILON as EPSILON, index_d$2_FACTOR_DEG_TO_RAD as FACTOR_DEG_TO_RAD, index_d$2_FACTOR_RAD_TO_DEG as FACTOR_RAD_TO_DEG, index_d$2_PI_DIV2 as PI_DIV2, index_d$2_PI_DIV4 as PI_DIV4, index_d$2_PI_MUL2 as PI_MUL2, index_d$2_clamp as clamp, index_d$2_degToRad as degToRad, index_d$2_eq as eq, index_d$2_geq as geq, index_d$2_leq as leq, index_d$2_radToDeg as radToDeg, index_d$2_roundTo as roundTo };
}

declare const LengthUnit: {
    readonly Millimeter: 0;
    readonly Centimeter: 1;
    readonly Inch: 2;
    readonly Feet: 3;
    readonly Meter: 4;
    readonly Kilometer: 5;
};
type LengthUnit = typeof LengthUnit[keyof typeof LengthUnit];
interface CurrencyStringOptions {
    /** @defaultValue true */
    useGrouping?: boolean;
    /** @defaultValue true */
    showCurrency?: boolean;
    /**
     * Can be used to increase the precision of the currency string.
     * Additional decimal places will be shown only if necessary.
     * The minimum number of shown decimal places depend on the used currency.
     * @defaultValue 0
     */
    additionalDecimalPlaces?: number;
}
/**
 * Returns true if the given object is a number. No type conversion will be performed.
 */
declare function isNumber(pObj: unknown): pObj is number;
/**
 * Converts a localized string to a number. Number grouping is not supported (thousands separators).
 * Null will be returned if the conversion fails.
 */
declare function fromLocaleString(pString: string): number | null;
/**
 * Converts a number to a localized string.
 * Null will be returned if the conversion fails.
 */
declare function toLocaleString(pValue: number, pLocale: string, pMinDecimalPlaces?: number, pMaxDecimalplaces?: number, pUseGrouping?: boolean): string | null;
/**
 * Converts a number to a localized currency string. Null will be returned if the conversion fails.
 */
declare function toLocaleCurrencyString(pValue: number, pCurrency: string, pLocale: string, pOptions?: CurrencyStringOptions): string | null;
/**
 * Converts a localized length string to number. Number grouping is not supported (thousands separators).
 * If the string does not contain a length unit the default unit will be used.
 * The value will be returned in meter.
 * Null will be returned if the conversion fails.
 */
declare function fromLocaleLengthString(pString: string, pDefaultUnit?: LengthUnit): number | null;
/**
 * Converts a number to localized length string. The value is expected in meter.
 * Null will be returned if the conversion fails.
 */
declare function toLocaleLengthString(pValue: number, pLocale: string, pTargetUnit?: LengthUnit, pAddUnit?: boolean): string | null;
/**
 * Converts the given value into another length unit.
 */
declare function convertLengthUnit(pValue: number, pFrom: LengthUnit, pTo: LengthUnit): number;

type index_d$1_CurrencyStringOptions = CurrencyStringOptions;
type index_d$1_LengthUnit = LengthUnit;
declare const index_d$1_convertLengthUnit: typeof convertLengthUnit;
declare const index_d$1_fromLocaleLengthString: typeof fromLocaleLengthString;
declare const index_d$1_fromLocaleString: typeof fromLocaleString;
declare const index_d$1_isNumber: typeof isNumber;
declare const index_d$1_toLocaleCurrencyString: typeof toLocaleCurrencyString;
declare const index_d$1_toLocaleLengthString: typeof toLocaleLengthString;
declare const index_d$1_toLocaleString: typeof toLocaleString;
declare namespace index_d$1 {
  export { type index_d$1_CurrencyStringOptions as CurrencyStringOptions, type index_d$1_LengthUnit as LengthUnit, index_d$1_convertLengthUnit as convertLengthUnit, index_d$1_fromLocaleLengthString as fromLocaleLengthString, index_d$1_fromLocaleString as fromLocaleString, index_d$1_isNumber as isNumber, index_d$1_toLocaleCurrencyString as toLocaleCurrencyString, index_d$1_toLocaleLengthString as toLocaleLengthString, index_d$1_toLocaleString as toLocaleString };
}

/**
 * Returns true if the given object is a string. No type conversion will be performed.
 */
declare function isString(pObj: unknown): pObj is string;
/**
 * Returns true if the string is null or empty.
 */
declare function isNullOrEmpty(pString: string | null | undefined): pString is null | undefined;
/**
 * Returns true if the string is NOT null or empty.
 */
declare function isNotNullOrEmpty(pString: string | null | undefined): pString is string;
/**
 * Removes pChar (default: " ") from the left and right end of the string.
 */
declare function trim(pString: string, pChar?: string): string;
/**
 * Removes pChar (default: " ") from the left end of the string.
 */
declare function trimLeft(pString: string, pChar?: string): string;
/**
 * Removes pChar (default: " ") from the right end of the string.
 */
declare function trimRight(pString: string, pChar?: string): string;
/**
 * Compares two strings.
 */
declare function compare(pString1: string, pString2: string): number;
/**
 * Returns the file extension of the given url. The returned extension will be always lowercase.
 * www.example.com/test/123.jpg ==> .jpg
 */
declare function getFileExtension(pUrl: string): string;
/**
 * Returns the path of the given url.
 * www.example.com/test/123.jpg ==> www.example.com/test/
 */
declare function getFilePath(pUrl: string): string;
/**
 * Returns the filename of the given url.
 * www.example.com/test/123.jpg ==> 123.jpg
 */
declare function getFileName(pUrl: string): string;
/**
 * Joins given path segements into one path.
 * Resolving of ".." or "." is not supported.
 */
declare function joinPath(...pSegments: Array<string>): string;
/**
 * Returns the value of the given parameter.
 * www.example.com/test/123.jpg?x=1&y=2 ==> 2 (for pParam = "y")
 */
declare function getUrlParamValue(pUrl: string, pParam: string): string | null;
/**
 * Removes the query string from the given url.
 * www.example.com/test/?x=1&y=2 ==> www.example.com/test/
 */
declare function removeQueryString(pUrl: string): string;
/**
 * Converts a Blob into a string.
 * If pAsDataUri is true the returned string is a data-uri, otherwise its returned as text.
 */
declare function fromBlob(pBlob: Blob, pAsDataUri?: boolean): Promise<string>;
declare function isDataUri(pUri: string | null | undefined): pUri is string;
declare function htmlEscape(pString: string): string;
declare function htmlUnescape(pString: string): string;
declare function regExpEscape(pString: string): string;
/** Returns a randomly generated UUID */
declare function generateRandomUUID(): string;
/**
 * Computes the hash for the given string and returns it as hex string.
 * Note: This function requires a secure connection (HTTPS).
 */
declare function hash(pString: string, pAlgorithm: "SHA-256" | "SHA-384" | "SHA-512"): Promise<string>;
/** Encodes the given UTF-16 string to UTF-8 */
declare function encodeToUtf8(pString: string): Uint8Array;

declare const index_d_compare: typeof compare;
declare const index_d_encodeToUtf8: typeof encodeToUtf8;
declare const index_d_fromBlob: typeof fromBlob;
declare const index_d_generateRandomUUID: typeof generateRandomUUID;
declare const index_d_getFileExtension: typeof getFileExtension;
declare const index_d_getFileName: typeof getFileName;
declare const index_d_getFilePath: typeof getFilePath;
declare const index_d_getUrlParamValue: typeof getUrlParamValue;
declare const index_d_hash: typeof hash;
declare const index_d_htmlEscape: typeof htmlEscape;
declare const index_d_htmlUnescape: typeof htmlUnescape;
declare const index_d_isDataUri: typeof isDataUri;
declare const index_d_isNotNullOrEmpty: typeof isNotNullOrEmpty;
declare const index_d_isNullOrEmpty: typeof isNullOrEmpty;
declare const index_d_isString: typeof isString;
declare const index_d_joinPath: typeof joinPath;
declare const index_d_regExpEscape: typeof regExpEscape;
declare const index_d_removeQueryString: typeof removeQueryString;
declare const index_d_trim: typeof trim;
declare const index_d_trimLeft: typeof trimLeft;
declare const index_d_trimRight: typeof trimRight;
declare namespace index_d {
  export { index_d_compare as compare, index_d_encodeToUtf8 as encodeToUtf8, index_d_fromBlob as fromBlob, index_d_generateRandomUUID as generateRandomUUID, index_d_getFileExtension as getFileExtension, index_d_getFileName as getFileName, index_d_getFilePath as getFilePath, index_d_getUrlParamValue as getUrlParamValue, index_d_hash as hash, index_d_htmlEscape as htmlEscape, index_d_htmlUnescape as htmlUnescape, index_d_isDataUri as isDataUri, index_d_isNotNullOrEmpty as isNotNullOrEmpty, index_d_isNullOrEmpty as isNullOrEmpty, index_d_isString as isString, index_d_joinPath as joinPath, index_d_regExpEscape as regExpEscape, index_d_removeQueryString as removeQueryString, index_d_trim as trim, index_d_trimLeft as trimLeft, index_d_trimRight as trimRight };
}

type utils_AbstractEventListener<T, O, R> = AbstractEventListener<T, O, R>;
type utils_AbstractListenableEvent<T, O, R> = AbstractListenableEvent<T, O, R>;
declare const utils_AbstractListenableEvent: typeof AbstractListenableEvent;
type utils_AsyncEventListener<T, O> = AsyncEventListener<T, O>;
type utils_AsyncListenableEvent<T, O> = AsyncListenableEvent<T, O>;
declare const utils_AsyncListenableEvent: typeof AsyncListenableEvent;
type utils_EventListener<T, O> = EventListener<T, O>;
type utils_GroupedMap = GroupedMap;
declare const utils_GroupedMap: typeof GroupedMap;
type utils_GroupedMapData = GroupedMapData;
type utils_ListenableEvent<T, O> = ListenableEvent<T, O>;
declare const utils_ListenableEvent: typeof ListenableEvent;
type utils_Log = Log;
declare const utils_Log: typeof Log;
type utils_Progress = Progress;
declare const utils_Progress: typeof Progress;
type utils_ProgressCallback = ProgressCallback;
type utils_WcfConfig = WcfConfig;
declare const utils_getDataPath: typeof getDataPath;
declare const utils_wcfConfig: typeof wcfConfig;
declare namespace utils {
  export { type utils_AbstractEventListener as AbstractEventListener, utils_AbstractListenableEvent as AbstractListenableEvent, type utils_AsyncEventListener as AsyncEventListener, utils_AsyncListenableEvent as AsyncListenableEvent, type utils_EventListener as EventListener, utils_GroupedMap as GroupedMap, type utils_GroupedMapData as GroupedMapData, utils_ListenableEvent as ListenableEvent, utils_Log as Log, utils_Progress as Progress, type utils_ProgressCallback as ProgressCallback, type utils_WcfConfig as WcfConfig, index_d$6 as array, index_d$5 as arraybuffer, index_d$d as async, index_d$4 as boolean, index_d$7 as dom, index_d$f as error, utils_getDataPath as getDataPath, index_d$3 as image, index_d$2 as math, index_d$1 as number, index_d$e as object, index_d as string, utils_wcfConfig as wcfConfig };
}

declare const WCF_VERSION = "9.0.0";
declare const WCF_BUILDINFO = "c1a843d9 master 2023-10-20";

declare global {
    export namespace egrWcf {
        export { eaiws, utils };
    }
}

export { WCF_BUILDINFO, WCF_VERSION, eaiws, utils };
