import * as basket from "../eaiws/basket";
import type { CalculationSheetInfo } from "../eaiws/basket";
import { BasketItem } from "./BasketItem";
import type { ArticleImageCameraSetup } from "./BaseItem";
import { ItemUpdateFlags } from "./BaseItem";
import type { Basket } from "./Basket";
export declare class ArticleItem extends BasketItem {
    get isOfmlArticle(): boolean;
    get ofmlUpdateState(): basket.OFMLUpdateState;
    constructor(pManager: Basket, pParent: BasketItem | null, pChildIndex: number, pEaiwsItem: basket.BasketItem);
    getMainArticle(): ArticleItem;
    isSubArticle(): boolean;
    getSubArticles(pRecursive: boolean): Array<ArticleItem>;
    /**
     * Updates the main article with all its sub articles (and there sub articles).
     * Note: BasketItemUpdateFlags.IncludeChildren will be ignored here.
     */
    updateWholeComposite(pFlags: ItemUpdateFlags): Promise<void>;
    setQuantity(pQuantity: number): Promise<void>;
    /**
     * Returns a composed calculation for the main article including all its sub articles.
     * @param pIgnoreHeaderCalculation If true the cached calculation will be returned even if the
     *      header calculation has changed in the meantime. Every condition which depends on a header condition
     *      may have a wrong/outdated value in this case. (default: false)
     */
    getCompositeCalculation(pIgnoreHeaderCalculation?: boolean): Promise<CalculationSheetInfo>;
    /**
     * Retrieves the ofml update state if it is currently unkown.
     */
    fetchOfmlUpdateState(): Promise<void>;
    setShortText(pText: string): Promise<void>;
    setLongText(pText: string): Promise<void>;
    setFeatureText(pText: string): Promise<void>;
    setPackagingNetWeight(pWeight: number, pUnit: string): Promise<void>;
    setPackagingVolume(pVolume: number, pUnit: string): Promise<void>;
    getTaxInformation(): Promise<Array<basket.TaxInfo>>;
    setTaxInformation(pTaxType: string, pTaxCategory: string): Promise<void>;
    /**
     * Returns a user defined description for the article
     * Use `setShortText()`, `setLongText()` or `setFeatureText()` to change the description.
     */
    getUserDescription(): Promise<basket.ArticleDescription>;
    getCameraSetup(): ArticleImageCameraSetup | null;
    setCameraSetup(pSetup: ArticleImageCameraSetup | null, pUpdateItem?: boolean): Promise<void>;
    protected static SetShortText(pItem: ArticleItem, pText: string, pUpdateItemLabel: boolean): Promise<void>;
    protected static SetManufacturerId(pItem: ArticleItem, pId: string): Promise<void>;
    protected static SetSeriesId(pItem: ArticleItem, pId: string): Promise<void>;
    protected static SetArticleNumber(pItem: ArticleItem, pArtNbr: string): Promise<void>;
    protected performUpdates(pFlags: ItemUpdateFlags): Promise<void>;
    protected invalidateCalculation(pTriggerUpdateEvent: boolean): void;
    protected generateImageUrl(): Promise<void>;
    protected handleChangedItemProps(): void;
    private mCameraSetup;
    private mPreferStoredImage;
    private mCompositeCalculation;
    private mCompositeCalculationHdrVersion;
    private mOfmlUpdateState;
    private mTaxInfo;
    private mTaxInfoLock;
    private mUserDescription;
    private mUserDescriptionLock;
    private mConfigData;
    private updateSubArticles;
    private internalGetSubArticles;
    private _getCachedArticleData;
}
