import type { EaiwsSession } from "../eaiws";
import * as basket from "../eaiws/basket";
import { CalculationSheetInfo } from "../eaiws/basket";
import { ListenableEvent } from "../utils";
import { ItemUpdateFlags } from "./BaseItem";
import type { BaseItem } from "./BaseItem";
export type InactiveItemCalcMode = "Auto" | "Include" | "Exclude";
export declare abstract class BaseItemManager<T extends BaseItem<T, M>, M extends BaseItemManager<T, M>> {
    get root(): T;
    get session(): EaiwsSession;
    get selection(): ReadonlyArray<T>;
    get isValid(): boolean;
    abstract readonly generatedImageResolution: number;
    abstract readonly includeCalculationErrorsInInconsistencies: boolean;
    readonly eventSelectionChanged: ListenableEvent<void, BaseItemManager<T, M>>;
    /**
    * Triggered every time the header calculation has changed.
    * Note: A changed header calculation may also imply that the calculation of all items has changed if
    * some conditions depend on header conditions. The event `eventItemUpdated` may not be triggered
    * for all items in these cases (e.g. for indirect changes).
    */
    readonly eventHeaderCalculationChanged: ListenableEvent<void, BaseItemManager<T, M>>;
    readonly eventItemCreated: ListenableEvent<T, BaseItemManager<T, M>>;
    readonly eventItemDisposed: ListenableEvent<T, BaseItemManager<T, M>>;
    /**
    * Triggered every time an item changed.
    * Note: The event will not be triggered if the item calculation has indirectly changed by
    * some header conditions. You should also listen to the event `eventHeaderCalculationChanged`.
    */
    readonly eventItemUpdated: ListenableEvent<{
        item: T;
        flags: ItemUpdateFlags;
    }, BaseItemManager<T, M>>;
    constructor(pSession: EaiwsSession);
    getHeaderCalculation(): Promise<CalculationSheetInfo>;
    invalidateHeaderCalculation(): void;
    getItemById(pItemId: string): T | null;
    setSelection(pSelection: Array<T> | null): boolean;
    addToSelection(pItem: T): boolean;
    removeFromSelection(pItem: T): boolean;
    beginSelectionChange(): void;
    endSelectionChange(): void;
    waitUntilItemsUpdated(): Promise<void>;
    protected mSession: EaiwsSession;
    protected mRoot: T;
    protected mViewId: string | undefined;
    protected mExtraPriceInfoSelectors: Array<string> | undefined;
    protected mSelection: Array<T>;
    protected internalClear(): void;
    protected loadRootFolder(): Promise<void>;
    protected abstract createItem(pParent: T | null, pChildIndex: number, pEaiwsItem: basket.BasketItem): T;
    private mItemMap;
    private mSelectionChanged;
    private mSelectionChangeDepth;
    private mItemUpdateDepth;
    private mItemUpdatePromise;
    private mItemUpdatePromiseResolve;
    private mCacheDepth;
    private mPropsCache;
    private mEaiwsItemCache;
    private mCalculationCache;
    private mHeaderCalculation;
    private mHeaderCalcVersion;
    private selectionChanged;
    private getUncachedItemIds;
}
