import * as basket from "../eaiws/basket";
import { ItemUpdateFlags, BaseItem } from "./BaseItem";
import type { Basket } from "./Basket";
import type { SetArticleItem } from "./SetArticleItem";
export declare class BasketItem extends BaseItem<BasketItem, Basket> {
    get basket(): Basket;
    /**
     * Returns the set if this item is part of a set.
     */
    getSetArticle(): SetArticleItem | null;
    /**
     * Sets the value a text manager text row with the given id.
     * @param pTextId Id of the text manager text
     * @param pValue New value of the text
     * @param pLanguage Which language to set. If undefined the current primary project language will be used.
     */
    setTmText(pTextId: string, pValue: string, pLanguage?: string): Promise<void>;
    /**
     * Sets the user defined image of this item.
     * @param pUrl Url of the image (supported formats: jpg and png). If `pImportIntoSession` is true this url has to
     * be an HTTP URL previously returned by the `getUploadURL()` eaiws operation and has to include a file extension.
     * Null or an empty string can be used to remove the current user image.
     * @param pImportIntoSession If true the image will be imported into session, and thus will be embedded inside the obk. (default: true)
     */
    setUserImageUrl(pUrl: string | null, pImportIntoSession?: boolean): Promise<void>;
    /**
     * Sets an additional user defined image of this item.
     * @param pIndex Index of the image to set (range: [0,9])
     * @param pUrl Url of the image (supported formats: jpg and png). If `pImportIntoSession` is true this url has to
     * be an HTTP URL previously returned by the `getUploadURL()` eaiws operation and has to include a file extension.
     * @param pImportIntoSession If true the image will be imported into session, and thus will be embedded inside the obk. (default: true)
     *
     * Note: Setting the url to null or empty will not delete the image its just set to `null`. Use `deleteAdditionalImage` function instead.
     */
    setAdditionalImageUrl(pIndex: number, pUrl: string | null, pImportIntoSession?: boolean): Promise<void>;
    /**
     * Deletes the additional image with the given index and adjusts the index of the following images.
     */
    deleteAdditionalImage(pIndex: number): Promise<void>;
    /**
     * Moves an additional image to a new position while adjusting the position of the other images.
     * Note: As a special case `-1` can be used as index to address the `UserImage`.
     */
    moveAdditionalImage(pFromIndex: number, pToIndex: number): Promise<void>;
    /**
     * Sets the external item number of this item.
     */
    setExtItemNumber(pExtItemNo: string): Promise<void>;
    /**
     * Sets comments for this item.
     */
    setComments(pComments: string): Promise<void>;
    protected get asType(): BasketItem;
    protected registerItem(): void;
    protected static BuildDisplayText(pBasket: Basket, pText: string): Promise<basket.DisplayText>;
    protected performUpdates(pFlags: ItemUpdateFlags): Promise<void>;
    private getRawAdditionalImageUrls;
}
