import * as basket from "../eaiws/basket";
import { CalculationSheetInfo, PricingProcedureInfo } from "../eaiws/basket";
import { ListenableEvent } from "../utils";
import type { Basket } from "./Basket";
import type { BasketItem } from "./BasketItem";
export declare class CalculationManager {
    /**
     * The currently active pricing procedure.
     */
    get pricingProcedure(): PricingProcedureInfo | null;
    get currency(): string;
    /** Will be triggered if the tax scheme has changed. */
    readonly eventTaxSchemeChanged: ListenableEvent<void, CalculationManager>;
    /** Will be triggered if the currency has changed. */
    readonly eventCurrencyChanged: ListenableEvent<void, CalculationManager>;
    constructor(pBasket: Basket);
    activatePricingProcedure(pPricingProcedureName: string): Promise<void>;
    setCurrency(pCurrency: string): Promise<void>;
    getTaxSchemeId(): Promise<string>;
    setTaxSchemeId(pSchemeId: string): Promise<void>;
    getTaxScheme(): Promise<basket.TaxScheme>;
    getDefaultTaxScheme(): Promise<basket.TaxScheme>;
    setTaxRate(pType: string, pCategory: string, pRate: number): Promise<void>;
    resetTaxRate(pType: string, pCategory: string): Promise<void>;
    resetTaxScheme(): Promise<void>;
    getExchangeRates(): Promise<Array<basket.ExchangeRate>>;
    getExchangeRatesMap(): Promise<Map<string, number>>;
    setExchangeRates(pRates: Array<basket.ExchangeRate>, pReferenceCurrency?: string): Promise<void>;
    getReferenceCurrency(): Promise<string>;
    setConditionDescription(pCondType: string, pLang: string | null, pDescription: string): Promise<void>;
    setItemConditionDescription(pItems: ReadonlyArray<BasketItem>, pCondType: string, pCounter: number, pLang: string | null, pDescription: string): Promise<void>;
    setConditionAmount(pItems: ReadonlyArray<BasketItem> | null, pCondType: string, pCounter: number, pAmount: number, pCurrency: string): Promise<void>;
    setQuantityRelation(pItems: ReadonlyArray<BasketItem> | null, pCondType: string, pCounter: number, pAmount: number, pUnit: string): Promise<void>;
    adjustConditionValue(pItems: ReadonlyArray<BasketItem> | null, pCondType: string, pCounter: number, pValue: number, pCurrency: string): Promise<void>;
    adjustCalculationLineAmount(pItems: ReadonlyArray<BasketItem> | null, pLevel: number, pCounter: number, pAmount: number, pCurrency: string): Promise<void>;
    adjustCalculationLineValue(pItems: ReadonlyArray<BasketItem> | null, pLevel: number, pCounter: number, pValue: number, pCurrency: string): Promise<void>;
    resetConditionAmount(pItems: ReadonlyArray<BasketItem> | null, pCondType: string, pCounter: number): Promise<void>;
    /**
     * Updates the default value of all conditions (in case it has changed) for the given items.
     * If an amount was overridden manually, it will not be changed.
     */
    updateConditionAmounts(pItems: ReadonlyArray<BasketItem>): Promise<void>;
    resetQuantityRelation(pItems: ReadonlyArray<BasketItem> | null, pCondType: string, pCounter: number): Promise<void>;
    addManualCondition(pItems: ReadonlyArray<BasketItem> | null, pCondType: string): Promise<void>;
    removeCondition(pItems: ReadonlyArray<BasketItem> | null, pCondType: string, pCounter: number): Promise<void>;
    /**
     * Returns a group calculation for the given items.
     * Note: Group calculations are not cached internally and will be requested everytime from EAIWS.
     */
    getGroupCalculation(pItems: ReadonlyArray<BasketItem>): Promise<CalculationSheetInfo>;
    private mBasket;
    private mPricingProcedure;
    private mTaxSchemeId;
    private mTaxScheme;
    private mDefaultTaxScheme;
    private mCurrency;
    private mReferenceCurrency;
    private mExchangeRates;
    private mExchangeRatesMap;
    private isPriceProcActive;
    private notifyCalculationChange;
    private resetUpToDateOfmlUpdateState;
    private containesSingleFolder;
    private getSetItemCalculationOptions;
}
