import type { EaiwsSession } from "../eaiws";
import * as basket from "../eaiws/basket";
import * as project from "../eaiws/project";
import * as session from "../eaiws/session";
import { ListenableEvent } from "../utils";
export declare class ProjectInfo {
    get session(): EaiwsSession;
    readonly eventSettingsChanged: ListenableEvent<void, ProjectInfo>;
    readonly eventProjectDataChanged: ListenableEvent<void, ProjectInfo>;
    readonly eventAppDataChanged: ListenableEvent<void, ProjectInfo>;
    readonly eventAddressDataChanged: ListenableEvent<project.AddressType, ProjectInfo>;
    readonly eventContactDataChanged: ListenableEvent<void, ProjectInfo>;
    readonly eventEffectiveProjectLanguagesChanged: ListenableEvent<void, ProjectInfo>;
    readonly eventDefaultPriceDateChanged: ListenableEvent<void, ProjectInfo>;
    constructor(pSession: EaiwsSession);
    /**
     * @obsolete
     * Should only be used for backwards compatibility.
     */
    getSettings(): Promise<session.ProjectSettings>;
    /**
     * This function can be used to change parts of the project settings. Properties which are undefined will
     * be ignored and not modified. Only properties which should be changed should have a value to reduce server load.
     * See EAIWS API documentation for further information.
     * @obsolete
     * Should only be used for backwards compatibility.
     */
    changeSettings(pSettings: session.ProjectSettings): Promise<void>;
    /**
     * Returns the project data of the current session.
     * Note: Project texts is returned in `JSON` format.
     */
    getProjectData(): Promise<project.ProjectData>;
    /**
     * This function can be used to change parts of the project data. Properties which are undefined will
     * be ignored and not modified. Only properties which should be changed should have a value to reduce server load.
     * See EAIWS API documentation for further information.
     */
    changeProjectData(pData: project.ProjectData): Promise<void>;
    /**
     * Can be used to trigger an update of the cached project data. Calling this function is only necessary if
     * the project data was modiefed without using the provided functions of this class.
     */
    notifyProjectDataChanged(): void;
    getAppData(pAppKey: string, pDataPaths: Array<string>): Promise<Map<string, string | null>>;
    setAppData(pAppKey: string, pData: Map<string, string | null>): Promise<void>;
    /**
     * Retrieves the address data with the given type. Null will be returned if the address does not exist.
     */
    getAddressData(pType: project.AddressType): Promise<project.AddressData | null>;
    /**
     * Can be used to fetch multiple address data at the same time from the server.
     * Afterwards `getAddressData()` can be used to retrieve the cached address.
     */
    fetchAddressData(pTypes: Array<project.AddressType>): Promise<void>;
    /**
     * Removes/deletes one or more addresses.
     */
    removeAddressData(pTypes: Array<project.AddressType>): Promise<void>;
    /**
     * This function can be used to change parts of an address or add a new one. Properties which are undefined will
     * be ignored and not modified. Only properties which should be changed should have a value to reduce server load.
     * See EAIWS API documentation for further information.
     */
    changeOrAddAddressData(pAddressData: project.AddressData): Promise<void>;
    /**
     * Retrieves the list of all contacts.
     */
    getContactData(): Promise<Array<project.ContactData>>;
    /**
     * This function can be used to change parts of an contact or add a new one. Properties which are undefined will
     * be ignored and not modified. Only properties which should be changed should have a value to reduce server load.
     * See EAIWS API documentation for further information.
     */
    changeOrAddContactData(pContactData: project.ContactData): Promise<void>;
    /**
     * Removes/deletes one or more contacts.
     */
    removeContactData(pContactDataIds: Array<number>): Promise<void>;
    /**
     * Retrieves the current default price date of the project.
     */
    getDefaultPriceDate(): Promise<basket.IsoDateString | undefined>;
    /**
     * Changes the default price date of the project.
     */
    setDefaultPriceDate(pDate: basket.IsoDateString): Promise<void>;
    /**
     * Resets this instance and clears internal caches.
     */
    clear(): void;
    /**
     * Returns the currently effective project languages taking into account the different fallbacks.
     */
    getEffectiveProjectLanguages(): Promise<Array<string>>;
    private mSession;
    private mSettings;
    private mSettingsLock;
    private mProjectData;
    private mProjectDataLock;
    private mAddressData;
    private mAddressDataLock;
    private mContactData;
    private mContactDataLock;
    private mBasketConfig;
    private mBasketConfigLock;
    private mAppData;
    private mAppDataLock;
    private onLanguageChanged;
    private notifyContactDataChanged;
    private notifySettingsChanged;
}
