import type { TransformNode } from "@babylonjs/core/Meshes/transformNode";
import { ElementCategory, SceneElement } from "../core/mdl";
import type { Property, PropertyClass } from "../core/prop";
import { PropertyChangedResult } from "../core/prop";
import type * as basket from "../eaiws/basket";
import type { CalculationSheetInfo } from "../eaiws/basket";
import { Interactors } from "./oap/Interactors";
import type { ArticleConfigData } from "./ArticleTypes";
import type { ArticleManager } from "./ArticleManager";
import type { MainArticleElement } from "./MainArticleElement";
import type { SubArticleElement } from "./SubArticleElement";
export declare abstract class ArticleElement extends SceneElement {
    /**
     * BasketId may be null if the article is not intantiated yes (use ensureIsInstanced()).
     * e.g. if article is a newly created clone
     */
    get basketId(): string | null;
    get category(): ElementCategory;
    /**
     * Returns false if the article (including its children) has no or an empty geometry.
     */
    get hasGeometry(): boolean;
    constructor(pBasketId: string, pManager: ArticleManager, pNode: TransformNode);
    showInteractors(pShow: boolean): void;
    dispose(): void;
    abstract isInstanced(): boolean;
    abstract ensureIsInstanced(): Promise<void>;
    abstract getMainArticle(): MainArticleElement;
    abstract getParentArticle(): ArticleElement | null;
    abstract isMainArticle(): this is MainArticleElement;
    abstract isSubArticle(): this is SubArticleElement;
    /**
     * Retrieves the article data for this article.
     * In order to retrieve the properties, the article has to be instantiated
     * on server side. This may not be possible if the ofml data is not installed or it has changed
     * (article requires migration). The operation would fail in those cases. If properties are not
     * required the noProperties option can be set to true to avoid this. (Default: false)
     */
    getArticleData(pOptions?: basket.GetArticleDataOptions): Promise<basket.ArticleData>;
    getCachedArticleData(pOptions?: basket.GetArticleDataOptions): basket.ArticleData | undefined;
    getBasketItem(): Promise<basket.BasketItem>;
    getCachedBasketItem(): basket.BasketItem | undefined;
    getItemProperties(): Promise<basket.ItemProperties>;
    getCachedItemProperties(): basket.ItemProperties | undefined;
    getCalculation(): Promise<CalculationSheetInfo>;
    getCachedCalculation(): CalculationSheetInfo | undefined;
    getCachedConfigData(): ArticleConfigData | undefined;
    getCatalogImageUrl(): Promise<string | null>;
    getSubArticles(pDirectOnly: boolean): Array<SubArticleElement>;
    getSubArticleById(pBasketId: string): SubArticleElement | null;
    setEaiwsPropertyValue(pPropClass: string, pPropName: string, pValue: string | null, pUpdateGeometry: boolean): Promise<PropertyChangedResult>;
    getProperties(): Promise<Array<Property> | null>;
    getPropertyClasses(): Promise<Array<PropertyClass> | null>;
    /**
     * Returns true if this article has interactors. E.g. OAP interactors.
     */
    hasInteractors(): Promise<boolean>;
    static GetEaiwsProperty(pProperty: Property): basket.Property | null;
    protected mBasketId: string | null;
    protected mRecoveryBasketId: string;
    protected mMngr: ArticleManager;
    protected mOapInteractors: Interactors;
    protected copyDataFrom(pElement: SceneElement): void;
    private mArticleDataLock;
    private onSetPropertyValue;
    private collectSubArticles;
    private findSubArticle;
}
