import { TransformNode } from "@babylonjs/core/Meshes/transformNode";
import type { DocumentContainer } from "../../core/io/Types";
import type { ModelManager } from "../../core/mdl/ModelManager";
import type * as basket from "../../eaiws/basket";
export declare class GfjLoader {
    onResolveUrl: ((pUrl: string) => string) | null;
    constructor(pModelManager: ModelManager);
    /**
     * Load gfj from url. Returns an array of loaded nodes.
     * @param pUrl The gfj url.
     * @param pBasketItems List of basket items (main article + sub articles) which belong to this gfj. (gfj should contain only one root object)
     * @param pContainer Optional container. If not null the gfj url should be a path to a file inside the container.
     */
    load(pUrl: string, pRootBasketId: string | null, pBasketItems: Array<basket.BasketItem> | null, pContainer?: DocumentContainer): Promise<Array<TransformNode> | null>;
    private mScene;
    private mLayerManager;
    private mGeometryManager;
    private mMaterialManager;
    private mPreloadResourcesLock;
    private mResourceLoadingLock;
    private mLoadingTexturesMap;
    private loadData;
    private preLoadResources;
    private loadObject;
    private createDummySubArticle;
    private getBasketId;
    private loadGeometry;
    private loadMaterial;
    private loadLegacyMaterialAsPbr;
    private loadPbrMaterial;
    private setTexture;
    private loadPbrMaterialTextures;
    private loadAlbedoTexture;
    private loadBumpTexture;
    private loadMetallicTexture;
    private loadRoughnessTexture;
    private loadTexture;
    private setupTextureMatrix;
    private getMaterialId;
    private getHashCode;
    private resolveUrl;
    private isPbrMaterial;
}
