import type { DocumentContainer } from "../../core/io/Types";
import type { SceneElement } from "../../core/mdl/SceneElement";
import type { View } from "../../core/view/View";
import * as basket from "../../eaiws/basket";
import type * as catalog from "../../eaiws/catalog";
import type { ProgressCallback } from "../../utils";
import type { ArticleManager } from "../ArticleManager";
export interface PecImportOptions {
    /**
     * Callback for progress handling.
     */
    onProgress?: ProgressCallback;
    /**
     * If the pec contains a camera definition and the view is given, the camera will be loaded for this view.
     * Not supported from importFromCatalog() at the moment.
     */
    view?: View;
    /**
     * Callback for article update handling.
     * If the PEC does not contain GFJ data, the GFJ will be requested from EAIWS. If an article
     * requires an update or migration this callback will be called.
     */
    shouldUpdateCallback?: (pItemProps: basket.ItemProperties) => boolean;
    /**
     * List of languages (in order of priority) used for the article texts. If the current EAIWS session is
     * valid this option will be ignored and the language settings of the session will be used.
     * Not supported from importFromCatalog(). (default: ["en"])
     */
    dataLanguage?: Array<string>;
}
export declare function importPec(pArticleManager: ArticleManager, pPecData: ArrayBuffer | Blob, pOptions?: PecImportOptions): Promise<Array<SceneElement>>;
export declare function importPecFromContainer(pArticleManager: ArticleManager, pContainer: DocumentContainer, pOptions?: PecImportOptions): Promise<Array<SceneElement>>;
export declare function importPecFromCatalog(pArticleManager: ArticleManager, pCatalogContainerItem: catalog.CatalogItem, pOptions?: PecImportOptions): Promise<Array<SceneElement>>;
