import { Vector3 } from "@babylonjs/core/Maths/math.vector";
import type { Application } from "../../core/Application";
import { AbstractTool } from "../../core/tool/AbstractTool";
import type { View } from "../../core/view/View";
import type * as basket from "./../../eaiws/basket";
import type { ArticleElement } from "../ArticleElement";
import type { Interactor } from "./Interactor";
export declare namespace DimChangeMode {
    type Axis = "x" | "y" | "z";
    type Plane = "xy" | "xz" | "yz";
    interface Context {
        article: ArticleElement;
        oapInteractorId: string;
        finishInteractorCorner: number;
    }
}
/**
 * Note: Because BabylonJS is using a left handed coordinate sytem we have to invert z-axis.
 * That means the meaning of `NZ` and `PZ` is inverted.
 */
export declare class DimChangeMode extends AbstractTool {
    constructor(pApp: Application, pContext: DimChangeMode.Context, pDimChanges: Array<basket.OAPDimChange>);
    start(pParameter: unknown): boolean;
    stop(): void;
    static GetAxis(pDim: basket.OAPDimChange): DimChangeMode.Axis;
    static GetAxisVector(pDim: basket.OAPDimChange): Vector3;
    static GetContext(pInteractor: Interactor): DimChangeMode.Context;
    static GetDirectionToCamera(pPos: Vector3, pView: View): Vector3;
    static MayStartDimChangeMode(pArticle: ArticleElement, pView: View | null, pDimChanges?: Array<basket.OAPDimChange>): boolean;
    private static GatActiveDimChanges;
    private mView;
    private mContext;
    private mDimChanges;
    private mActiveDimChanges;
    private mArticle;
    private mInteractors;
    private mArticleBounds;
    private mFeedbackNode;
    private mFeedbackMat;
    private onSelectionChanged;
    private onCameraChanged;
    private onArticleChanged;
    private createOrUpdateInteractors;
    private createFeedback;
    private needInteractorUpdate;
    private createSeparateInteractors;
    private create3rdInteractors;
    private createMultiInteractors;
    private createFinishInteractor;
    private createInteractor;
    private getSortedDimChanges;
    private getPlane;
}
