import type { ProgressCallback } from "../utils";
import { GroupedMap } from "../utils";
import type { AppDocument } from "./AppDocument";
import type { DocumentContainer, DocumentHeader } from "./io/Types";
export interface AppDocumentLoadOptions {
    /**
     * Callback for progress handling.
     */
    onProgress?: ProgressCallback;
    /**
     * Callback for document validation.
     * Will be called in the beginning of the load process to allow custom document validation.
     * The promise should be rejected if the document is not valid. In this case the loading will be aborted.
     */
    onValidateDocument?: (pDocHeader: DocumentHeader, pAppData: GroupedMap) => Promise<void>;
}
export interface AppDocumentSaveOptions {
    /**
     * Controls if geometries will be embedded in the document. (default: false)
     */
    embedGeometries?: boolean;
    /**
     * Controls if textures will be embedded in the document. (default: false)
     */
    embedTextures?: boolean;
    /**
     * Controls if app module resources will be embedded in the document. (default: true)
     */
    embedAppModuleResources?: boolean;
    /**
     * Callback for progress handling.
     */
    onProgress?: ProgressCallback;
}
export interface AppDocumentZipSaveOptions extends AppDocumentSaveOptions {
    /**
     * Level of compression for the zip file. 0 means no compression. (default: 4, range: [0, 9]).
     */
    compressionLevel?: number;
}
export declare function loadDocumentFromZip(pDocument: AppDocument, pZipData: ArrayBuffer | Blob, pOptions?: AppDocumentLoadOptions): Promise<void>;
export declare function loadDocumentFromContainer(pDocument: AppDocument, pContainer: DocumentContainer, pOptions?: AppDocumentLoadOptions): Promise<void>;
export declare function saveDocumentToZip(pDocument: AppDocument, pOptions?: AppDocumentZipSaveOptions): Promise<ArrayBuffer>;
export declare function saveDocumentToContainer(pDocument: AppDocument, pContainer: DocumentContainer, pOptions?: AppDocumentSaveOptions): Promise<void>;
