import type { AppDocumentSaveOptions } from "./AppDocumentSerialization";
import type { DataMap, DocumentInputContext, DocumentOutputContext } from "./io/Types";
export declare abstract class AppModule {
    /**
     * A unique id for each module.
     */
    abstract readonly moduleId: string;
    /**
     * Will be called from the document everytime it gets cleared.
     * Modules should clear its document related data.
     */
    clearDocumentData(): void;
    /**
     * Will be called from the document everytime after it gets loaded.
     * If the promise is rejected with a core.io.AbortError the whole document load process will be aborted.
     */
    loadDocumentData(pContext: DocumentInputContext, pData: DataMap | null): Promise<void>;
    /**
     * Will be called from the document everytime it gets saved.
     * If the promise is rejected with a core.io.AbortError the whole document save process will be aborted.
     */
    saveDocumentData(pContext: DocumentOutputContext, pOptions: AppDocumentSaveOptions): Promise<DataMap | null>;
}
