import * as ioTypes from "./io/Types";
import { deserializeNode, serializeNode } from "./io/Serialization";
import { SceneElement } from "./SceneElement";
/**
 * A simple graphical scene element which supports serialization.
 * E.g. can be used for imported models.
 */
export class BasicElement extends SceneElement {
    clone(pNewParent) {
        const tClone = new BasicElement(this.mModel, SceneElement.cloneNode(this.mNode, pNewParent));
        return (tClone);
    }
    serialize(pContext) {
        if (this.mNode == null)
            return (null);
        const tIOElement = {};
        tIOElement.classId = ioTypes.BASIC_ELEMENT_CLASSID;
        tIOElement.node = serializeNode(this.mModel, pContext, this.mNode);
        return (tIOElement);
    }
    //// internal //////////////////////////////////////////////////////////////////////////////
    /** @internal */
    static _RegisterClass(pModel) {
        pModel.registerElementLoader(ioTypes.BASIC_ELEMENT_CLASSID, (pApp, pContext, pIOElement, pParentGroup) => {
            if (pIOElement == null)
                return (null);
            const tIOElement = pIOElement;
            const tNode = deserializeNode(pApp.model, pContext, tIOElement.node, pParentGroup != null ? pParentGroup.node : null);
            if (tNode == null)
                return (null);
            return (new BasicElement(pApp.model, tNode));
        });
    }
}
