import { ImageProcessingConfiguration } from "@babylonjs/core/Materials/imageProcessingConfiguration";
import { CubeTexture } from "@babylonjs/core/Materials/Textures/cubeTexture";
import type { Scene } from "@babylonjs/core/scene";
import "@babylonjs/core/Misc/dds";
import "@babylonjs/core/Materials/Textures/Loaders/envTextureLoader";
import type { Application } from "../Application";
import type { DocumentContainer } from "../io/Types";
import type * as ioTypes from "./io/Types";
import { PbrMaterial } from "./PbrMaterial";
import { Texture } from "./Texture";
export interface ResourceTextureData {
    type: ioTypes.TextureType;
    data: ArrayBuffer | null;
    blobUrl: string | null;
}
export type EnvironmentMode = "Default" | "Planning";
export declare class MaterialManager {
    readonly defaultMaterial: PbrMaterial;
    readonly missingResourceTextures: Set<string>;
    readonly pbrImageProcessing: ImageProcessingConfiguration;
    get scene(): Scene;
    /**
     * The environment mode controls which environment map/reflection texture will be used for PBR materials.
     * `Default` = `defaultHDR_512.env`
     * `Planning` = `planningHDR_512.env`
     */
    get environmentMode(): EnvironmentMode;
    set environmentMode(pMode: EnvironmentMode);
    /**
     * Url of a custom environment map/reflection texture which will be used instead of the predefined ones.
     * Only BabylonJs `.env` files are suppoted. If defined the `environmentMode` will be ignored.
     */
    get customEnvironmentUrl(): string | null;
    set customEnvironmentUrl(pUrl: string | null);
    constructor(pApp: Application);
    addMaterial(pId: string, pMaterial: PbrMaterial): boolean;
    getMaterial(pId: string): PbrMaterial | null;
    hasMaterial(pId: string): boolean;
    clear(): void;
    getTexture(pId: string): Texture | null;
    hasTexture(pId: string): boolean;
    /**
     * Creates a persistent texture.
     * If a container is given, the url should be a path to a texture inside the container.
     */
    createResourceTexture(pId: string, pUrl: string, pHasAlpha?: boolean, pContainer?: DocumentContainer): Promise<Texture>;
    /** Returnes the data of a resource texture */
    getResourceTextureData(pTextureId: string): ResourceTextureData | null;
    /**
     * Creates a runtime only texture.
     */
    createTexture(pId: string, pUrl: string, pHasAlpha?: boolean): Texture;
    waitUntilTexturesLoaded(): Promise<void>;
    getDefaultReflectionTexture(): CubeTexture;
    private static readonly CACHE_CLEANUP_INTERVAL;
    private mScene;
    private mApp;
    private mMaterials;
    private mTextures;
    private mResourceTextures;
    private mDefaultReflectionTexture;
    private mLastCacheCleanUp;
    private mLoadTexturesCount;
    private mLoadTexturesPromise;
    private mLoadTexturesPromiseResolve;
    private mMaxAnisotropy;
    private mEnvMode;
    private mCustomEnvUrl;
    private onDisposeMaterial;
    private onDisposeTexture;
    private isTextureSupported;
    private cleanUpMaterialCache;
    private cleanUpTextureCache;
    private startLoadTexture;
    private finishLoadTexture;
}
