import type { AbstractMesh } from "@babylonjs/core/Meshes/abstractMesh";
import type { Node } from "@babylonjs/core/node";
import { Scene } from "@babylonjs/core/scene";
import { ListenableEvent } from "../../utils";
import type { Application } from "../Application";
import type { DocumentInputContext } from "../io/Types";
import type { MultiPropertyProvider } from "../prop/MultiPropertyProvider";
import { GeometryManager } from "./GeometryManager";
import type { GroupElement } from "./GroupElement";
import type * as ioTypes from "./io/Types";
import { LayerManager } from "./LayerManager";
import { MaterialManager } from "./MaterialManager";
import type { SceneElement } from "./SceneElement";
export type SceneElementLoader = (pApp: Application, pContext: DocumentInputContext, pIOElement: ioTypes.SceneElement, pParentGroup: GroupElement | null) => SceneElement | null;
export declare class ModelManager {
    get app(): Application;
    get scene(): Scene;
    get geometries(): GeometryManager;
    get materials(): MaterialManager;
    get layers(): LayerManager;
    /**
     * array of top level scene elements
     */
    get elements(): ReadonlyArray<SceneElement>;
    /**
     * array of selected scene elements
     */
    get selection(): ReadonlyArray<SceneElement>;
    get selectionProperties(): MultiPropertyProvider;
    /**
     * This mesh array contains all meshes which belong to the scene and are not disposed (but maybe removed from the scene).
     * The difference between this and Scene.meshes is that Scene.meshes does not
     * contain meshes which were removed from the scene.
     */
    get meshInstances(): Array<AbstractMesh>;
    readonly eventSelectionChanged: ListenableEvent<void, ModelManager>;
    readonly eventModified: ListenableEvent<void, ModelManager>;
    readonly eventBeginTransformElements: ListenableEvent<void, ModelManager>;
    readonly eventEndTransformElements: ListenableEvent<void, ModelManager>;
    constructor(pApp: Application);
    addElement(pElement: SceneElement, pNodeParent?: Node | null, pAddToScene?: boolean): void;
    removeElement(pElement: SceneElement, pRemoveFromScene?: boolean, pDisposeElement?: boolean): void;
    clear(): void;
    setSelection(pSelection: ReadonlyArray<SceneElement> | null): boolean;
    addToSelection(pElement: SceneElement): boolean;
    removeFromSelection(pElement: SceneElement): boolean;
    /**
     * Selects a sub element for the given main element. The main element has to be selected already.
     */
    setSubElementSelection(pMainElement: SceneElement, pSubElement: SceneElement | null): boolean;
    getSubElementSelection(pMainElement: SceneElement): SceneElement | null;
    /**
     * Selects and returns the parent selectable sub element based on the current sub element
     * selection for the given main element. If no sub element is found the main element will
     * be selected and null will be returned.
     */
    selectParentSubElement(pMainElement: SceneElement): SceneElement | null;
    clearSubElementSelection(): void;
    hasSubElementSelection(): boolean;
    validateSelection(): void;
    beginSelectionChange(): void;
    endSelectionChange(): void;
    notifyModification(): void;
    beginModification(): void;
    endModification(): void;
    registerElementLoader(pClassId: string, pLoader: SceneElementLoader): void;
    getElementLoader(pClassId: string): SceneElementLoader | null;
    static readonly NODEDATA_MESHADDED = "core:meshAddedToModel";
    private mApp;
    private mScene;
    private mGeometryManager;
    private mMaterialManager;
    private mLayerManager;
    private mElements;
    private mMeshInstances;
    private mCleanUpCachesOnDispose;
    private mSelection;
    private mSubElementSelection;
    private mSelectionProperties;
    private mSelectionChanged;
    private mSelectionChangeDepth;
    private mModified;
    private mModificationDepth;
    private mLoaders;
    private onMeshAddedToScene;
    private onMeshDisposed;
    private selectionChanged;
    private getSelectedProviders;
}
