import { isNullOrEmpty } from "../../utils/string";
export class ResourceCache {
    constructor() {
        this.mCache = new Map();
        this.onDisposeResource = null;
    }
    has(pKey) {
        return (this.mCache.has(pKey));
    }
    add(pKey, pResource) {
        if (isNullOrEmpty(pKey))
            return (false);
        this.mCache.set(pKey, { data: pResource, lastUsed: Date.now() });
        return (true);
    }
    get(pKey) {
        if (isNullOrEmpty(pKey))
            return (null);
        const tResource = this.mCache.get(pKey);
        if (tResource != null) {
            tResource.lastUsed = Date.now();
            return (tResource.data);
        }
        else
            return (null);
    }
    remove(pKey, pDispose = true) {
        if (isNullOrEmpty(pKey))
            return (false);
        if (pDispose && this.onDisposeResource != null) {
            const tResource = this.mCache.get(pKey);
            if (tResource != null)
                this.onDisposeResource(tResource.data, false);
        }
        return (this.mCache.delete(pKey));
    }
    forEach(pCallback) {
        this.mCache.forEach((pResource, pKey, pMap) => {
            pCallback(pKey, pResource.data);
        });
    }
    clear(pDispose = true) {
        if (pDispose && this.onDisposeResource != null)
            this.mCache.forEach((pRes) => this.onDisposeResource(pRes.data, true));
        this.mCache.clear();
    }
    removeUnused(pUsedResources, pMaxTimeUnused, pDispose = true) {
        if (pUsedResources == null)
            return;
        const tNow = Date.now();
        this.mCache.forEach((pResource, pKey, pMap) => {
            if (!pUsedResources.has(pKey)) {
                if (tNow - pResource.lastUsed > pMaxTimeUnused) {
                    this.remove(pKey, pDispose);
                }
            }
        });
    }
}
