import type { Color3, Quaternion, Vector2, Vector3 } from "../../io/Types";
export declare const BASIC_ELEMENT_CLASSID = "egr.wcf.core:BasicElement";
export interface Model {
    elements: Array<SceneElement>;
    layers: Array<Layer>;
    geometries: Array<Geometry>;
    textures: Array<Texture>;
    materials: Array<Material>;
}
export interface SceneElement {
    classId: string;
}
export interface BasicElement extends SceneElement {
    node: ElementNode;
}
export interface ElementNode {
    position?: Vector3;
    rotation?: Quaternion;
    scale?: Vector3;
    layer?: number;
    geometry?: number;
    material?: number;
    nodes?: Array<ElementNode>;
}
export interface Geometry {
    id: string;
    boundMin: Vector3;
    boundMax: Vector3;
}
export interface Layer {
    name: string;
    visible?: boolean;
}
export type TextureType = "jpg" | "png";
export interface Texture {
    id: string;
    type?: TextureType;
    name?: string;
    transparent?: boolean;
}
export type MaterialType = "std" | "pbr";
export interface Material {
    id: string;
    name?: string;
    type?: MaterialType;
}
export interface StdMaterial extends Material {
    diffuse?: Color3;
    specular?: Color3;
    emissive?: Color3;
    shininess?: number;
    reflectivity?: number;
    alpha?: number;
    diffuseTexture?: TextureMap;
    bumpTexture?: TextureMap;
}
export interface PbrMaterial extends Material {
    albedo?: Color3;
    emissive?: Color3;
    metallic?: number;
    roughness?: number;
    alpha?: number;
    alphaTest?: boolean;
    albedoTexture?: TextureMap;
    bumpTexture?: TextureMap;
    metallicTexture?: TextureMap;
    roughnessTexture?: TextureMap;
}
export interface TextureMap {
    texture: number;
    offset?: Vector2;
    scale?: Vector2;
    rotation?: Vector3;
}
