import { ListenableEvent } from "../../utils";
import type { Application } from "../Application";
import type { Property, PropertyClass, PropertyValue, PropertyValueType } from "./Property";
import type { PropertyProvider } from "./PropertyProvider";
import { PropertyChangedResult } from "./PropertyProvider";
export declare const PropertyMergeMode: {
    readonly Intersection: 0;
    readonly Union: 1;
};
export type PropertyMergeMode = typeof PropertyMergeMode[keyof typeof PropertyMergeMode];
export type MultiPropertyProviderProgressHandler = (pFinshed: number, pTotal: number) => boolean;
export declare class MultiPropertyProvider implements PropertyProvider {
    get providers(): ReadonlyArray<PropertyProvider>;
    get mergeMode(): PropertyMergeMode;
    readonly eventPropertiesChanged: ListenableEvent<PropertyChangedResult, PropertyProvider>;
    constructor(pApp: Application | null);
    setProviders(pProviders: ReadonlyArray<PropertyProvider>): void;
    setMergeMode(pMode: PropertyMergeMode): void;
    getProperties(pProgressHandler?: MultiPropertyProviderProgressHandler): Promise<Array<Property>>;
    getPropertyClasses(pProgressHandler?: MultiPropertyProviderProgressHandler): Promise<Array<PropertyClass>>;
    /** Returning the same result as `Property.getChoices()` but with an abortable progress. */
    getPropertyChoices(pMultiProperty: Property, pProgressHandler?: MultiPropertyProviderProgressHandler): Promise<Array<PropertyValue> | null>;
    beginPropertyChange(): void;
    endPropertyChange(): void;
    setPropertyValueUndoable(pMultiProperty: Property, pValue: PropertyValueType, pProgressHandler?: MultiPropertyProviderProgressHandler): Promise<PropertyChangedResult>;
    /**
     * Returnes true if the merged properties of the given multi property do not have an equal value.
     */
    isPropertyValueUndetermined(pMultiProperty: Property): boolean;
    protected mApp: Application | null;
    protected beginSetPropertyValue(): void;
    protected endSetPropertyValue(): void;
    protected finalizeSetPropertyValue(): Promise<void>;
    private static readonly SUB_PROPERTIES;
    private static readonly MAX_CONCURRENT_TASKS;
    private static readonly MAX_CONCURRENT_SET_PROPVALUE;
    private mProviders;
    private mMergeMode;
    private mPropertyListNeedsUpdate;
    private mPropertyValuesNeedUpdate;
    private mPropertyChangeDepth;
    private mPropertyChangedState;
    private mProperties;
    private mPropertyClasses;
    private mPropertyMap;
    private mPropertyValueMap;
    private mPropertyListPromise;
    private propertiesChanged;
    private registerProviderEvents;
    private deregisterProviderEvents;
    private updatePropertyList;
    private updatePropertyValues;
    private clearPropertyList;
    private addProviderClasses;
    private addProviderProperties;
    private buildPropertyList;
    private buildProperty;
    private setPropertyValue;
    private getPropertyValue;
    private internalGetPropertyChoices;
    private getSubProperties;
    private onPropertiesChanged;
}
