import { clone } from "../../utils/array";
import { isNotNullOrEmpty } from "../../utils/string";
import { DEFAULT_PROPERTYCLASS_KEY, PropertyClass } from "./Property";
/**
 * Groups the provided properties according to their class and merges classes with identical names.
 * Empty groups will be removed.
 */
export function groupProperties(pProperties, pPropertyClasses, pOptions) {
    if (pProperties == null || pProperties.length === 0) {
        return ([]);
    }
    const tPropertyClasses = pPropertyClasses != null ? clone(pPropertyClasses) : new Array();
    //add default property class
    let tDefaultClass = tPropertyClasses.find((tClass) => tClass.key === DEFAULT_PROPERTYCLASS_KEY);
    if (tDefaultClass == null) {
        tDefaultClass = new PropertyClass();
        tDefaultClass.key = DEFAULT_PROPERTYCLASS_KEY;
        tPropertyClasses.push(tDefaultClass);
    }
    tDefaultClass.name = pOptions.defaultClassName; //adjust the name of the default class
    //build class maps, used to merge property classes with equal name
    const tClassKeyNameMap = new Map(); //key -> name
    const tMergedClasses = new Map(); //name -> key
    for (const tClass of tPropertyClasses) {
        const tName = tClass.getName();
        tClassKeyNameMap.set(tClass.key, tName);
        if (pOptions.mergeClassesWithIdenticalName !== false) {
            if (!tMergedClasses.has(tName)) {
                tMergedClasses.set(tName, tClass.key);
            }
        }
    }
    //map from class key to properties
    const tPropMap = new Map();
    for (const tProp of pProperties) {
        if (tProp.visible) {
            let tClass = tProp.class;
            if (isNotNullOrEmpty(tClass)) {
                //get class with identical name from map
                const tClassName = tClassKeyNameMap.get(tClass); //get name for current class
                if (tClassName != null) {
                    const tClassByName = tMergedClasses.get(tClassName);
                    if (tClassByName != null) {
                        tClass = tClassByName; //use merged class
                    }
                }
                else {
                    //class unknown -> fallback to default class
                    tClass = DEFAULT_PROPERTYCLASS_KEY;
                }
            }
            else {
                //fallback to default class
                tClass = DEFAULT_PROPERTYCLASS_KEY;
            }
            let tProperties = tPropMap.get(tClass);
            if (tProperties == null) {
                tProperties = new Array();
                tPropMap.set(tClass, tProperties);
            }
            tProperties.push(tProp);
        }
    }
    //build result
    const tGroups = new Array();
    for (const tClass of tPropertyClasses) {
        const tProps = tPropMap.get(tClass.key);
        if (tProps != null && tProps.length > 0) {
            tGroups.push({
                class: tClass,
                poperties: tProps
            });
        }
    }
    return (tGroups);
}
