import type { ListenableEvent } from "../../utils";
import type { Property, PropertyClass } from "./Property";
export declare const PropertyChangedResult: {
    /** nothing changed */
    readonly Nothing: 0;
    /** the value of one or more properties has changed */
    readonly Value: 1;
    /** the list of properties or the state of properties (visible, editable) has changed */
    readonly Properties: 2;
    /** the list of providers has changed (used from MultiPropertyProvider) */
    readonly Providers: 3;
};
export type PropertyChangedResult = typeof PropertyChangedResult[keyof typeof PropertyChangedResult];
export interface PropertyProvider {
    /**
     * Should be triggered if the list of properties, the value or the state (visible, editable)
     * of one or more properties has changed.
     */
    readonly eventPropertiesChanged: ListenableEvent<PropertyChangedResult, PropertyProvider>;
    getProperties(): Promise<Array<Property> | null>;
    getPropertyClasses(): Promise<Array<PropertyClass> | null>;
    beginPropertyChange(): void;
    endPropertyChange(): void;
}
