import "@babylonjs/core/Lights/Shadows/shadowGeneratorSceneComponent";
import type { Application } from "../Application";
import { ShadowGenerator } from "./ShadowGenerator";
export declare class ShadowMapping implements ShadowGenerator {
    get enabled(): boolean;
    /**
     * Defines the softness of the shadows.
     * @range [0, 0.5]
     * @defaulValue 0.1
     */
    get softness(): number;
    set softness(pValue: number);
    /**
     * Altitude of the shadow light in degree.
     * @range [0, 90]
     * @defaulValue 65
     */
    get altitude(): number;
    set altitude(pValue: number);
    /**
     * Azimuth of the shadow light in degree.
     * @range [-360, 360]
     * @defaulValue -50
     */
    get azimuth(): number;
    set azimuth(pValue: number);
    /**
     * Creates a ShadowMapping instance. Only a single instance should be used at runtime.
     * @param pResolution Resolution of the shadw map. Can be increased for bigger scenes. (default: 2048)
     */
    constructor(pApp: Application, pResolution?: 2048 | 4096);
    dispose(): void;
    setEnabled(pEnabled: boolean): void;
    notifyModelInteraction(): void;
    prepareRenderFrame(pMultiSamplingStep: number, pMaxSteps: number): void;
    finalizeRenderFrame(pMultiSamplingStep: number, pMaxSteps: number): void;
    private static readonly sShadowSamplingOffsets;
    private mApp;
    private mScene;
    private mSoftness;
    private mAltitude;
    private mAzimuth;
    private mDummyMesh;
    private mShadowGenerator;
    private mShadowsNeedUpdate;
    private onModelModified;
    private onViewerBeforeRender;
    private onCameraBeforeRender;
    private createShadowGenerator;
    private addMeshToRenderList;
    private updateShadows;
}
