import type { Application } from "../Application";
import { ShadowGenerator } from "./ShadowGenerator";
/**
 * The ShadowPlaneResolution can be used to control the shadow quality.
 * With increasing scene size the shadows will get more blurry. The resolution can be increased to reduce this effect.
 * Values higher 1024 shouldn't be used on mobile devices.
 */
export type ShadowPlaneResolution = 512 | 1024 | 2048 | 4096;
export declare class ShadowPlane implements ShadowGenerator {
    get planeYOffset(): number;
    set planeYOffset(pOffset: number);
    get planeYPosition(): number;
    get transparency(): number;
    get enabled(): boolean;
    constructor(pApp: Application, pResolution?: ShadowPlaneResolution);
    dispose(): void;
    setEnabled(pEnabled: boolean): void;
    setPlaneYPosition(pPos: number): void;
    setTransparency(pTransparency: number): void;
    notifyModelInteraction(): void;
    prepareRenderFrame(pMultiSamplingStep: number, pMaxSteps: number): void;
    finalizeRenderFrame(pMultiSamplingStep: number, pMaxSteps: number): void;
    private static readonly REFERENCE_RATIO;
    private static readonly CAMERA_Y_OFFSET;
    private mApp;
    private mScene;
    private mPlane;
    private mPlaneMaterial;
    private mCamera;
    private mPosY;
    private mTransparency;
    private mPlaneSize;
    private mMinPlaneSize;
    private mRenderTarget;
    private mDepthMaterial;
    private mDummyMesh;
    private mShadowsNeedUpdate;
    private mEnabled;
    private mShadowUpdateTimeout;
    private onModelModified;
    private onWebGLContextRestored;
    private onViewerBeforeRender;
    private clearUpdateTimeout;
    private addMeshToRenderList;
    private updateShadows;
    private createCamera;
    private createRenderTarget;
    private createPlane;
    private updatePlaneSize;
}
