import type { Application } from "../Application";
import type { InputState } from "../view/InputState";
import { AbstractTool } from "./AbstractTool";
/**
 * Selection mode of the rectangle select tool.
 * - `Complete`: elements have to be completely inside of the rectangle to be selected
 * - `Partial`: elements have to be partially inside of the rectangle to be selected
 * - `Both`: if rectangle is drawn from left to right `Complete` will be used, otherwise `Partial`
 */
export type RectangleSelectMode = "Complete" | "Partial" | "Both";
export declare class RectangleSelect extends AbstractTool {
    multiSelectMode: boolean;
    mode: RectangleSelectMode;
    constructor(pApp: Application);
    start(pParameter: unknown): boolean;
    stop(): void;
    handlePointerDown(pEvent: PointerEvent, pState: InputState): void;
    handlePointerMove(pEvent: PointerEvent, pState: InputState): void;
    handlePointerUp(pEvent: PointerEvent, pState: InputState): void;
    private mRectDiv;
    private mView;
    private mPartialMode;
    private setPartialMode;
    private applyRectDivColor;
    private select;
    private maySelectElement;
    private isNodeCompletelyInFrustum;
    private isNodePartiallyInFrustum;
    private triangleRectIntersects;
    private segmentRectIntersects;
}
