import { Matrix, Vector2, Vector3 } from "@babylonjs/core/Maths/math.vector";
import { ListenableEvent } from "../../utils";
import type { Application } from "../Application";
import { BoundingBox } from "../mdl/BoundingBox";
import { SceneElement } from "../mdl/SceneElement";
import type { InputState } from "../view/InputState";
import { PointerInfo } from "../view/InputState";
import type { View } from "../view/View";
import { AbstractTool } from "./AbstractTool";
import type { RectangleSelectMode } from "./RectangleSelect";
import { InteractionMode } from "./Tool";
export declare class SelectionInfo {
    bounds: BoundingBox;
    worldMatrix: Matrix;
    canRotate: boolean;
    canTranslate: boolean;
    canDelete: boolean;
    worldBounds: BoundingBox;
    worldPoints: Array<Vector3>;
    constructor();
    update(): void;
}
export declare class SelectionDefault extends AbstractTool {
    get multiSelectMode(): boolean;
    set multiSelectMode(pEnabled: boolean);
    /** if true the multi selection mode is started automatically if the user pressed ctrl or used long touch on an element (default: false) */
    multiSelectAutoStartEnabled: boolean;
    /** if false its not possible to deselect all elements by clicking on the background in multi select mode (default: true) */
    multiSelectDeselectAllEnabled: boolean;
    /** enable/disable selection of sub elements */
    subElementSelectionEnabled: boolean;
    /** if false deselection is not possible, atleast one element always stays selected */
    deselectionEnabled: boolean;
    /**
     * If true the rectangle selection will be started using with left mouse button. (default: false)
     * The flag `view.CameraControl.leftMouseButtonEnabled` should be set to false in this case.
     * Note: One finger touch will not start rectangle selection.
     */
    leftMouseButtonRectangleSelectEnabled: boolean;
    /** Selection mode of the rectangle select tool  (default: `Complete`) */
    rectangleSelectMode: RectangleSelectMode;
    get showMainElementSelection(): boolean;
    set showMainElementSelection(pShow: boolean);
    get showSubElementSelection(): boolean;
    set showSubElementSelection(pShow: boolean);
    get showElementInteractors(): boolean;
    set showElementInteractors(pShow: boolean);
    readonly eventRectangleSelectFinished: ListenableEvent<void, SelectionDefault>;
    /**
     * Will be triggered (after the double click delay) if the user clicks/tabs
     * on the background and there is currently no selection.
     */
    readonly eventBackgroundClick: ListenableEvent<void, SelectionDefault>;
    /** Will be triggered immediately if the user clicks/tabs on the background and there is currently no selection. */
    readonly eventBackgroundClickImmediate: ListenableEvent<void, SelectionDefault>;
    /** Will be triggered if the user clicks/tabs on a SceneElement. */
    readonly eventElementClick: ListenableEvent<SceneElement, SelectionDefault>;
    /** Will be triggered if the state of the multi selection mode has changed. */
    readonly eventMultiSelectModeChanged: ListenableEvent<void, SelectionDefault>;
    constructor(pApp: Application);
    getInteractionMode(): InteractionMode;
    start(pParameter: unknown): boolean;
    stop(): void;
    handlePointerDown(pEvent: PointerEvent, pState: InputState): void;
    handlePointerMove(pEvent: PointerEvent, pState: InputState): void;
    handlePointerUp(pEvent: PointerEvent, pState: InputState): void;
    startRectangleSelect(): void;
    protected mView: View;
    protected mSelection: Array<SceneElement>;
    protected mSelectionInfo: SelectionInfo;
    protected mPickedElement: SceneElement | null;
    protected mPickedPos: Vector3;
    protected updateInteractors(pOnlyCameraChanged: boolean): void;
    protected updateInteractorHover(pPos: Vector2): void;
    protected pickInteractors(pPointer: PointerInfo): boolean;
    protected startPointerMoveTool(pEvent: PointerEvent, pState: InputState): void;
    protected getDirectionToCamera(pPos: Vector3, pView: View): Vector3;
    private static readonly PICK_FRUSTUM_SIZE;
    private static readonly SELECTION_BOX_OFFSET;
    private static readonly LONG_TOUCH_TIMEOUT;
    private mSelectionBoxSides;
    private mSelectionBoxSideGeom;
    private mInteractorElements;
    private mSelectionChanged;
    private mCameraChanged;
    private mCameraModeChanged;
    private mMultiSelectMode;
    private mHandleSelection;
    private mHandleClick;
    private mShowMainElementSelection;
    private mShowSubElementSelection;
    private mShowElementInteractors;
    private mRectSelectTool;
    private mBackgroundClickTimer;
    private mLongTouchTimer;
    private onSelectionChanged;
    private onCameraChanged;
    private onCameraModeChanged;
    private onBeforeRender;
    private onBeforeRenderCamera;
    private onTriggerBackgroundClick;
    private onHandleLongTouch;
    private resetBackgroundClickTimer;
    private resetLongTouchTimer;
    private pointerWasMoved;
    private setMultiSelectMode;
    private handleSelection;
    private getPickedElement;
    private clearSelection;
    private updateSelectionIfRunning;
    private updateSelection;
    private prepareSelectionBoxSides;
    private prepareSelectionBoxSide;
    private createSelectionBox;
    private updateSelectionBoxSides;
    private startPointerDownRectangleSelect;
    private resetPickingStates;
}
