import { Vector2 } from "@babylonjs/core/Maths/math.vector";
import type { Application } from "../Application";
import type { View } from "../view/View";
/**
 * The SelectionMenu can be used to provide a custom menu for the selected SceneElements.
 * A show and hide callback has to be provided to implement the custom menu.
 * The SelectionMenu only works in combination with a default tool derived from the SelectionDefault tool.
 */
export declare class SelectionMenu {
    get active(): boolean;
    set active(pValue: boolean);
    /**
     * If true the menu gets deactivated as sonn as a tool other than the default tool gets started. (default: true)
     */
    deactivateOnToolStart: boolean;
    /**
     * Creates and registers a new SelectionMenu.
     * @param pApp Reference to the core application.
     * @param pShowCallback Called if the menu should be shown. A 2d bounding rect in viewer coordinates is given for the current selection.
     * @param pHideCallback Called if the menu should be hidden.
     */
    constructor(pApp: Application, pShowCallback: (pRectMin: Vector2, pRectMax: Vector2, pView: View) => void, pHideCallback: () => void);
    /** Disposes this menu. */
    dispose(): void;
    private mApp;
    private mView;
    private mVisible;
    private mActive;
    private mCameraTimeout;
    private mShowCallback;
    private mHideCallback;
    private onElementClicked;
    private onToolStarted;
    private onInteractorTriggered;
    private onSelectionChanged;
    private onCameraChanged;
    private setActive;
    private hide;
    private resetCameraTimeout;
    private show;
}
