import { Vector3 } from "@babylonjs/core/Maths/math.vector";
import { projectPointOnLine3 } from "../utils/MathUtils";
export class SnapLine {
    get point1() {
        return (this.mPoint1);
    }
    get point2() {
        return (this.mPoint2);
    }
    get direction() {
        return (this.mDirection);
    }
    constructor(pPoint1, pPoint2, pIsSegment = false) {
        this.mPoint1 = pPoint1;
        this.mPoint2 = pPoint2;
        this.locked = false;
        this.isSegment = pIsSegment;
        this.updateDirection();
    }
    setPoint1(pPoint) {
        this.mPoint1 = pPoint;
        this.updateDirection();
    }
    setPoint2(pPoint) {
        this.mPoint2 = pPoint;
        this.updateDirection();
    }
    static FromAxis(pOrigin, pAxis) {
        return (new SnapLine(pOrigin, pOrigin.add(pAxis)));
    }
    /**
     * Find nearest snap line. If pView is null pSnapDistance will be handled as meter otherwise as pixel.
     */
    static Snap(pPos, pLines, pView, pSnapDistance = 15) {
        if (pPos == null || pLines == null)
            return (null);
        let tNearestLine = null;
        let tDistance = 0;
        let tNewPos = null;
        for (const tLine of pLines) {
            const tProjPos = projectPointOnLine3(pPos, tLine.mPoint1, tLine.mPoint2, tLine.isSegment);
            if (tProjPos == null)
                continue;
            //check if line is locked and return immediately
            if (tLine.locked) {
                return ({
                    pos: tProjPos,
                    line: tLine
                });
            }
            const tD = Math.abs(Vector3.DistanceSquared(pPos, tProjPos));
            if (tNearestLine == null || tD < tDistance) {
                tNewPos = tProjPos;
                tNearestLine = tLine;
                tDistance = tD;
            }
        }
        if (tNearestLine == null || tNewPos == null)
            return (null);
        let tSnappedDistance = null;
        if (pView != null) {
            //use pixel distance
            tSnappedDistance = pView.projectedDistance(pPos, tNewPos);
        }
        else {
            //use meter distance
            tSnappedDistance = Math.sqrt(tDistance);
        }
        if (tSnappedDistance != null && tSnappedDistance < pSnapDistance) {
            return ({
                pos: tNewPos,
                line: tNearestLine
            });
        }
        return (null);
    }
    updateDirection() {
        this.mDirection = this.mPoint2.subtract(this.mPoint1);
        this.mDirection.normalize();
    }
}
