import type { Ray } from "@babylonjs/core/Culling/ray";
import type { Plane } from "@babylonjs/core/Maths/math.plane";
import { Quaternion, Vector2, Vector3, Vector4 } from "@babylonjs/core/Maths/math.vector";
export declare const VECTOR2_X: Vector2;
export declare const VECTOR2_Y: Vector2;
export declare const VECTOR3_ZERO: Vector3;
export declare const VECTOR3_MIN: Vector3;
export declare const VECTOR3_MAX: Vector3;
export declare const VECTOR3_X: Vector3;
export declare const VECTOR3_Y: Vector3;
export declare const VECTOR3_Z: Vector3;
/**
 * A frustum is defined as an array of the 6 frustum planes.
 */
export type Frustum = Array<Plane>;
export declare const Orientation: {
    readonly Collinear: 0;
    readonly Clockwise: 1;
    readonly CounterClockwise: 2;
};
export type Orientation = typeof Orientation[keyof typeof Orientation];
export declare class Rectangle {
    min: Vector2;
    max: Vector2;
    constructor(pP1: Vector2, pP2: Vector2);
    set(pP1: Vector2, pP2: Vector2): Rectangle;
}
export declare function intersectRayPlane(pRay: Ray, pPlane: Plane): Vector3 | null;
export declare function intersectLineLine2(pS1: Vector2, pE1: Vector2, pS2: Vector2, pE2: Vector2): Vector2 | null;
export declare function angleBetweenVectors2(pV1: Vector2, pV2: Vector2): number;
export declare function angleBetweenVectors3(pV1: Vector3, pV2: Vector3): number;
/**
 * Returns a signed 360° angle, range (-PI, PI).
 */
export declare function signedAngleBetweenVectors2(pV1: Vector2, pV2: Vector2): number;
/**
 * Returns a signed 360° angle, range (-PI, PI).
 */
export declare function signedAngleBetweenVectors3(pV1: Vector3, pV2: Vector3, pPlaneNormal: Vector3): number;
/**
 * Normalizes an angle to be in range (0, 2PI) or (-2PI, 2PI) if pSigned is true.
 */
export declare function normalizeAngle(pAngle: number, pSigned: boolean): number;
/**
 * Returns the shortest distance (signed) between 2 angles.
 */
export declare function angleDistance(pAngle1: number, pAngle2: number): number;
export declare function quaternionToAxisAngle(pQ: Quaternion): Vector4;
/**
 * Returns a rotation for a target coordinate system.
 * The 3 given axes need to be normalized and orthogonal to each other.
 */
export declare function quaternionFromAxes(pX: Vector3, pY: Vector3, pZ: Vector3): Quaternion;
/**
 * Returns a rotation for a target coordinate system.
 * The 3 given axes need to be normalized and orthogonal to each other.
 */
export declare function quaternionFromAxesToRef(pX: Vector3, pY: Vector3, pZ: Vector3, pResult: Quaternion): void;
export declare function rotateVector2(pV: Vector2, pAngle: number): Vector2;
export declare function rotateVector2ToRef(pV: Vector2, pAngle: number, pResult: Vector2): void;
export declare function rotateVector3(pV: Vector3, pRot: Quaternion): Vector3;
export declare function rotateVector3ToRef(pV: Vector3, pRot: Quaternion, pResult: Vector3): void;
/**
 * Returns a vector which is perpendicular to pV.
 */
export declare function perpendicularVector2(pV: Vector2): Vector2;
/**
 * Returns a "random" vector which is perpendicular to pV.
 */
export declare function perpendicularVector3(pV: Vector3): Vector3;
export declare function projectPointOnPlane(pP: Vector3, pPlane: Plane): Vector3;
export declare function projectPointOnLine2(pP: Vector2, pLS: Vector2, pLE: Vector2, pAsSegment?: boolean): Vector2;
export declare function projectPointOnLine2ToRef(pP: Vector2, pLS: Vector2, pLE: Vector2, pAsSegment: boolean, pResult: Vector2): void;
export declare function projectPointOnLine3(pP: Vector3, pLS: Vector3, pLE: Vector3, pAsSegment?: boolean): Vector3;
export declare function projectPointOnLine3ToRef(pP: Vector3, pLS: Vector3, pLE: Vector3, pAsSegment: boolean, pResult: Vector3): void;
export declare function orientationToLine2(pP: Vector2, pLS: Vector2, pLE: Vector2): Orientation;
export declare function triangleNormal(pP1: Vector3, pP2: Vector3, pP3: Vector3): Vector3;
export declare function triangleNormalToRef(pP1: Vector3, pP2: Vector3, pP3: Vector3, pResult: Vector3): void;
/**
 * Returns true if the point is lying inside the frustum.
 */
export declare function isPointInFrustum(pP: Vector3, pFrustum: Frustum): boolean;
/**
 * This functions performs only a fast check.
 * Returns false if the triangle is definitely outside of the frustum. If true is returned the
 * triangle MAY be inside of the frustum.
 */
export declare function isTriangleInFrustum(pP1: Vector3, pP2: Vector3, pP3: Vector3, pFrustum: Frustum): boolean;
export declare function isPointInSegmentBounds2(pP: Vector2, pSS: Vector2, pSE: Vector2): boolean;
export declare function isPointOnSegment2(pP: Vector2, pSS: Vector2, pSE: Vector2): boolean;
export declare function isPointInTriangle2(pPoint: Vector2, pP1: Vector2, pP2: Vector2, pP3: Vector2): boolean;
/**
 * Returns true if point 1, 2 and 3 are collinear.
 */
export declare function isCollinear2(pP1: Vector2, pP2: Vector2, pP3: Vector2): boolean;
export declare function isMirrorScaling3(pScale: Vector3): boolean;
/**
 * Returns true if line 1 is parallel to line 2.
 */
export declare function isParallel2(pS1: Vector2, pE1: Vector2, pS2: Vector2, pE2: Vector2): boolean;
export declare function segmentsIntersecting2(pS1: Vector2, pE1: Vector2, pS2: Vector2, pE2: Vector2): boolean;
export declare function rectanglesIntersecting(pR1: Rectangle, pR2: Rectangle): boolean;
export declare function segmentRectangleIntersecting(pP1: Vector2, pP2: Vector2, pRect: Rectangle): boolean;
export declare function triangleRectangleIntersecting(pP1: Vector2, pP2: Vector2, pP3: Vector2, pRect: Rectangle): boolean;
