import { Matrix, Quaternion, Vector3 } from "@babylonjs/core/Maths/math.vector";
import type { TransformNode } from "@babylonjs/core/Meshes/transformNode";
import type { Scene } from "@babylonjs/core/scene";
import type { View } from "../view/View";
export declare function getLocalMatrix(pNode: TransformNode): Matrix;
export declare function getLocalMatrixToRef(pNode: TransformNode, pResult: Matrix): void;
export declare function setLocalMatrix(pNode: TransformNode, pMatrix: Matrix): boolean;
/**
 * Returns the current rotation quaternion of pNode or creates a new one.
 * Note: Does not return a clone.
 */
export declare function getRotationQuaternion(pNode: TransformNode): Quaternion;
export declare function rotate(pNode: TransformNode, pRotation: Quaternion, pLocal: boolean, pRefPoint?: Vector3 | null): boolean;
/**
 * Removes pNode and all its children from the scene.
 * Note: The parent of pMode is not changed or notified. pNode still counts as a children of its parent.
 */
export declare function removeFromScene(pNode: TransformNode, pScene: Scene): void;
/**
 * Adds pNode and all its children to the scene.
 * Note: No checks are made to ensure that the nodes are not already in the scene.
 */
export declare function addToScene(pNode: TransformNode, pScene: Scene): void;
/**
     * Resizes a node in view space. The current scaling of the node will be overridden.
     * The node will be handled as if it is sphere. pWorldRadius is the assumed radius of the
     * sphere (e.g. radius of the bounding sphere). pPixelRadius is the desired radius in view space.
     */
export declare function resizeInViewSpace(pView: View, pNode: TransformNode, pWorldRadius: number, pPixelRadius: number): void;
export declare function updateFrozenWorldMatrix(pNode: TransformNode, pUpdateChilds?: boolean): void;
