import { Vector2 } from "@babylonjs/core/Maths/math.vector";
export declare const PointerButton: {
    readonly Unknown: -2;
    readonly None: -1;
    readonly Left: 0;
    readonly Middle: 1;
    readonly Right: 2;
};
export type PointerButton = typeof PointerButton[keyof typeof PointerButton];
export declare const PointerButtonFlags: {
    readonly None: 0;
    readonly Left: 1;
    readonly Right: 2;
    readonly Middle: 4;
};
export type PointerButtonFlags = number;
export declare class PointerInfo {
    event: PointerEvent;
    id: number;
    type: string;
    position: Vector2;
    initialPosition: Vector2;
    previousPosition: Vector2;
    isMousePointer: boolean;
    button: PointerButton;
    initialButton: PointerButton;
    previousButton: PointerButton;
    buttons: PointerButtonFlags;
    previousButtons: PointerButtonFlags;
    constructor(pEvent: PointerEvent);
    update(pEvent: PointerEvent): void;
    static IsMousePointer(pEvent: PointerEvent): boolean;
    static IsPrimaryMousePointer(pEvent: PointerEvent): boolean;
}
export declare class InputState {
    pointers: Map<number, PointerInfo>;
    /**
     * The last known position of the pointer. Will be updated with every incoming pointer event.
     */
    pointerPosition: Vector2;
    /**
     * The last known pointer type. Will be updated with every incoming pointer event.
     */
    pointerType: string;
    constructor();
    reset(): void;
    registerPointer(pEvent: PointerEvent): boolean;
    updatePointer(pEvent: PointerEvent): boolean;
    deregisterPointer(pPointerId: number): boolean;
    getPointer(pPointerId: number): PointerInfo | null;
    getPointerByIndex(pIndex: number): PointerInfo | null;
    /**
     * Returns true if the pointerId of the given event belongs to the currently only
     * active pointer and in case of a mouse device it has to be the left mouse button.
     */
    isPrimaryPointer(pEvent: PointerEvent): boolean;
    /**
     * Returns true if there is currently no active pointer and the event belongs to a mouse device.
     */
    isMouseHoverPointer(pEvent: PointerEvent): boolean;
    private mPointerIds;
    private setOrUpdatePointer;
}
