import { CustomError } from "./../utils/error";
import type { Indexable } from "./../utils/object";
import type { AjaxOptions } from "../utils/async";
import type { EaiwsSession } from "./EaiwsSession";
export declare class SoapError extends CustomError {
    get detail(): SoapErrorDetail | undefined;
    get methodName(): string | undefined;
    constructor(pMessage?: string, pDetail?: SoapErrorDetail, pMethodName?: string);
    private mDetail;
    private mMethodName;
}
export interface SoapErrorDetail {
}
export type RequestOptionsCallback = (pSoapMethod: string) => AjaxOptions | undefined;
export declare abstract class SoapService {
    get url(): string;
    get namespaceUrl(): string;
    get sessionId(): string;
    /** custom timeout for soap requests */
    requestTimeout?: number;
    /**
     * Can be used to define custom request options for different soap methods.
     */
    onGetRequestOptions?: RequestOptionsCallback | undefined;
    constructor(pUrl: string, pNamespaceUrl: string, pSessionId: string);
    static SoapDataToArray(pSoapData: any, pItemCallback?: (pSoapItem: any) => any): Array<any> | undefined;
    static SoapDataToArrayNU(pSoapData: any, pItemCallback?: (pSoapItem: any) => any): Array<any>;
    static SoapDataToBool(this: void, pSoapData: any): boolean | undefined;
    static SoapDataToFloat(this: void, pSoapData: any): number | undefined;
    static SoapDataToDecimal(this: void, pSoapData: any): number | undefined;
    static SoapDataToInt(this: void, pSoapData: any): number | undefined;
    static GetSoapDataNodeValue(pSoapData: any): string | undefined;
    static SerializeDataToXml(pData: string | object, pAddTypeNSCallback: () => void): string | null;
    static DeserializeXmlToObject(pXml: string | null): Indexable | null;
    static LogSoapErrors: boolean;
    protected mUrl: string;
    protected mNamespaceUrl: string;
    protected mSessionId: string;
    /**
     * @param pOptions Deprecated - should no longer be used, use `SoapService.onGetRequestOptions` instead
     */
    protected soapAjax(pMethod: string, pData: any, pOptions?: AjaxOptions): Promise<any>;
    protected getErrorDetail(pSoapData: any): SoapErrorDetail | undefined;
    private static readonly NODE_TEXT_KEY;
    private static ObjectToXml;
    private static PropertyToXml;
    private static XmlToJson;
    private getBodyFromSoapResponse;
    private getErrorBodyFromXhr;
}
export declare abstract class SoapRequestData {
    constructor();
    /**
     * Helper property to force correct type in TypeScript.
     * If you get a TypeScript error like `Property _ensureTypeSafety is missing` you are perhaps
     * using a plain JavaScript object as a parameter for a SOAP function call.
     * Please use the correct class instance instead.
     */
    protected _ensureTypeSafety: string;
}
/**
 * Soap attribute decorator
 * Decorated properties will be used as soap attributes instead of elements.
 */
export declare function soapAttribute(): PropertyDecorator;
/**
 * Soap node text decorator
 * The decorated property will be used as the element text. All other
 * properties (except attributes) will be ignored in this case.
 */
export declare function soapNodeText(): PropertyDecorator;
export declare abstract class BaseEaiwsService extends SoapService {
    constructor(pOwner: EaiwsSession, pUrl: string, pNamespaceUrl: string, pSessionId: string);
    protected mOwner: EaiwsSession;
}
