/* eslint-disable @typescript-eslint/no-unsafe-return */
/* eslint-disable @typescript-eslint/no-unsafe-member-access */
/* eslint-disable @typescript-eslint/no-unsafe-call */
/* eslint-disable @typescript-eslint/no-unsafe-argument */
/* eslint-disable @typescript-eslint/no-unsafe-assignment */
/* eslint-disable no-prototype-builtins */
import { CustomError } from "./../utils/error";
import { isPlainObject } from "./../utils/object";
import { htmlEscape, isString } from "./../utils/string";
import { isBoolean } from "./../utils/boolean";
import { Log } from "./../utils/Log";
import { ERR_INVALID_ARGUMENT, newError } from "../utils/error";
import { ajax } from "../utils/async";
import { isArray } from "../utils/array";
export class SoapError extends CustomError {
    get detail() {
        return (this.mDetail);
    }
    get methodName() {
        return (this.mMethodName);
    }
    constructor(pMessage, pDetail, pMethodName) {
        super(pMessage);
        Object.setPrototypeOf(this, SoapError.prototype);
        this.name = "SoapError";
        this.mDetail = pDetail;
        this.mMethodName = pMethodName;
    }
}
export class SoapService {
    get url() {
        return (this.mUrl);
    }
    get namespaceUrl() {
        return (this.mNamespaceUrl);
    }
    get sessionId() {
        return (this.mSessionId);
    }
    constructor(pUrl, pNamespaceUrl, pSessionId) {
        this.mUrl = pUrl;
        this.mNamespaceUrl = pNamespaceUrl;
        this.mSessionId = pSessionId;
    }
    static SoapDataToArray(pSoapData, pItemCallback) {
        if (pSoapData == null)
            return (undefined);
        const tItems = [];
        if (Array.isArray(pSoapData)) {
            for (let i = 0; i < pSoapData.length; ++i) {
                const tItem = pItemCallback == null ? pSoapData[i] : pItemCallback(pSoapData[i]);
                tItems.push(tItem);
            }
        }
        else {
            const tItem = pItemCallback == null ? pSoapData : pItemCallback(pSoapData);
            tItems.push(tItem);
        }
        return (tItems);
    }
    //NU = Not Undefined
    static SoapDataToArrayNU(pSoapData, pItemCallback) {
        const tArray = SoapService.SoapDataToArray(pSoapData, pItemCallback);
        return (tArray == null ? [] : tArray);
    }
    static SoapDataToBool(pSoapData) {
        if (pSoapData == null)
            return (undefined);
        return (pSoapData === "true");
    }
    static SoapDataToFloat(pSoapData) {
        if (pSoapData == null)
            return (undefined);
        return (parseFloat(pSoapData));
    }
    static SoapDataToDecimal(pSoapData) {
        if (pSoapData == null)
            return (undefined);
        //handle special decimal values
        if (pSoapData === "-999999999999999999")
            return (Number.NEGATIVE_INFINITY);
        if (pSoapData === "999999999999999999")
            return (Number.POSITIVE_INFINITY);
        return (parseFloat(pSoapData));
    }
    static SoapDataToInt(pSoapData) {
        if (pSoapData == null)
            return (undefined);
        return (parseInt(pSoapData));
    }
    static GetSoapDataNodeValue(pSoapData) {
        if (pSoapData == null)
            return (undefined);
        if (isString(pSoapData))
            return (pSoapData);
        else
            return (pSoapData[SoapService.NODE_TEXT_KEY]);
    }
    static SerializeDataToXml(pData, pAddTypeNSCallback) {
        if (isString(pData)) {
            return (pData); //xml string expected
        }
        else if (isPlainObject(pData)) {
            return (SoapService.ObjectToXml(pData, true, pAddTypeNSCallback));
        }
        else {
            return (null);
        }
    }
    static DeserializeXmlToObject(pXml) {
        if (pXml == null)
            return (null);
        //parse xml
        let tResponse;
        try {
            tResponse = (new DOMParser()).parseFromString(pXml, "text/xml");
        }
        catch (e) {
            tResponse = undefined;
        }
        if (tResponse == null || tResponse.documentElement == null || tResponse.getElementsByTagName("parsererror").length > 0) {
            throw newError(ERR_INVALID_ARGUMENT, "Invalid XML string");
        }
        return (SoapService.XmlToJson(tResponse));
    }
    /**
     * @param pOptions Deprecated - should no longer be used, use `SoapService.onGetRequestOptions` instead
     */
    soapAjax(pMethod, pData, pOptions) {
        //build soap request header
        let tAddTypeNS = false;
        const tDataXml = SoapService.SerializeDataToXml(pData, () => tAddTypeNS = true);
        const tTypeNS = `xmlns:ns1="${this.mNamespaceUrl}"`;
        const tSoapXML = '<s:Envelope xmlns:s="http://schemas.xmlsoap.org/soap/envelope/">' +
            `<s:Body${tAddTypeNS ? ' xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"' : ''}>` +
            `<${pMethod} xmlns="${this.mNamespaceUrl}"${tAddTypeNS ? ' ' + tTypeNS : ''}>` +
            tDataXml +
            `</${pMethod}></s:Body></s:Envelope>`;
        const tOptions = {
            dataType: "xml",
            timeout: this.requestTimeout,
            headers: {
                "Content-Type": "text/xml; charset=UTF-8"
            }
        };
        //get custom options
        if (this.onGetRequestOptions != null) {
            Object.assign(tOptions, this.onGetRequestOptions(pMethod));
        }
        //assign options given as parameter (deprecated)
        Object.assign(tOptions, pOptions);
        const tPromise = ajax("POST", this.mUrl, tSoapXML, tOptions, (pError, pXhr, pResponse) => //custom error
         {
            //get soap error
            const tResponseBody = this.getErrorBodyFromXhr(pXhr, pResponse);
            if (tResponseBody != null) {
                const tFault = tResponseBody["S:Fault"];
                if (tFault != null) {
                    const tError = tFault["faultstring"];
                    const tDetailSoap = tFault["detail"];
                    let tDetail;
                    if (tDetailSoap != null) {
                        tDetail = this.getErrorDetail(tDetailSoap);
                    }
                    if (SoapService.LogSoapErrors) {
                        Log.warn("EAIWS-Error: " + tError);
                    }
                    return (new SoapError(tError, tDetail, pMethod));
                }
            }
            return (pError);
        }).then((pResponse) => {
            const tResponseBody = this.getBodyFromSoapResponse(pResponse);
            let tResponseData = null;
            if (tResponseBody != null)
                tResponseData = tResponseBody["ns2:" + pMethod + "Response"]["return"];
            return (tResponseData);
        });
        return (tPromise);
    }
    getErrorDetail(pSoapData) {
        return (undefined);
    }
    static ObjectToXml(pObj, pAddXmlns, pAddTypeNSCallback) {
        let tXmlString = "";
        if (pObj instanceof SoapRequestData) {
            for (const tProperty in pObj) {
                if (pObj.hasOwnProperty(tProperty) && !pObj._isAttribute(tProperty) && tProperty !== "_ensureTypeSafety") {
                    tXmlString += SoapService.PropertyToXml(tProperty, pObj._getPropertyValue(tProperty), pAddXmlns, pAddTypeNSCallback);
                }
            }
        }
        else {
            for (const tProperty in pObj) {
                if (pObj.hasOwnProperty(tProperty)) {
                    tXmlString += SoapService.PropertyToXml(tProperty, pObj[tProperty], pAddXmlns, pAddTypeNSCallback);
                }
            }
        }
        return (tXmlString);
    }
    static PropertyToXml(pName, pValue, pAddXmlns, pAddTypeNSCallback) {
        if (pValue == null)
            return ("");
        let tXmlString = "";
        //array
        if (isArray(pValue)) {
            for (let i = 0; i < pValue.length; ++i) {
                tXmlString += SoapService.PropertyToXml(pName, pValue[i], pAddXmlns, pAddTypeNSCallback);
            }
            return (tXmlString);
        }
        if (pAddXmlns)
            tXmlString += "<" + pName + " xmlns=\"\"";
        else
            tXmlString += "<" + pName;
        let tRawValue = pValue;
        //special handling for attribute and node value properties
        if (pValue instanceof SoapRequestData) {
            //add xsi:type
            const tClassName = pValue._getClassName();
            if (tClassName != null) {
                pAddTypeNSCallback();
                tXmlString += ' xsi:type="ns1:' + tClassName + '"';
            }
            for (const tProperty in pValue) {
                if (!pValue.hasOwnProperty(tProperty))
                    continue;
                if (pValue._isAttribute(tProperty)) {
                    const tPropValue = pValue[tProperty];
                    if (tPropValue != null) {
                        tXmlString += " " + tProperty + "=\"" + htmlEscape(tPropValue.toString()) + "\"";
                    }
                }
                else if (pValue._isNodeText(tProperty)) {
                    //use node text as value, in this case all other properties except attributes will be ignored
                    tRawValue = pValue[tProperty];
                }
            }
        }
        tXmlString += ">";
        if (tRawValue != null) { //maybe undefined if it is a node text
            //plain object or SoapRequestData
            if (isPlainObject(tRawValue) || tRawValue instanceof SoapRequestData) {
                tXmlString += SoapService.ObjectToXml(tRawValue, false, pAddTypeNSCallback);
            }
            //boolean
            else if (isBoolean(tRawValue)) {
                tXmlString += tRawValue ? "true" : "false";
            }
            //string, number ...
            else {
                tXmlString += htmlEscape(tRawValue.toString());
            }
        }
        tXmlString += "</" + pName + ">";
        return (tXmlString);
    }
    static XmlToJson(pXml) {
        //this function was copied and modified from: https://github.com/sparkbuzz/jQuery-xml2json
        if (pXml == null)
            return (null);
        const tResult = {};
        let i, tNode, tChild, tName;
        //read attributes
        if (pXml instanceof Element && pXml.attributes.length > 0) {
            for (i = 0; i < pXml.attributes.length; i++) {
                const tItem = pXml.attributes.item(i);
                if (tItem == null)
                    continue;
                //handle special null attribute
                if (tItem.nodeName === "xsi:nil" && tItem.value === "true")
                    return (null);
                tResult[tItem.nodeName] = tItem.value;
            }
        }
        //process child nodes
        for (i = 0; i < pXml.childNodes.length; i++) {
            tNode = pXml.childNodes[i];
            switch (tNode.nodeType) {
                case 1: { //1 = Element
                    const tElement = tNode;
                    if (tElement.attributes.length === 0 && tElement.childElementCount === 0) {
                        tChild = tNode.textContent; //normalize(tNode.textContent, options);
                    }
                    else {
                        tChild = SoapService.XmlToJson(tNode);
                    }
                    tName = tNode.nodeName;
                    if (tResult.hasOwnProperty(tName)) {
                        // For repeating elements, cast/promote the node to array
                        let tVal = tResult[tName];
                        if (!Array.isArray(tVal)) {
                            tVal = [tVal];
                            tResult[tName] = tVal;
                        }
                        tVal.push(tChild);
                    }
                    else {
                        tResult[tName] = tChild;
                    }
                    break;
                }
                case 3: //3 = text node
                    tResult[SoapService.NODE_TEXT_KEY] = tNode.nodeValue;
                    break;
            }
        }
        return tResult;
    }
    getBodyFromSoapResponse(pResponse) {
        if (pResponse == null || !(pResponse instanceof Node))
            return (null);
        const tJson = SoapService.XmlToJson(pResponse);
        if (tJson == null)
            return (null);
        const tEnvelope = tJson["S:Envelope"];
        if (tEnvelope == null)
            return (null);
        return (tEnvelope["S:Body"]);
    }
    getErrorBodyFromXhr(pXhr, pResponse) {
        let tXmlResponse = null;
        if (pResponse != null && pResponse instanceof Node)
            tXmlResponse = pResponse;
        else
            tXmlResponse = pXhr.responseXML;
        return (this.getBodyFromSoapResponse(tXmlResponse));
    }
}
SoapService.LogSoapErrors = false;
//// private ///////////////////////////////////////////////////////////////////////////////
SoapService.NODE_TEXT_KEY = "soapNodeText";
export class SoapRequestData {
    constructor() {
        //// protected /////////////////////////////////////////////////////////////////////////////////
        /**
         * Helper property to force correct type in TypeScript.
         * If you get a TypeScript error like `Property _ensureTypeSafety is missing` you are perhaps
         * using a plain JavaScript object as a parameter for a SOAP function call.
         * Please use the correct class instance instead.
         */
        this._ensureTypeSafety = "ensureTypeSafety";
    }
    /** @internal */
    _isAttribute(pProperty) {
        const tAnyThis = this;
        if (tAnyThis._soapAttributes == null)
            return (false);
        return (tAnyThis._soapAttributes.has(pProperty));
    }
    /** @internal */
    _isNodeText(pProperty) {
        return (this._soapNodetext === pProperty);
    }
    /** @internal */
    _getPropertyValue(pProperty) {
        return (this[pProperty]);
    }
    /** @internal */
    _getClassName() {
        return (undefined);
    }
}
/**
 * Soap attribute decorator
 * Decorated properties will be used as soap attributes instead of elements.
 */
export function soapAttribute() {
    return (pTarget, pPropertyKey) => {
        if (pTarget._soapAttributes == null)
            pTarget._soapAttributes = new Set();
        pTarget._soapAttributes.add(pPropertyKey);
    };
}
/**
 * Soap node text decorator
 * The decorated property will be used as the element text. All other
 * properties (except attributes) will be ignored in this case.
 */
export function soapNodeText() {
    return (pTarget, pPropertyKey) => {
        pTarget._soapNodetext = pPropertyKey;
    };
}
export class BaseEaiwsService extends SoapService {
    constructor(pOwner, pUrl, pNamespaceUrl, pSessionId) {
        super(pUrl, pNamespaceUrl, pSessionId);
        this.mOwner = pOwner;
    }
}
