import type { SoapErrorDetail } from "../SoapService";
import { BaseEaiwsService } from "../SoapService";
import type { EaiwsSession } from "../EaiwsSession";
import type { CondGroupSelectionOptions, CopyOptions, DeleteItemsOptions, GetAllItemsOptions, GetArticleDataOptions, GetArticleFeaturesOptions, GetChoiceListOptions, GetImagesOptions, GetItemFieldsOptions, GetItemPropertiesOptions, GetManufacturerInfoOptions, GetPriceCalculationSheetOptions, InsertArticleOptions, InsertInfo, ItemSelectionOptions, MoveItemsDirection, MoveItemsResult, OAPActionContext, OAPClientCapability, OperationMode, PasteContainerOptions, PasteOptions, RelocateItemsOptions, RelocateItemsResult, SetLanguagesMode, SetPropertyValueOptions, UpdateBasketArticlesOptions } from "./BasketTypes";
import { ArticleData, ArticleFeature, BasketColumn, BasketConfig, BasketItem, BasketViewConfig, CalculationSheet, ChoiceList, ConditionType, ExchangeRate, ImageInfo, ItemCalculationSheet, ItemField, ItemProperties, ManufacturerInfo, MergeResult, OAPAction, OAPActionResult, OAPInteractor, PasteContainerResult, PricingProcedure, PricingProcedureDescription, PropertyValue, TaxInfo, TaxScheme, TaxSchemeDescription, TMRow, TMTable, UpdateBasketArticleResult } from "./BasketTypes";
export declare class BasketService extends BaseEaiwsService {
    constructor(pOwner: EaiwsSession, pBaseUrl: string, pSessionId: string);
    addBasketColumns(pColumns?: ReadonlyArray<BasketColumn>): Promise<Array<BasketColumn>>;
    addBasketView(pTemplate: BasketViewConfig): Promise<BasketViewConfig | undefined>;
    addManualCondition(pItemIds: ReadonlyArray<string>, pPpName: string, pCondType: string, pOptions?: ItemSelectionOptions): Promise<number>;
    addPriceCalculation(pPpName: string): Promise<void>;
    addToSetArticle(pItemIds: ReadonlyArray<string>, pOpMode?: OperationMode): Promise<void>;
    adjustCalculationLineAmount(pItemIds: ReadonlyArray<string>, pPpName: string, pLevel: number, pCounter: number, pAmount: number, pCurrency: string, pOptions?: CondGroupSelectionOptions): Promise<void>;
    adjustCalculationLineValue(pItemIds: ReadonlyArray<string>, pPpName: string, pLevel: number, pCounter: number, pValue: number, pCurrency: string, pOptions?: CondGroupSelectionOptions): Promise<void>;
    adjustConditionValue(pItemIds: ReadonlyArray<string>, pPpName: string, pCondType: string, pCounter: number, pValue: number, pCurrency: string, pOptions?: CondGroupSelectionOptions): Promise<void>;
    breakUpSetArticle(pSetArtId: string): Promise<string>;
    changeAlternativePositionState(pItemIds: ReadonlyArray<string>, pPpName: string, pAltPos: boolean, pOptions?: ItemSelectionOptions, pOptional?: boolean): Promise<boolean>;
    changeBasketConfig(pBasketConfig: BasketConfig): Promise<void>;
    changeBasketViewConfig(pViewConfig: BasketViewConfig): Promise<void>;
    collapseSetArticles(pItemIds?: ReadonlyArray<string>): Promise<void>;
    convertToSetArticle(pFolderId: string, pOpMode?: OperationMode): Promise<string>;
    convertToUserArticles(pItemIds: ReadonlyArray<string>, pOptions?: ItemSelectionOptions): Promise<Array<string>>;
    copy(pItemIds: ReadonlyArray<string>, pOpMode?: OperationMode | null, pUri?: string | null, pOptions?: CopyOptions): Promise<string>;
    deleteItems(pItemIds: ReadonlyArray<string>, pOptions?: DeleteItemsOptions): Promise<void>;
    expandSetArticles(pItemIds?: ReadonlyArray<string>): Promise<void>;
    getAllChoiceLists(pItemId: string, pOptions?: GetChoiceListOptions): Promise<Array<ChoiceList>>;
    getAllItems(pItemIds?: ReadonlyArray<string>, pOptions?: GetAllItemsOptions): Promise<Array<BasketItem>>;
    getArticleData(pItemId: string, pOptions?: GetArticleDataOptions): Promise<ArticleData>;
    getArticleFeatures(pItemId: string, pOptions?: GetArticleFeaturesOptions): Promise<Array<ArticleFeature>>;
    getBasketAppData(pAppKey: string, pPaths: ReadonlyArray<string>): Promise<Array<string>>;
    getBasketColumns(pColumnIds?: ReadonlyArray<string>): Promise<Array<BasketColumn>>;
    getBasketConfig(): Promise<BasketConfig | undefined>;
    getBasketViewConfigs(pViewIds?: ReadonlyArray<string>): Promise<Array<BasketViewConfig>>;
    getChoiceList(pItemId: string, pPropClass: string, pPropName: string, pOptions?: GetChoiceListOptions): Promise<Array<PropertyValue>>;
    getConditionTypes(pActive: boolean, pPpName: string, pNames?: ReadonlyArray<string>): Promise<Array<ConditionType>>;
    getCurrency(): Promise<string>;
    getCurrentTaxScheme(): Promise<string>;
    getExchangeRates(pCurrencies?: ReadonlyArray<string>): Promise<Array<ExchangeRate>>;
    /**
     * @param pTimeout Deprecated - should no longer be used, use `SoapService.onGetRequestOptions` instead
     */
    getExportedGeometry(pItemId: string, pOptions: ReadonlyArray<string>, pTimeout?: number): Promise<string>;
    getGeneratedImage(pItemId: string, pOptions: ReadonlyArray<string>): Promise<string>;
    getImages(pItemId: string, pOptions?: GetImagesOptions): Promise<Array<ImageInfo>>;
    getItemAppData(pItemId: string, pAppKey: string, pPaths: ReadonlyArray<string>): Promise<Array<string | null>>;
    getItemFields(pItemIds?: ReadonlyArray<string>, pColumnIds?: ReadonlyArray<string>, pOptions?: GetItemFieldsOptions): Promise<Array<ItemField>>;
    getItemProperties(pItemIds?: ReadonlyArray<string>, pOptions?: GetItemPropertiesOptions): Promise<Array<ItemProperties>>;
    /**
     * Note: The server response will be cached to speed up further calls.
     */
    getLanguages(): Promise<Array<string>>;
    getManufacturerInfo(pItemIds?: ReadonlyArray<string> | null, pManuIds?: ReadonlyArray<string> | null, pSeriesIds?: ReadonlyArray<string> | null, pOptions?: GetManufacturerInfoOptions): Promise<Array<ManufacturerInfo>>;
    getPriceCalculationSheet(pItemIds: ReadonlyArray<string>, pPpName: string, pOptions?: GetPriceCalculationSheetOptions): Promise<CalculationSheet>;
    getPriceCalculationSheets(pItemIds: ReadonlyArray<string> | null | undefined, pPpName: string, pOptions?: GetPriceCalculationSheetOptions): Promise<Array<ItemCalculationSheet>>;
    getPricingProcedure(pActive: boolean, pName: string): Promise<PricingProcedure>;
    getReferenceCurrency(): Promise<string>;
    getTaxInformation(pItemId: string): Promise<Array<TaxInfo>>;
    getTaxScheme(pActive: boolean, pSchemeId: string): Promise<TaxScheme>;
    getTopFolderId(pViewId?: string): Promise<string>;
    insertFolder(pFatherId: string | null, pBeforeId: string | null, pName: string): Promise<string>;
    insertTextItem(pFatherId: string | null, pBeforeId: string | null, pText: string): Promise<string>;
    insertUserArticle(pFatherId: string | null, pBeforeId: string | null, pShortText: string): Promise<string>;
    insertOFMLArticle(pFatherId: string | null, pBeforeId: string | null, pInsertInfo: InsertInfo, pOptions?: InsertArticleOptions): Promise<string>;
    listPricingProcedures(pActive: boolean): Promise<Array<PricingProcedureDescription>>;
    listTaxSchemes(pActive: boolean, pCountry: string): Promise<Array<TaxSchemeDescription>>;
    mergeBasketArticles(pItemIds: ReadonlyArray<string>, pOptions?: ItemSelectionOptions): Promise<MergeResult>;
    moveItems(pItemIds: ReadonlyArray<string>, pDirection: MoveItemsDirection): Promise<MoveItemsResult>;
    oapGetActionData(pItemId: string, pActionId: string, pDpr?: number, pInteractor?: string): Promise<OAPAction | undefined>;
    oapGetInteractors(pItemId: string, pInteractorIds?: ReadonlyArray<string>, pDpr?: number): Promise<Array<OAPInteractor>>;
    oapProcessActions(pActionIds: ReadonlyArray<string>, pExec: boolean, pContext: OAPActionContext): Promise<Array<OAPActionResult>>;
    oapSetClientCapabilities(pCapabilities?: ReadonlyArray<OAPClientCapability>): Promise<void>;
    paste(pFatherId: string | null, pBeforeId: string | null, pUri: string, pOptions?: PasteOptions): Promise<Array<string>>;
    pasteContainer(pFatherId: string | null, pBeforeId: string | null, pUri: string, pOptions?: PasteContainerOptions): Promise<PasteContainerResult | undefined>;
    relocateItems(pFatherId: string | null, pBeforeId: string | null, pItemIds: ReadonlyArray<string>, pOptions?: RelocateItemsOptions): Promise<RelocateItemsResult>;
    removeBasketColumns(pColumnIds: ReadonlyArray<string>): Promise<void>;
    removeBasketViews(pViewIds: ReadonlyArray<string>): Promise<void>;
    removeCondition(pItemIds: ReadonlyArray<string>, pPpName: string, pCondType: string, pCounter: number, pOptions?: ItemSelectionOptions): Promise<boolean>;
    removeFromSetArticle(pItemIds: ReadonlyArray<string>, pOpMode?: OperationMode): Promise<void>;
    resetConditionAmount(pItemIds: ReadonlyArray<string>, pPpName: string, pCondType: string, pCounter: number, pOptions?: CondGroupSelectionOptions): Promise<void>;
    resetItemFields(pItemIds: ReadonlyArray<string>, pColumnId: string, pData?: string, pOptions?: ItemSelectionOptions): Promise<void>;
    resetQuantityRelation(pItemIds: ReadonlyArray<string>, pPpName: string, pCondType: string, pCounter: number, pOptions?: ItemSelectionOptions): Promise<void>;
    resetTaxConfiguration(): Promise<void>;
    resetTaxScheme(pSchemeId: string): Promise<void>;
    resetTaxRate(pSchemeId: string, pTypeId: string, pCategoryId: string): Promise<void>;
    selectCurrentTaxScheme(pSchemeId: string): Promise<void>;
    setBasketAppData(pAppKey: string, pData: ReadonlyArray<string>): Promise<void>;
    setBasketColumnProperties(pColumns?: ReadonlyArray<BasketColumn>): Promise<void>;
    setConditionAmount(pItemIds: ReadonlyArray<string>, pPpName: string, pCondType: string, pCounter: number, pAmount: number, pCurrency: string, pOptions?: CondGroupSelectionOptions): Promise<void>;
    setConditionDescription(pPpName: string, pCondType: string, pLang: string | null, pDescription: string): Promise<void>;
    setCurrency(pCurrency: string): Promise<void>;
    setExchangeRates(pExchangeRates: ReadonlyArray<ExchangeRate>, pReferenceCurrency?: string): Promise<void>;
    setItemAppData(pItemId: string, pAppKey: string, pData: ReadonlyArray<string>): Promise<void>;
    setItemConditionDescription(pItemIds: ReadonlyArray<string>, pPpName: string, pCondType: string, pCounter: number, pLang: string | null, pDescription: string, pOptions?: ItemSelectionOptions): Promise<void>;
    setItemFields(pFields: ReadonlyArray<ItemField>): Promise<void>;
    setItemProperties(pItemId: string, pProperties: ItemProperties): Promise<void>;
    setLanguages(pLanguages: ReadonlyArray<string>, pMode?: SetLanguagesMode): Promise<void>;
    setPropertyValue(pItemId: string, pPropClass: string, pPropName: string, pValue: string | null, pOptions?: SetPropertyValueOptions): Promise<string>;
    setQuantityRelation(pItemIds: ReadonlyArray<string>, pPpName: string, pCondType: string, pCounter: number, pQuantity: number, pUnit: string, pOptions?: ItemSelectionOptions): Promise<void>;
    setTaxInformation(pItemId: string, pTaxType: string, pTaxCategory: string): Promise<void>;
    setTaxRate(pSchemeId: string, pTypeId: string, pCategoryId: string, pRate: number): Promise<void>;
    splitUpCompositeArticles(pItemIds: ReadonlyArray<string>, pOptions?: ItemSelectionOptions): Promise<Array<string>>;
    startOFMLDebugging(pDebugModes: Array<string>, pTraceLevel: number, pDetailLevel: string, pOutputDevice?: string, pDebugClasses?: Array<string>): Promise<void>;
    stopOFMLDebugging(): Promise<void>;
    tmGetTable(pViewId: string | null, pItemId: string | null): Promise<TMTable | undefined>;
    tmGetText(pViewId: string | null, pItemId: string | null, pAllLanguages: boolean, pEnableLangTags?: boolean): Promise<Array<TMRow>>;
    tmSetText(pViewId: string | null, pItemId: string | null, pTextId: string, pLang: string, pText: string): Promise<void>;
    tmSetTextVisibility(pViewId: string | null, pItemId: string | null, pTextId: string, pVisible: boolean): Promise<void>;
    updateBasketArticles(pItemIds: ReadonlyArray<string>, pCatalogIds?: ReadonlyArray<string> | null, pOptions?: UpdateBasketArticlesOptions): Promise<Array<UpdateBasketArticleResult>>;
    protected getErrorDetail(pSoapData: any): SoapErrorDetail | undefined;
    private mLanguages;
}
