import type { EaiwsSession } from "../EaiwsSession";
import type { ConditionType, PricingProcedure, PricingProcedureLine } from "./BasketTypes";
export type PricingProcedureLineTag = Uppercase<string> | "PURCHASE_CALC" | "PD_PURCHASE_PRICE" | "GROSS_PURCHASE_PRICE" | "PURCHASE_VALUE" | "PD_SALES_PRICE" | "GROSS_SALES_PRICE" | "ITEM_NET_VALUE" | "NET_VALUE" | "NET_VALUE_ECO" | "FINAL_VALUE" | "FINAL_VALUE_NO_DISCOUNTS" | "PURCHASE_DISCOUNT" | "PURCHASE_EXTRA_CHARGE" | "DISCOUNT" | "EXTRA_CHARGE" | "HEADER_DISCOUNT" | "HEADER_EXTRA_CHARGE" | "VAT" | "TAX" | "MARGIN_QTY" | "MARGIN_REL" | "INVISIBLE";
/**
 * Helper class for PricingProcedure handling.
 */
export declare class PricingProcedureInfo {
    get name(): string;
    get procedure(): PricingProcedure;
    getConditionType(pConditionName: string): ConditionType | undefined;
    /**
     * Returns the PricingProcedureLine for the given line level and counter. If the line
     * doesn't exist and pFallbackToDefaultCounter is true, the default counter (0) will be used
     * as a fallback.
     */
    getProcedureLine(pLevel: number, pCounter: number, pFallbackToDefaultCounter?: boolean): PricingProcedureLine | undefined;
    /**
     * Returns the tags of a PricingProcedureLine as Set which is cached internally.
     */
    getLineTags(pLine: PricingProcedureLine): Set<PricingProcedureLineTag>;
    static CreateInfo(pSession: EaiwsSession, pPricingProcedureName: string, pUseActiveProcedure?: boolean): Promise<PricingProcedureInfo>;
    private mProcedure;
    private mTypes;
    private mLines;
    private mLineTags;
    private constructor();
}
