import { ERR_INVALID_ARGUMENT, ERR_INVALID_STATE, newError } from "../../utils/error";
/**
 * Helper class for PricingProcedure handling.
 */
export class PricingProcedureInfo {
    get name() {
        return (this.mProcedure.name);
    }
    get procedure() {
        return (this.mProcedure);
    }
    getConditionType(pConditionName) {
        return (this.mTypes.get(pConditionName));
    }
    /**
     * Returns the PricingProcedureLine for the given line level and counter. If the line
     * doesn't exist and pFallbackToDefaultCounter is true, the default counter (0) will be used
     * as a fallback.
     */
    getProcedureLine(pLevel, pCounter, pFallbackToDefaultCounter = true) {
        const tKey = pLevel.toString() + "_" + pCounter.toString();
        const tLine = this.mLines.get(tKey);
        if (pFallbackToDefaultCounter && tLine == undefined && pCounter !== 0)
            return (this.getProcedureLine(pLevel, 0, false));
        return (tLine);
    }
    /**
     * Returns the tags of a PricingProcedureLine as Set which is cached internally.
     */
    getLineTags(pLine) {
        const tTags = this.mLineTags.get(pLine);
        if (tTags == null)
            throw newError(ERR_INVALID_ARGUMENT, "unknown pricing procedure line");
        return (tTags);
    }
    static async CreateInfo(pSession, pPricingProcedureName, pUseActiveProcedure = true) {
        if (!pSession.isValid)
            throw newError(ERR_INVALID_STATE, "session not valid");
        const tResult = await Promise.all([
            pSession.basket.getPricingProcedure(pUseActiveProcedure, pPricingProcedureName),
            pSession.basket.getConditionTypes(pUseActiveProcedure, pPricingProcedureName)
        ]);
        return (new PricingProcedureInfo(tResult[0], tResult[1]));
    }
    constructor(pProc, pTypes) {
        this.mProcedure = pProc;
        //build condition types map
        this.mTypes = new Map();
        for (const tType of pTypes)
            this.mTypes.set(tType.name, tType);
        //build line and tags map
        this.mLines = new Map();
        this.mLineTags = new Map();
        for (const tLine of this.mProcedure.lines) {
            //line map
            const tKey = tLine.level.toString() + "_" + tLine.counter.toString();
            this.mLines.set(tKey, tLine);
            //tag map
            const tTags = new Set();
            if (tLine.tags != null) {
                for (const tTag of tLine.tags) {
                    tTags.add(tTag);
                }
            }
            this.mLineTags.set(tLine, tTags);
        }
    }
}
