import { SoapRequestData } from "../SoapService";
export type CatalogItemType = "Undefined" | "CatalogView" | "Folder" | "Article" | "Information" | "Graphics" | "MethodCall" | "MetaPlanning" | "Container";
export type DisplayMode = "Undefined" | "All" | "Planning2D" | "Planning3D" | "Configuration" | "CAD" | "AllVisible" | "AllVisibleBasket";
export type PackageType = "Unknown" | "Foundation" | "ProductWithCatalog" | "ProductWithoutCatalog" | "CatalogOnly" | "Extension" | "ACMaterial" | "User" | "AttributeSelection";
export type PackageCategory = "Unknown" | "Furniture" | "Building";
export type SearchFlag = "ViewItems" | "CatalogItems" | "WildcardsInFilter" | "FolderText";
export type SeriesType = "Undefined" | "GOMeta";
export type VarCodeType = "None" | "Manufacturer" | "OFML";
export type IsoDateString = string;
export declare abstract class BasicSearchParameterSet extends SoapRequestData {
    catalogIds?: Array<string>;
    flags?: Array<SearchFlag>;
    views?: Array<string>;
    firstHitPosition?: number;
    numberOfHits?: number;
}
export declare class DisplayText extends SoapRequestData {
    value: string;
    lang?: string;
    constructor();
    static FromSoapArray(pSoapArray: any): Array<DisplayText> | undefined;
    static FromSoapNU(this: void, pSoapData: any): DisplayText;
}
export declare class GetPackageInfoOptions extends SoapRequestData {
    allData?: boolean;
    allLanguages?: boolean;
    useManufacturerConfig?: boolean;
    manufacturerId?: boolean;
    supplierId?: boolean;
    seriesIds?: boolean;
    releaseVersion?: boolean;
    releaseDate?: boolean;
    releaseState?: boolean;
    languages?: boolean;
    type?: boolean;
    category?: boolean;
    dependencies?: boolean;
    catalogs?: boolean;
    features?: boolean;
    seriesType?: boolean;
    priceProfileRegionId?: boolean;
    specialArticleScheme?: boolean;
    globalTradeItemNumber?: boolean;
    maskedCatalogs?: boolean;
    releaseText?: boolean;
    manufacturerName?: boolean;
    programName?: boolean;
    distributorName?: boolean;
    copyright?: boolean;
    description?: boolean;
}
export declare class LookupOptions extends SoapRequestData {
    itemTypes?: Array<CatalogItemType>;
    languages?: Array<string>;
    textPurposes?: Array<string>;
    imagePurposes?: Array<string>;
    resourceTypes?: Array<string>;
    displayMode?: DisplayMode;
    descriptors?: boolean;
    subCategories?: boolean;
    synonyms?: boolean;
    resourceValues?: boolean;
    resourceURLs?: boolean;
}
export declare class SearchArticleParameterSet extends BasicSearchParameterSet {
    brandId?: string;
    manufacturerId?: string;
    seriesId?: string;
    baseArticleNumber?: string;
    varCodeType?: VarCodeType;
    variantCode?: string;
}
export declare class SearchParameterSet extends BasicSearchParameterSet {
    query: string;
    filter?: string;
    constructor();
}
export declare class SearchResourceParameterSet extends BasicSearchParameterSet {
    value: string;
    catalogPackageId?: string;
    language?: string;
    resourceType?: string;
    constructor();
}
export declare class CatalogItem {
    catalogId: string;
    catalogNodeKey: string;
    catalogPackageId: string;
    label: string;
    icon: string;
    name: string;
    type: CatalogItemType;
    resources?: Array<CatalogResource>;
    manufacturerIds?: Array<string>;
    images?: Array<CatalogImage>;
    static FromSoapArrayNU(pSoapArray: any): Array<CatalogItem>;
    static FromSoapNU(this: void, pSoapData: any): CatalogItem;
}
export declare class ArticleCatalogItem extends CatalogItem {
    articlePackageId: string;
    baseArticleNumber: string;
    varCodeType: VarCodeType;
    variantCode: string;
}
export declare class CatalogImage {
    purpose: string;
    language: string;
    highRes: boolean;
    width: number;
    height: number;
    name: string;
    url: string;
    static FromSoapArray(pSoapArray: any): Array<CatalogImage> | undefined;
    static FromSoapNU(this: void, pSoapData: any): CatalogImage;
}
export declare class CatalogResource {
    language: string;
    type: string;
    value?: string;
    url?: string;
    static FromSoapArray(pSoapArray: any): Array<CatalogResource> | undefined;
    static FromSoapNU(this: void, pSoapData: any): CatalogResource;
}
export declare class MaskedCatalog {
    moduleKey: string;
    version?: string;
    static FromSoapArray(pSoapArray: any): Array<MaskedCatalog> | undefined;
    static FromSoapNU(this: void, pSoapData: any): MaskedCatalog;
}
export declare class PackageInfo {
    manufacturerId?: string;
    supplierId?: string;
    seriesIds?: Array<string>;
    releaseVersion?: string;
    releaseDate?: IsoDateString;
    releaseState?: string;
    languages?: Array<string>;
    type?: PackageType;
    category?: PackageCategory;
    dependencies?: Array<PackageDependency>;
    catalogs?: Array<string>;
    features?: Array<string>;
    seriesType?: SeriesType;
    priceProfileRegionId?: string;
    specialArticleScheme?: string;
    globalTradeItemNumber?: string;
    maskedCatalogs?: Array<MaskedCatalog>;
    releaseText?: Array<DisplayText>;
    manufacturerName?: Array<DisplayText>;
    programName?: Array<DisplayText>;
    distributorName?: Array<DisplayText>;
    copyright?: Array<DisplayText>;
    description?: Array<DisplayText>;
    packageId: string;
    static FromSoapArrayNU(pSoapArray: any): Array<PackageInfo>;
    static FromSoapNU(this: void, pSoapData: any): PackageInfo;
}
export declare class PackageDependency {
    packageId: string;
    version: string;
    static FromSoapArray(pSoapArray: any): Array<PackageDependency> | undefined;
    static FromSoapNU(this: void, pSoapData: any): PackageDependency;
}
export declare class ScoredCatalogItem {
    item: CatalogItem;
    score: number;
    static FromSoapArrayNU(pSoapArray: any): Array<ScoredCatalogItem>;
    static FromSoapNU(this: void, pSoapData: any): ScoredCatalogItem;
}
export declare class TopCatalogItems {
    scoredItems: Array<ScoredCatalogItem>;
    totalHits: number;
    static FromSoap(pSoapData: any): TopCatalogItems | undefined;
}
