import { SoapRequestData } from "../SoapService";
export type AddressType = "SoldTo" | "ShipTo" | "BillTo" | "Payer" | "Carrier" | "Supplier" | "EndUser" | "InstallationCompany" | "InstallationLocation" | "Branch" | "InCharge";
export type AuthMessageType = "SCRAM_SHA_256_first" | "SCRAM_SHA_256_final";
export type CommAddrType = "Phone" | "Fax" | "Mobile" | "WWW" | "EMail";
export type ContactType = "Sale" | "Warehouse" | "Installer" | "Support" | "Employee" | "Client";
export type LockingMode = "Default" | "NoLock" | "TryLock" | "Lock" | "ForceLock";
export type ScopeInfo = "Business" | "Private";
export type ProjectAttribute = "CreateTime" | "LastModifiedTime" | "ProjectState" | "ProjectName" | "ProjectNumber" | "Description" | "ExternalReferenceNumber" | "ExternalReferenceText" | "CustomerNumber" | "ExternalCustomerId" | "CustomerRelatedRemarks" | "Company" | "GeneralAgreementNumber" | "Keywords" | "ProjectDate" | "ValidToDate" | "CreatedBy" | "LastModifiedBy" | "AddressNumber" | "AddressId" | "Title" | "Name1" | "Name2" | "Name3" | "Name4" | "Street" | "Street2" | "CountryCode" | "PostalCode" | "Location" | "District" | "RegionCode" | "PoBox" | "TaxCode" | "TaxCodeEU" | "TaxCodeUSA" | "ContactNumber" | "ContactTitle" | "ContactFirstName" | "ContactLastName";
export type ProjectFilterOperator = "IsDefined" | "IsUndefined" | "And" | "Or" | "Not" | "Equal" | "NotEqual" | "Distinct" | "NotDistinct" | "Less" | "LessEqual" | "Greater" | "GreaterEqual" | "Between" | "NotBetween" | "Like" | "NotLike";
export type ProjectState = "Undefined" | "InProgress" | "Offered" | "Ordered" | "NotCommissioned" | "ApprovalRequired" | "WaitingForApproval" | "ApprovalDenied" | "Approved";
export type ProjectTextType = "HeaderText" | "FooterText";
export type TextFormat = "None" | "IML" | "XML" | "JSON" | "HTML";
export type IsoDateString = string;
export type IsoDateTimeString = string;
export type IsoDurationString = string;
export declare class AddressData extends SoapRequestData {
    addressNumber?: string;
    addressId?: string;
    title?: string;
    name1?: string;
    name2?: string;
    name3?: string;
    name4?: string;
    street?: string;
    street2?: string;
    countryCode?: string;
    postalCode?: string;
    location?: string;
    district?: string;
    regionCode?: string;
    poBox?: string;
    taxCode?: string;
    taxCodeEU?: string;
    taxCodeUSA?: string;
    commAddresses?: Array<CommAddress>;
    contacts?: Array<ContactData>;
    addressType: AddressType;
    constructor();
    /** Serialize to xml string. */
    static Serialize(pAddress: AddressData): string | null;
    /** Deserialize xml string. */
    static Deserialize(pData: string, pResetContactIds?: boolean): AddressData | null;
    static FromSoapArray(pSoapArray: any): Array<AddressData> | undefined;
    static FromSoapArrayNU(pSoapArray: any): Array<AddressData>;
    static FromSoapNU(this: void, pSoapData: any): AddressData;
    static FromSoap(pSoapData: any): AddressData | undefined;
}
export declare class AutoSaveOptions extends SoapRequestData {
    onSessionClose?: boolean;
    onProjectClose?: boolean;
    periodical?: boolean;
    interval?: IsoDurationString;
    idleTime?: IsoDurationString;
    static FromSoap(pSoapData: any): AutoSaveOptions | undefined;
}
export declare class CommAddress extends SoapRequestData {
    value: string;
    type: CommAddrType;
    scope: ScopeInfo;
    constructor();
    static FromSoapArrayNU(pSoapArray: any): Array<CommAddress>;
    static FromSoapNU(this: void, pSoapData: any): CommAddress;
}
export declare class ContactData extends SoapRequestData {
    contactNumber?: string;
    title?: string;
    firstName?: string;
    lastName?: string;
    commAddresses?: Array<CommAddress>;
    id: number;
    contactType?: ContactType;
    constructor();
    static FromSoapArrayNU(pSoapArray: any): Array<ContactData>;
    static FromSoapNU(this: void, pSoapData: any): ContactData;
}
export declare class DeleteProjectsOptions extends SoapRequestData {
    ignoreVersionNumbers?: boolean;
    failIfNonExistent?: boolean;
    failIfPermissionDenied?: boolean;
    failIfNotLockable?: boolean;
    ignoreLocks?: boolean;
}
export declare class DisplayName extends SoapRequestData {
    value: string;
    language: string;
    constructor();
    static FromSoapArrayNU(pSoapArray: any): Array<DisplayName>;
    static FromSoapNU(this: void, pSoapData: any): DisplayName;
}
export declare class FormattedText extends SoapRequestData {
    value: string;
    language: string;
    format: TextFormat;
    constructor();
    static FromSoapArray(pSoapArray: any): Array<FormattedText> | undefined;
    static FromSoapNU(this: void, pSoapData: any): FormattedText;
}
export declare class ListCompletionsOptions extends SoapRequestData {
    prefix: string;
    projectGroupPattern?: string;
    addressType?: AddressType;
    contactType?: ContactType;
    limit?: number;
    filterAttribute?: ProjectAttribute;
    ignoreCase?: boolean;
    constructor();
}
export declare class ListProjectsOptions extends SoapRequestData {
    projectURI?: string;
    searchExpression?: string;
    filter?: ProjectFilter;
    orderBy?: Array<ProjectSortSpec>;
    resultAddressTypes?: Array<AddressType>;
    projectGroupPattern?: string;
    addressType?: AddressType;
    contactType?: ContactType;
    offset?: number;
    limit?: number;
}
export declare class Permission extends SoapRequestData {
    userRole?: string;
    create?: boolean;
    read?: boolean;
    write?: boolean;
    delete?: boolean;
    list?: boolean;
    static FromSoapArrayNU(pSoapArray: any): Array<Permission>;
    static FromSoapNU(this: void, pSoapData: any): Permission;
    static FromSoap(pSoapData: any): Permission | undefined;
}
export declare class PriceList extends SoapRequestData {
    userRoles?: Array<string>;
    displayNames?: Array<DisplayName>;
    id: string;
    startup?: string;
    availableToCurrentUser?: boolean;
    constructor();
    static FromSoapArrayNU(pSoapArray: any): Array<PriceList>;
    static FromSoapNU(this: void, pSoapData: any): PriceList;
}
export declare class ProjectData extends SoapRequestData {
    uri?: string;
    projectName?: string;
    projectNumber?: string;
    description?: string;
    externalReferenceNumber?: string;
    externalReferenceText?: string;
    customerNumber?: string;
    externalCustomerId?: string;
    customerRelatedRemarks?: string;
    company?: string;
    generalAgreementNumber?: string;
    keywords?: Array<string>;
    addresses?: Array<AddressData>;
    languages?: Array<string>;
    projectTexts?: Array<ProjectText>;
    projectGroup?: string;
    projectId?: string;
    projectVersion?: number;
    priceList?: string;
    projectState?: ProjectState;
    created?: IsoDateTimeString;
    lastModified?: IsoDateTimeString;
    projectDate?: IsoDateString;
    validToDate?: IsoDateString;
    createdByUser?: string;
    modifiedByUser?: string;
    changed?: boolean;
    locked?: boolean;
    lockHolder?: string;
    lockTime?: IsoDateTimeString;
    projectNumberEditable?: boolean;
    static FromSoapArrayNU(pSoapArray: any): Array<ProjectData>;
    static FromSoapNU(this: void, pSoapData: any): ProjectData;
    static FromSoap(pSoapData: any): ProjectData | undefined;
}
export declare abstract class ProjectFilterNode extends SoapRequestData {
}
export declare class ProjectFilter extends ProjectFilterNode {
    arguments: Array<ProjectFilterNode>;
    operator: ProjectFilterOperator;
    ignoreCase?: boolean;
    constructor();
}
export declare class ProjectFilterAttribute extends ProjectFilterNode {
    attribute: ProjectAttribute;
    constructor();
}
export declare abstract class ProjectFilterValue extends ProjectFilterNode {
}
export declare class ProjectFilterStringValue extends ProjectFilterValue {
    value: string;
    constructor();
}
export declare class ProjectFilterDateTimeValue extends ProjectFilterValue {
    value: IsoDateTimeString;
    constructor();
}
export declare class ProjectFilterDateValue extends ProjectFilterValue {
    date: IsoDateString;
    constructor();
}
export declare class ProjectFilterStateValue extends ProjectFilterValue {
    value: ProjectState;
    constructor();
}
export declare class ProjectGroup extends SoapRequestData {
    numberScheme?: ProjectNumberScheme;
    priceLists?: Array<PriceList>;
    permissions?: Array<Permission>;
    simpleNames?: Array<DisplayName>;
    fullNames?: Array<DisplayName>;
    subgroupTitles?: Array<DisplayName>;
    currentUserPermissions?: Permission;
    id: string;
    folder?: boolean;
    constructor();
    static FromSoapArrayNU(pSoapArray: any): Array<ProjectGroup>;
    static FromSoapNU(this: void, pSoapData: any): ProjectGroup;
}
export declare class ProjectNumberScheme extends SoapRequestData {
    id: string;
    pattern?: string;
    minimumValue?: number;
    maximumValue?: number;
    nextValue?: number;
    currentYear?: number;
    zoneId?: string;
    constructor();
    static FromSoapArrayNU(pSoapArray: any): Array<ProjectNumberScheme>;
    static FromSoap(pSoapData: any): ProjectNumberScheme | undefined;
    static FromSoapNU(this: void, pSoapData: any): ProjectNumberScheme;
}
export declare class ProjectSortSpec extends SoapRequestData {
    attribute: ProjectAttribute;
    ascending?: boolean;
    undefFirst?: boolean;
    ignoreCase?: boolean;
    constructor();
}
export declare class ProjectText extends SoapRequestData {
    texts?: Array<FormattedText>;
    type: ProjectTextType;
    constructor();
    static FromSoapArrayNU(pSoapArray: any): Array<ProjectText>;
    static FromSoapNU(this: void, pSoapData: any): ProjectText;
}
export declare class SaveProjectOptions extends SoapRequestData {
    projectGroup?: string;
    priceList?: string;
    noVersionCheck?: boolean;
    autoDelete?: boolean;
}
export declare class CountryData {
    displayName: string;
    iso3166Code: string;
    static FromSoapArrayNU(pSoapArray: any): Array<CountryData>;
    static FromSoapNU(this: void, pSoapData: any): CountryData;
}
export declare class SubdivisionData {
    iso3166names: Array<string>;
    localVariants?: Array<string>;
    languageCodes: Array<string>;
    displayName: string;
    category: string;
    iso3166Code: string;
    regionCode: string;
    parentSubdivision?: string;
    static FromSoapArrayNU(pSoapArray: any): Array<SubdivisionData>;
    static FromSoapNU(this: void, pSoapData: any): SubdivisionData;
}
