import { SoapRequestData } from "../SoapService";
export type SessionCacheFileType = "Project" | "CutBuffer" | "Import";
export type SendMessageStatus = "OK" | "UnexpectedError" | "UnknownTargetType" | "UnknownPlugin" | "NoPluginImplementation" | "NoMessageHandler" | "UnknownMessageId" | "InvalidMessageData" | "TargetError";
export declare class ClientMessage extends SoapRequestData {
    data?: Array<StringPair>;
    target: string;
    messageId: string;
    constructor();
}
export declare class CustomerData extends SoapRequestData {
    customerNumber?: string;
    salutation?: string;
    firstName?: string;
    lastName?: string;
    emailAddr?: string;
    company?: string;
    organization?: string;
    streetAddr?: string;
    city?: string;
    stateOrProvince?: string;
    cityCode?: string;
    poBox?: string;
    postalCode?: string;
    poBoxPostalCode?: string;
    country?: string;
    language?: string;
    phone?: string;
    fax?: string;
    static FromSoap(pSoapData: any): CustomerData | undefined;
}
export declare class GetSystemInformationOptions extends SoapRequestData {
    operatingSystem?: boolean;
    runtime?: boolean;
    memory?: boolean;
    application?: boolean;
    server?: boolean;
}
export declare class ImportFileOptions extends SoapRequestData {
    deleteAfterImport?: boolean;
}
export declare class LoadSessionOptions extends SoapRequestData {
    suffix?: string;
    assignNewProjectId?: boolean;
}
export declare class LogConfig extends SoapRequestData {
    maxRecordCount?: number;
    discardOldest?: boolean;
    storeStackTrace?: boolean;
    timeZoneId?: string;
    filter?: LogFilter;
}
export declare class LogFilter extends SoapRequestData {
    include?: Array<LogFilterSpec>;
    exclude?: Array<LogFilterSpec>;
}
export declare class LogFilterSpec extends SoapRequestData {
    level?: string;
    facility?: string;
    origin?: string;
}
export declare class ProjectData extends SoapRequestData {
    number?: string;
    name?: string;
    description?: string;
    personInCharge?: string;
    extRefNr?: string;
    extRefText?: string;
    static FromSoap(pSoapData: any): ProjectData | undefined;
}
export declare class ProjectSettings extends SoapRequestData {
    projectData?: ProjectData;
    customerData?: CustomerData;
    static FromSoap(pSoapData: any): ProjectSettings | undefined;
}
export declare class ResolveURIsOptions extends SoapRequestData {
    serverBase?: string;
}
export declare class SaveSessionOptions extends SoapRequestData {
    suffix?: string;
    overwrite?: boolean;
    generateImages?: boolean;
    omitPriceData?: boolean;
    saveCalculations?: boolean;
    saveLegacyCalculation?: boolean;
    legacyCalculationName?: string;
    export?: boolean;
}
export declare class StringPair extends SoapRequestData {
    first: string;
    second: string;
    constructor(pFirst?: string, pSecond?: string);
    static FromSoapArray(pSoapArray: any): Array<StringPair> | undefined;
    static FromSoapNU(this: void, pSoapData: any): StringPair;
}
export declare class ApplicationInformation {
    appName: string;
    appKey: string;
    appVersion: string;
    vendorKey: string;
    static FromSoap(pSoapData: any): ApplicationInformation | undefined;
}
export declare class CallSite {
    className: string;
    methodName: string;
    fileName?: string;
    lineNumber?: number;
    static FromSoapArray(pSoapArray: any): Array<CallSite> | undefined;
    static FromSoapArrayNU(pSoapArray: any): Array<CallSite>;
    static FromSoap(pSoapData: any): CallSite | undefined;
    static FromSoapNU(this: void, pSoapData: any): CallSite;
}
export declare class FaultInfo {
    message: string;
    stackTrace: Array<CallSite>;
    type: string;
    static FromSoapArray(pSoapArray: any): Array<FaultInfo> | undefined;
    static FromSoapNU(this: void, pSoapData: any): FaultInfo;
}
export declare class LogData {
    data: Array<LogRecord>;
    discarded: number;
    suppressed: number;
    static FromSoap(pSoapData: any): LogData | undefined;
}
export declare class LogRecord {
    cause?: Array<FaultInfo>;
    message: string;
    origin?: CallSite;
    facility: string;
    level: string;
    timeStamp: string;
    static FromSoapArrayNU(pSoapArray: any): Array<LogRecord>;
    static FromSoapNU(this: void, pSoapData: any): LogRecord;
}
export declare class SendMessageResult {
    messages: Array<ServerResponse>;
    sessionAlive: boolean;
    static FromSoap(pSoapData: any): SendMessageResult | undefined;
}
export declare class ServerInformation {
    maxConcurrentSessionCount: number;
    openSessionCount: number;
    activeSessionCount: number;
    sessionTimeout: number;
    sessionSuspendTimeout: number;
    static FromSoap(pSoapData: any): ServerInformation | undefined;
}
export declare class ServerResponse {
    data?: Array<StringPair>;
    errorDetail?: Array<string>;
    origin: string;
    messageId: string;
    statusCode: SendMessageStatus;
    targetErrorCode?: string;
    static FromSoapArrayNU(pSoapArray: any): Array<ServerResponse>;
    static FromSoapNU(this: void, pSoapData: any): ServerResponse;
}
export declare class SystemInformation {
    operatingSystem?: any;
    runtime?: any;
    memory?: any;
    application?: ApplicationInformation;
    server?: ServerInformation;
    static FromSoap(pSoapData: any): SystemInformation | undefined;
}
