import { Vector3 } from "@babylonjs/core/Maths/math.vector";
import { SelectionDefault } from "../../core/tool/SelectionDefault";
import { TouchDefaultMove } from "./TouchDefaultMove";
import { TouchDefaultRotate } from "./TouchDefaultRotate";
export class TouchDefault extends SelectionDefault {
    constructor(pApp) {
        super(pApp);
        this.moveYBelowGroundEnabled = true;
        this.groundYPosition = 0;
        this.moveLimitMin = new Vector3(-20, -20, -20);
        this.moveLimitMax = new Vector3(20, 20, 20);
        this.mMoveTool = new TouchDefaultMove(this.mApp);
        this.mRotateTool = new TouchDefaultRotate(this.mApp);
    }
    //// protected /////////////////////////////////////////////////////////////////////////////
    startPointerMoveTool(pEvent, pState) {
        if (pEvent.ctrlKey || this.mSelection.length === 0)
            return;
        const tUsePickedPos = this.mPickedElement != null && this.mPickedElement.getTopLevelElement().isSelected;
        //if camera control is enabled the user has to pick a selected element in order to start move/rotate
        if (!tUsePickedPos && this.mApp.viewer.view.cameraControl.controlsEnabled) {
            return;
        }
        if (pState.pointers.size === 1) {
            //move plane
            if (this.mSelectionInfo.canTranslate) {
                this.mMoveTool.initialize(this.mPickedPos, false, this.moveYBelowGroundEnabled, this.groundYPosition);
                this.mMoveTool.setMoveLimit(this.moveLimitMin, this.moveLimitMax);
                this.mApp.tools.startTool(this.mMoveTool, tUsePickedPos);
            }
        }
        else if (pState.pointers.size === 2) {
            //rotate
            if (this.mSelectionInfo.canRotate) {
                this.mRotateTool.initialize();
                this.mApp.tools.startTool(this.mRotateTool);
            }
        }
        else if (pState.pointers.size === 3) {
            //move y
            if (this.mSelectionInfo.canTranslate) {
                this.mMoveTool.initialize(this.mPickedPos, true, this.moveYBelowGroundEnabled, this.groundYPosition);
                this.mMoveTool.setMoveLimit(this.moveLimitMin, this.moveLimitMax);
                this.mApp.tools.startTool(this.mMoveTool, tUsePickedPos);
            }
        }
    }
}
