import { Vector2 } from "@babylonjs/core/Maths/math.vector";
import { BoundingBox } from "../../core/mdl/BoundingBox";
import { InteractionMode } from "../../core/tool/Tool";
import { AbstractMove } from "./AbstractMove";
export class TouchDefaultMove extends AbstractMove {
    start(pUseRefPoint) {
        const tResult = super.start(undefined);
        if (!tResult)
            return (tResult);
        this.mPickPlane = this.getPickPlane(pUseRefPoint ? this.mRefPoint : this.mBBoxWorld.getCenter());
        this.setInteractionMode(this.mMoveY ? InteractionMode.All : InteractionMode.Primary);
        return (true);
    }
    initialize(pRefPoint, pMoveY, pAllowMoveBelowGround, pGroundPosition) {
        this.mRefPoint = pRefPoint.clone();
        this.mMoveY = pMoveY;
        this.mAllowMoveBelowGround = pAllowMoveBelowGround;
        this.mGroundPosition = pGroundPosition;
    }
    //// protected ///////////////////////////////////////////////////////////////////////////////
    prepareSnapping() {
        let tBounds;
        let tTransform = null;
        if (this.mApp.model.selection.length === 1) {
            tBounds = this.mApp.model.selection[0].boundingBoxVisible.clone();
            tTransform = this.mApp.model.selection[0].worldTransform;
            this.mBBoxWorld = tBounds.transform(tTransform);
        }
        else {
            tBounds = BoundingBox.FromElements(this.mApp.model.selection, undefined, true);
            this.mBBoxWorld = tBounds;
        }
    }
    performSnap(pPos) {
        let tCurrentPos = this.preventMoveBelowGround(pPos);
        tCurrentPos = this.limitMovement(tCurrentPos);
        return (tCurrentPos);
    }
    getPointerPosition(pEvent, pState, pInitialPos) {
        if (this.mMoveY) {
            const tNumPointers = pState.pointers.size;
            if (tNumPointers !== 3)
                return (null);
            const tPos = Vector2.Zero();
            for (let i = 0; i < tNumPointers; ++i) {
                const tPointer = pState.getPointerByIndex(i);
                if (tPointer == null)
                    return (null);
                tPos.addInPlace(pInitialPos ? tPointer.initialPosition : tPointer.position);
            }
            tPos.scaleInPlace(1 / tNumPointers);
            return (tPos);
        }
        else {
            return (super.getPointerPosition(pEvent, pState, pInitialPos));
        }
    }
}
