import { Vector2, Quaternion } from "@babylonjs/core/Maths/math.vector";
import { BoundingBox } from "../../core/mdl/BoundingBox";
import { InteractionMode } from "../../core/tool/Tool";
import { normalizeAngle, signedAngleBetweenVectors2, VECTOR2_X } from "../../core/utils/MathUtils";
import { AbstractRotate } from "./AbstractRotate";
export class TouchDefaultRotate extends AbstractRotate {
    constructor(pApp) {
        super(pApp);
        this.mLastAngle = null;
    }
    start(pParameter) {
        const tResult = super.start(pParameter);
        if (!tResult)
            return (tResult);
        this.mLastAngle = null;
        this.setInteractionMode(InteractionMode.All);
        return (true);
    }
    stop() {
        super.stop();
    }
    handlePointerMove(pEvent, pState) {
        if (this.mCommand == null)
            return;
        if (this.mLastAngle == null) {
            this.mLastAngle = this.getPointerAngle(pState, true);
            return;
        }
        const tAngle = this.getPointerAngle(pState, false);
        if (tAngle == null)
            return;
        const tAngleDiff = this.mLastAngle - tAngle;
        this.mTotalAngle += tAngleDiff;
        this.mTotalAngle = normalizeAngle(this.mTotalAngle, true);
        const tRot = Quaternion.RotationAxis(this.mAxisVector, tAngleDiff);
        this.mCommand.rotate(tRot, this.mLocalRotation, this.mTransformedRefPoint);
        this.mLastAngle = tAngle;
    }
    initialize() {
        const tBounds = BoundingBox.FromElements(this.mApp.model.selection, undefined, true);
        this.mRefPoint = tBounds.getCenter();
    }
    getPointerAngle(pState, pInitialAngle) {
        if (pState.pointers.size !== 2)
            return (null);
        const tP1 = pState.getPointerByIndex(0);
        const tP2 = pState.getPointerByIndex(1);
        if (tP1 == null || tP2 == null)
            return (null);
        let tDir;
        Vector2;
        if (pInitialAngle) {
            tDir = tP1.initialPosition.subtract(tP2.initialPosition);
        }
        else {
            tDir = tP1.position.subtract(tP2.position);
        }
        tDir.normalize();
        return (signedAngleBetweenVectors2(tDir, VECTOR2_X));
    }
}
