import type { Scene } from "@babylonjs/core/scene";
import { Mesh } from "@babylonjs/core/Meshes/mesh";
import { Vector2 } from "@babylonjs/core/Maths/math.vector";
import type { ModelManager } from "../../core/mdl/ModelManager";
import type { SceneElement } from "../../core/mdl/SceneElement";
import type { View } from "../../core/view/View";
export interface PlaceElementsOptions {
    /**
     * Minimum coordinates of the placing area (Default: [-5.0, -5.0])
     */
    placingAreaMin?: Vector2;
    /**
 * Maximum coordinates of the placing area (Default: [5.0, 5.0])
 */
    placingAreaMax?: Vector2;
    /**
     * Snapping grid used for placement. (Default: size defined in application settings)
     */
    snapGridSize?: Vector2;
}
/**
 * Creates a line based grid.
 * @param pScene BabylonJS scene
 * @param pSize Size of the grid in meter.
 * @param pLineDistance Distance between the grid lines in meter. (default: 0.1)
 */
export declare function createGrid(pScene: Scene, pSize: number, pLineDistance?: number): Mesh;
export declare function createAxisTrihedron(pScene: Scene, pSize?: number): Mesh;
/**
 * Places the elements in the center of the given view and tries to avoid collusion with other elements.
 * The elements will be centered at the found position. The positioning is done in the XZ-plane only.
 * The y-coordinate of the elements will not be modified.
 */
export declare function placeElementsInViewCenter(pElements: Array<SceneElement>, pView: View, pModel: ModelManager, pOptions?: PlaceElementsOptions): void;
/**
 * Places the elements at the desired position and tries to avoid collusion with other elements.
 * The elements will be centered at the found position. The positioning is done in the XZ-plane only.
 * The y-coordinate of the elements will not be modified.
 * @pDesiredPos: Desired position of the elements given as a 2D vector on the XZ-plane.
 */
export declare function placeElementsAtFreePosition(pElements: Array<SceneElement>, pDesiredPos: Vector2, pModel: ModelManager): void;
