import type { Serializable } from "./object";
export interface GroupedMapData {
    [groupKey: string]: {
        [dataKey: string]: unknown;
    };
}
export declare class GroupedMap implements Serializable<GroupedMapData> {
    constructor();
    clear(): void;
    /**
     * Adds or overrides an data entry.
     * Data used as custom data has to be serializable as a JSON string.
     * If pData is undefined an existing entry will be removed.
     * The group key should be a unique identifer (e.g. an appliaction id or a module id)
     */
    setData<T>(pGroupKey: string, pDataKey: string, pData: T | undefined): void;
    /**
     * Get the value for an data entry.
     */
    getData<T>(pGroupKey: string, pDataKey: string): T | undefined;
    serialize(): GroupedMapData | null;
    deserialize(pData?: GroupedMapData | null): boolean;
    private mData;
    private getGroup;
    private hasKeys;
}
export default GroupedMap;
