import { isNullOrEmpty } from "./string";
export class GroupedMap {
    constructor() {
        this.mData = {};
    }
    clear() {
        this.mData = {};
    }
    /**
     * Adds or overrides an data entry.
     * Data used as custom data has to be serializable as a JSON string.
     * If pData is undefined an existing entry will be removed.
     * The group key should be a unique identifer (e.g. an appliaction id or a module id)
     */
    setData(pGroupKey, pDataKey, pData) {
        if (isNullOrEmpty(pGroupKey) || isNullOrEmpty(pDataKey))
            return;
        if (pData !== undefined) {
            const tGroup = this.getGroup(pGroupKey, true);
            tGroup[pDataKey] = pData;
        }
        else {
            //remove data entry
            const tGroup = this.getGroup(pGroupKey, false);
            if (tGroup != null && pDataKey in tGroup) {
                delete tGroup[pDataKey];
                //remove group
                if (!this.hasKeys(tGroup))
                    delete this.mData[pGroupKey];
            }
        }
    }
    /**
     * Get the value for an data entry.
     */
    getData(pGroupKey, pDataKey) {
        if (isNullOrEmpty(pGroupKey) || isNullOrEmpty(pDataKey))
            return (undefined);
        const tGroup = this.getGroup(pGroupKey, false);
        if (tGroup != null) {
            const tData = tGroup[pDataKey];
            return (tData !== undefined ? tData : undefined);
        }
        return (undefined);
    }
    serialize() {
        if (this.hasKeys(this.mData))
            return (this.mData);
        return (null);
    }
    deserialize(pData) {
        this.mData = pData != null ? pData : {};
        return (true);
    }
    getGroup(pGroupKey, pCreate) {
        const tGroup = this.mData[pGroupKey];
        if (tGroup != null)
            return tGroup;
        if (pCreate) {
            const tGroup = {};
            this.mData[pGroupKey] = tGroup;
            return (tGroup);
        }
        return (undefined);
    }
    hasKeys(pObj) {
        if (pObj == null)
            return (false);
        return (Object.keys(pObj).length !== 0);
    }
}
export default GroupedMap;
