export type AbstractEventListener<T, O, R> = (pParameter: T, pEventOwner: O) => R;
export type EventListener<T, O> = AbstractEventListener<T, O, void>;
export type AsyncEventListener<T, O> = AbstractEventListener<T, O, Promise<void>>;
export declare abstract class AbstractListenableEvent<T, O, R> {
    get hasListeners(): boolean;
    constructor(pOwner: O);
    addListener(pListener: AbstractEventListener<T, O, R>): void;
    removeListener(pListener: AbstractEventListener<T, O, R>): void;
    abstract trigger(pParameter?: T): R;
    protected mOwner: O;
    protected mListeners: Array<AbstractEventListener<T, O, R>>;
    protected mLockQueue: Array<{
        remove: boolean;
        listener: AbstractEventListener<T, O, R>;
    }> | null;
    protected mListenersLocked: boolean;
    protected addToLockQueue(pRemove: boolean, pListener: AbstractEventListener<T, O, R>): void;
    protected processLockQueue(): void;
}
/**
* Synchronous listenable event.
*/
export declare class ListenableEvent<T, O> extends AbstractListenableEvent<T, O, void> {
    trigger(pParameter: T): void;
}
/**
* Asynchronous listenable event.
*/
export declare class AsyncListenableEvent<T, O> extends AbstractListenableEvent<T, O, Promise<void>> {
    constructor(pOwner: O);
    trigger(pParameter: T): Promise<void>;
    private mTriggerLock;
}
