export class Progress {
    get progress() {
        return (this.mProgress);
    }
    get sectionProgress() {
        return (this.mSectionProgress);
    }
    constructor(pCallback = null, pMultipleSections = false) {
        this.mSectionSize = 0;
        this.mSectionProgress = 0;
        this.mBaseProgress = 0;
        this.mProgress = 0;
        this.mCallback = pCallback;
        if (!pMultipleSections) {
            this.startSection(100);
        }
    }
    /**
     * Sets the current progress. If multiple sections are used the progress for the
     * current section will be set.
     * @param pProgress The new progress in percent. (range: [0, 100])
     */
    setProgress(pProgress) {
        if (this.mSectionProgress == pProgress)
            return;
        this.mSectionProgress = pProgress;
        const tAbsoluteProgress = this.mSectionProgress * (this.mSectionSize / 100.0);
        this.mProgress = this.mBaseProgress + tAbsoluteProgress;
        if (this.mCallback != null)
            this.mCallback(this.mProgress);
    }
    /**
     * Starts a new progress section and finishes previous one.
     * @param pSize Size of the section in percent.
     */
    startSection(pSize) {
        //finishe current section
        this.finishSection();
        this.mSectionSize = pSize;
    }
    finishSection() {
        //trigger callback
        this.setProgress(100);
        this.mBaseProgress += this.mSectionSize;
        this.mProgress = this.mBaseProgress;
        this.mSectionSize = 0;
        this.mSectionProgress = 0;
    }
}
export default Progress;
