import type { LoadContentErrorInfo } from "./dom";
import type { AjaxOptions, AjaxErrorInfo, AjaxRequestInfo } from "./async";
import type { ArticleConfigurationOptions } from "./options";
export interface WcfConfig {
    /**
     * Path of the W-CF data folder. e.g. `/wcf/data/`
     */
    dataPath?: string;
    /**
     * Options for article configuration.
     */
    articleConfigurationOptions: ArticleConfigurationOptions;
    /**
     * Default options used for ajax requests.
     */
    ajaxDefaultOptions: Required<AjaxOptions>;
    /**
     * Global ajax error handler which can be used to capture and handle all ajax errors.
     */
    ajaxErrorHandler?: ((pError: AjaxErrorInfo) => void);
    /**
     * Global ajax event which will be triggered for every successful ajax request.
     */
    ajaxResolvedEvent?: ((pRequestInfo: AjaxRequestInfo, pXhr: XMLHttpRequest) => void);
    /**
     * Global ajax event which will be triggered for every failed ajax request.
     */
    ajaxRejectedEvent?: ((pRequestInfo: AjaxRequestInfo, pXhr: XMLHttpRequest, pError: Error) => void);
    /**
     * Function which returns a delay (in ms) for the next ajax retry attempt based on the retry counter.
     * Can be overridden for custom delays. (default: 200ms * pRetryCount)
     */
    ajaxGetRetryDelay: (pRetryCount: number) => number;
    /**
     * Global error handler which can be used to capture and handle all content loading errors (DomUtils).
     */
    loadContentErrorHandler?: ((pError: LoadContentErrorInfo) => void);
}
export declare function getDataPath(): string;
/**
 * Global configuration for W-CF.
 */
export declare const wcfConfig: WcfConfig;
export default wcfConfig;
