/**
 * Returns true if the given object is an array. No type conversion will be performed.
 */
export declare function isArray<T = unknown>(pObj: unknown): pObj is Array<T>;
/**
 * Removes the first element from pArray equal to pElement.
 * Returns true if element was removed.
 */
export declare function removeElement<T>(pArray: Array<T>, pElement: T): boolean;
/**
 * Adds a list of elements to the given array.
 */
export declare function addElements<T>(pArray: Array<T>, pElements: Array<T>): void;
/**
 * Inserts a list of elements into the given array.
 */
export declare function insertElements<T>(pArray: Array<T>, pElements: Array<T>, pInsertIndex: number): void;
/**
 * Creates a clone of the given array.
 */
export declare function clone<T>(pArray: Array<T> | ReadonlyArray<T>): Array<T>;
/**
 * Returns true if pArray contains pElement.
 */
export declare function contains<T>(pArray: Array<T> | ReadonlyArray<T>, pElement: T): boolean;
/**
 * Clears the given array.
 * Note: Its usually faster to create a new empty array instead of clearing it.
 */
export declare function clear<T>(pArray: Array<T>): void;
/**
 * Returns a new array which only contains the unique entries (no duplicates) of pArray.
 */
export declare function unique<T>(pArray: Array<T> | ReadonlyArray<T>): Array<T>;
/**
 * Splits the given array into chunks.
 * Returns an array of arrays with the given chunk size.
 */
export declare function chunk<T>(pArray: Array<T> | ReadonlyArray<T>, pChunkSize: number): Array<Array<T>>;
