/**
 * A task which will be executed after a given delay.
 */
export declare class DelayedTask<T = void> {
    constructor(pTask: () => Promise<T>);
    /**
     * Starts the execution of the task. The task will be executed only once if consecutive
     * calls are made during the delay.
     * @param pDelay Delay in milliseconds before the task gets executed.
     * @param pRestartTimer If true and the delay timer is currently running, the timer will be
     * restartet with the new delay. If false the currently running timer will
     * stay active and the new delay is ignored. (default: false)
     */
    run(pDelay: number, pRestartTimer?: boolean): Promise<T>;
    private mTask;
    private mTimer;
    private mPromise;
    private mPromiseResolve;
    private mPromiseReject;
    private onTimeout;
}
export default DelayedTask;
