import { Timer } from "./Timer";
/**
 * A task which will be executed after a given delay.
 */
export class DelayedTask {
    constructor(pTask) {
        this.onTimeout = () => {
            const tResolve = this.mPromiseResolve;
            const tReject = this.mPromiseReject;
            this.mPromise = null;
            this.mPromiseResolve = null;
            this.mPromiseReject = null;
            if (tResolve != null && tReject != null) {
                this.mTask().then(tResolve).catch(tReject);
            }
        };
        this.mTask = pTask;
        this.mTimer = new Timer(this.onTimeout);
    }
    /**
     * Starts the execution of the task. The task will be executed only once if consecutive
     * calls are made during the delay.
     * @param pDelay Delay in milliseconds before the task gets executed.
     * @param pRestartTimer If true and the delay timer is currently running, the timer will be
     * restartet with the new delay. If false the currently running timer will
     * stay active and the new delay is ignored. (default: false)
     */
    run(pDelay, pRestartTimer = false) {
        if (this.mPromise == null) {
            this.mPromise = new Promise((resolve, reject) => {
                this.mPromiseResolve = resolve;
                this.mPromiseReject = reject;
            });
        }
        this.mTimer.start(pDelay, pRestartTimer);
        return (this.mPromise);
    }
}
export default DelayedTask;
