import { Lock } from "./Lock";
import { ERR_INVALID_ARGUMENT } from "../error";
/**
 * The TaskQueue is a FIFO queue for asynchronous tasks. The tasks are sequentially processed
 * in the order they were added.
 */
export class TaskQueue {
    get hasPendingTasks() {
        return (this.mLock.isLocked);
    }
    constructor(pLock) {
        this.mLock = pLock != null ? pLock : new Lock();
    }
    async addTask(pTask) {
        if (pTask == null)
            return (Promise.reject(new Error(ERR_INVALID_ARGUMENT)));
        const tLockContext = await this.mLock.acquireLock();
        try {
            const tResult = await pTask();
            return (tResult);
        }
        finally {
            //delay unlock to make sure that the promise then chain was executed first
            tLockContext.unlock(true);
        }
    }
}
export default TaskQueue;
