import type { AjaxMethod } from "../async";
export interface LoadContentErrorInfo {
    /** Url of the content which failed to load. */
    url: string;
    /** Shows how many retries were already performed. 0 for the first error. */
    retryCount: number;
    /** If called another attempt will be made to load the content. */
    retry(): void;
    /** If retry was not called reject has to be called to reject the underlying promise. */
    reject(): void;
}
/**
 * Loads the content of the given url and provides it via blob url.
 * If the content is no longer used `URL.revokeObjectURL()` has to be called to release resources.
 * Note: This function will trigger `async.ajaxErrorHandler` instead of `loadContentErrorHandler` because ajax is used internally.
 */
export declare function loadContentAsBlobUrl(pUrl: string): Promise<string>;
/**
 * Loads and executes JavaScript.
 * pAsync can be set to false to ensure correct execution order of loaded script. (default: true)
 */
export declare function loadScript(pUrl: string, pAsync?: boolean): Promise<void>;
/**
 * Loads a Cascading Style Sheet.
 */
export declare function loadStyleSheet(pUrl: string): Promise<void>;
/**
 * Submits the given fields as a form to the given url. This will change the window location.
 */
export declare function submitForm(pMethod: AjaxMethod, pUrl: string, pFields: Map<string, string>): void;
