export type ImageMimeType = "image/jpeg" | "image/png" | "image/svg+xml" | "image/gif";
export interface ResizeOptions {
    /** new width of the image */
    width: number;
    /** new height of the image */
    height: number;
    /** if false the aspect ratio of the resulting image may change (default: true) */
    keepAspectRatio?: boolean;
    /** mime type of the resulting dataUri / blob (default: "image/png") */
    mimeType?: string;
}
/**
 * Loads the given image and returns it as an HTMLImageElement.
 */
export declare function loadImage(pImageSrc: string | Blob | File): Promise<HTMLImageElement>;
/**
 * Returns the mime type of the given image source. Null will be returned if the mime type is
 * unknown or if its an unsupported type.
 */
export declare function getImageMimeType(pImageSrc: string | Blob | File): Promise<ImageMimeType | null>;
/** Resizes the given image according to the resize options and returns it as a canvas. */
export declare function resizeToCanvas(pImage: HTMLImageElement, pOptions: ResizeOptions): HTMLCanvasElement;
/** Resizes the given image according to the resize options and returns it as a dataUri. */
export declare function resizeToDataUri(pImage: HTMLImageElement, pOptions: ResizeOptions): string;
/** Resizes the given image according to the resize options and returns it as a blob. */
export declare function resizeToBlob(pImage: HTMLImageElement, pOptions: ResizeOptions): Promise<Blob>;
/**
 * Returns the image content of the given canvas as a blob.
 * If pMimeType is undefined it will be returned as a png file.
 */
export declare function canvasToBlob(pCanvas: HTMLCanvasElement, pMimeType?: string): Promise<Blob>;
