export declare const LengthUnit: {
    readonly Millimeter: 0;
    readonly Centimeter: 1;
    readonly Inch: 2;
    readonly Feet: 3;
    readonly Meter: 4;
    readonly Kilometer: 5;
};
export type LengthUnit = typeof LengthUnit[keyof typeof LengthUnit];
export interface CurrencyStringOptions {
    /** @defaultValue true */
    useGrouping?: boolean;
    /** @defaultValue true */
    showCurrency?: boolean;
    /**
     * Can be used to increase the precision of the currency string.
     * Additional decimal places will be shown only if necessary.
     * The minimum number of shown decimal places depend on the used currency.
     * @defaultValue 0
     */
    additionalDecimalPlaces?: number;
}
/**
 * Returns true if the given object is a number. No type conversion will be performed.
 */
export declare function isNumber(pObj: unknown): pObj is number;
/**
 * Converts a localized string to a number. Number grouping is not supported (thousands separators).
 * Null will be returned if the conversion fails.
 */
export declare function fromLocaleString(pString: string): number | null;
/**
 * Converts a number to a localized string.
 * Null will be returned if the conversion fails.
 */
export declare function toLocaleString(pValue: number, pLocale: string, pMinDecimalPlaces?: number, pMaxDecimalplaces?: number, pUseGrouping?: boolean): string | null;
/**
 * Converts a number to a localized currency string. Null will be returned if the conversion fails.
 */
export declare function toLocaleCurrencyString(pValue: number, pCurrency: string, pLocale: string, pOptions?: CurrencyStringOptions): string | null;
/**
 * Converts a localized length string to number. Number grouping is not supported (thousands separators).
 * If the string does not contain a length unit the default unit will be used.
 * The value will be returned in meter.
 * Null will be returned if the conversion fails.
 */
export declare function fromLocaleLengthString(pString: string, pDefaultUnit?: LengthUnit): number | null;
/**
 * Converts a number to localized length string. The value is expected in meter.
 * Null will be returned if the conversion fails.
 */
export declare function toLocaleLengthString(pValue: number, pLocale: string, pTargetUnit?: LengthUnit, pAddUnit?: boolean): string | null;
/**
 * Converts the given value into another length unit.
 */
export declare function convertLengthUnit(pValue: number, pFrom: LengthUnit, pTo: LengthUnit): number;
