/**
 * Returns true if the given object is a string. No type conversion will be performed.
 */
export declare function isString(pObj: unknown): pObj is string;
/**
 * Returns true if the string is null or empty.
 */
export declare function isNullOrEmpty(pString: string | null | undefined): pString is null | undefined;
/**
 * Returns true if the string is NOT null or empty.
 */
export declare function isNotNullOrEmpty(pString: string | null | undefined): pString is string;
/**
 * Removes pChar (default: " ") from the left and right end of the string.
 */
export declare function trim(pString: string, pChar?: string): string;
/**
 * Removes pChar (default: " ") from the left end of the string.
 */
export declare function trimLeft(pString: string, pChar?: string): string;
/**
 * Removes pChar (default: " ") from the right end of the string.
 */
export declare function trimRight(pString: string, pChar?: string): string;
/**
 * Compares two strings.
 */
export declare function compare(pString1: string, pString2: string): number;
/**
 * Returns the file extension of the given url. The returned extension will be always lowercase.
 * www.example.com/test/123.jpg ==> .jpg
 */
export declare function getFileExtension(pUrl: string): string;
/**
 * Returns the path of the given url.
 * www.example.com/test/123.jpg ==> www.example.com/test/
 */
export declare function getFilePath(pUrl: string): string;
/**
 * Returns the filename of the given url.
 * www.example.com/test/123.jpg ==> 123.jpg
 */
export declare function getFileName(pUrl: string): string;
/**
 * Joins given path segements into one path.
 * Resolving of ".." or "." is not supported.
 */
export declare function joinPath(...pSegments: Array<string>): string;
/**
 * Returns the value of the given parameter.
 * www.example.com/test/123.jpg?x=1&y=2 ==> 2 (for pParam = "y")
 */
export declare function getUrlParamValue(pUrl: string, pParam: string): string | null;
/**
 * Removes the query string from the given url.
 * www.example.com/test/?x=1&y=2 ==> www.example.com/test/
 */
export declare function removeQueryString(pUrl: string): string;
/**
 * Converts a Blob into a string.
 * If pAsDataUri is true the returned string is a data-uri, otherwise its returned as text.
 */
export declare function fromBlob(pBlob: Blob, pAsDataUri?: boolean): Promise<string>;
export declare function isDataUri(pUri: string | null | undefined): pUri is string;
export declare function htmlEscape(pString: string): string;
export declare function htmlUnescape(pString: string): string;
export declare function regExpEscape(pString: string): string;
/** Returns a randomly generated UUID */
export declare function generateRandomUUID(): string;
/**
 * Computes the hash for the given string and returns it as hex string.
 * Note: This function requires a secure connection (HTTPS).
 */
export declare function hash(pString: string, pAlgorithm: "SHA-256" | "SHA-384" | "SHA-512"): Promise<string>;
/** Encodes the given UTF-16 string to UTF-8 */
export declare function encodeToUtf8(pString: string): Uint8Array;
